/**
 * Copyright (c) 2024 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_M3NGLR.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_M3NGLR *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_M3NGLR_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_M3NGLR));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_M3NGLR(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_M3NGLR_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_M3NGLR();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_M3NGLR::Heavy_WSTD_M3NGLR(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_ZOeBbbVZ);
  numBytes += sLine_init(&sLine_hGf2FpqY);
  numBytes += sLine_init(&sLine_9Xgar7jj);
  numBytes += sLine_init(&sLine_MKJ09TSf);
  numBytes += sLine_init(&sLine_hvgeg9sF);
  numBytes += sBiquad_init(&sBiquad_s_QwZvdJJN);
  numBytes += sLine_init(&sLine_Mg9MSduF);
  numBytes += sLine_init(&sLine_WOvgOVEU);
  numBytes += sLine_init(&sLine_aN7Jc6BW);
  numBytes += sLine_init(&sLine_4vFahpIw);
  numBytes += sLine_init(&sLine_vBUUph3E);
  numBytes += sBiquad_init(&sBiquad_s_KAqkDk9J);
  numBytes += sLine_init(&sLine_EQmP72dH);
  numBytes += sLine_init(&sLine_rMV9vtvg);
  numBytes += sLine_init(&sLine_SrI2ZcZI);
  numBytes += sLine_init(&sLine_ThP14mLv);
  numBytes += sLine_init(&sLine_8Z45XNva);
  numBytes += sLine_init(&sLine_cO5lWzbm);
  numBytes += sBiquad_init(&sBiquad_s_P08K5zH7);
  numBytes += sLine_init(&sLine_VxqEsrjh);
  numBytes += sLine_init(&sLine_cv5YdsnC);
  numBytes += sLine_init(&sLine_xFV4yTk9);
  numBytes += sLine_init(&sLine_z24rrDfZ);
  numBytes += sLine_init(&sLine_V7LUW4nh);
  numBytes += sLine_init(&sLine_RnPwQuAo);
  numBytes += sBiquad_init(&sBiquad_s_2FTIEPeW);
  numBytes += sLine_init(&sLine_jvbffNYL);
  numBytes += sLine_init(&sLine_CMani0fC);
  numBytes += sLine_init(&sLine_PLd9bjgH);
  numBytes += sLine_init(&sLine_VHBmNeoE);
  numBytes += sLine_init(&sLine_1XFfSDBF);
  numBytes += sBiquad_init(&sBiquad_s_lU6SMEuO);
  numBytes += sLine_init(&sLine_8RDoSDxF);
  numBytes += sLine_init(&sLine_dNtwdJeF);
  numBytes += sLine_init(&sLine_65gaAlL7);
  numBytes += sLine_init(&sLine_BOVxuxvB);
  numBytes += sLine_init(&sLine_4LoNRmDL);
  numBytes += sLine_init(&sLine_tOpsZd1x);
  numBytes += sBiquad_init(&sBiquad_s_UVSlBIDf);
  numBytes += sLine_init(&sLine_BGKMYpVJ);
  numBytes += sLine_init(&sLine_M0BhYKdh);
  numBytes += sLine_init(&sLine_j3vHudWM);
  numBytes += sLine_init(&sLine_b6JfQ6Yx);
  numBytes += sLine_init(&sLine_TcGiiXx5);
  numBytes += sLine_init(&sLine_TsrwImJS);
  numBytes += sLine_init(&sLine_vgk2A29g);
  numBytes += sLine_init(&sLine_5i3cKbwr);
  numBytes += sLine_init(&sLine_as6iOcEA);
  numBytes += sLine_init(&sLine_uZVPAFjQ);
  numBytes += sLine_init(&sLine_Y2aK6ioQ);
  numBytes += sLine_init(&sLine_rux4Ib7O);
  numBytes += sLine_init(&sLine_SUsBlk7q);
  numBytes += sLine_init(&sLine_vjWx736Y);
  numBytes += sLine_init(&sLine_x2v0Xapd);
  numBytes += sEnv_init(&sEnv_SzU1Mg5w, 512, 256);
  numBytes += sEnv_init(&sEnv_r1AUVe7v, 512, 256);
  numBytes += sLine_init(&sLine_Hl5evBY3);
  numBytes += sLine_init(&sLine_9PytLlaS);
  numBytes += sLine_init(&sLine_KAuxWufi);
  numBytes += sLine_init(&sLine_haNl1Bjx);
  numBytes += sLine_init(&sLine_JbSmkbzI);
  numBytes += sLine_init(&sLine_BJG1KiGC);
  numBytes += sLine_init(&sLine_Amup6ac7);
  numBytes += sLine_init(&sLine_5PX6IIL2);
  numBytes += sLine_init(&sLine_LE4uBWtt);
  numBytes += sLine_init(&sLine_CFcAkCVd);
  numBytes += sLine_init(&sLine_fWn3rJPF);
  numBytes += sLine_init(&sLine_x3BXTbFk);
  numBytes += sLine_init(&sLine_Iz1IHbn5);
  numBytes += sLine_init(&sLine_6UeR09yG);
  numBytes += sLine_init(&sLine_kFMrlk7R);
  numBytes += sLine_init(&sLine_WehHQnjj);
  numBytes += sLine_init(&sLine_KteZ0aWz);
  numBytes += sLine_init(&sLine_oQ3pGVQP);
  numBytes += sEnv_init(&sEnv_kksJiUaw, 512, 256);
  numBytes += sEnv_init(&sEnv_ZjkUFwqk, 512, 256);
  numBytes += sLine_init(&sLine_q5pfCqxf);
  numBytes += sLine_init(&sLine_RfORtUQ1);
  numBytes += sLine_init(&sLine_RsX1NoMl);
  numBytes += sLine_init(&sLine_rsY2H9Ff);
  numBytes += sLine_init(&sLine_zREY1SfF);
  numBytes += sLine_init(&sLine_WgWslSHv);
  numBytes += sLine_init(&sLine_Ocj7vzbK);
  numBytes += sLine_init(&sLine_vLgVHuBp);
  numBytes += sLine_init(&sLine_33yab13v);
  numBytes += sLine_init(&sLine_nEOA8aI9);
  numBytes += sLine_init(&sLine_HkB7Kaxa);
  numBytes += sLine_init(&sLine_tJWtFdSf);
  numBytes += sLine_init(&sLine_4oL7ZEfr);
  numBytes += sLine_init(&sLine_Wq1AhdFy);
  numBytes += sLine_init(&sLine_hq1ABSg2);
  numBytes += sLine_init(&sLine_zGKQYMr7);
  numBytes += sLine_init(&sLine_AXn5EXnY);
  numBytes += sLine_init(&sLine_437k1aT2);
  numBytes += sLine_init(&sLine_EPkRW1uP);
  numBytes += sLine_init(&sLine_hxeeEjSG);
  numBytes += sEnv_init(&sEnv_YC3GgUsK, 512, 256);
  numBytes += sEnv_init(&sEnv_myiR8KhG, 512, 256);
  numBytes += sLine_init(&sLine_Cebs6eJz);
  numBytes += sLine_init(&sLine_o8S4vgbQ);
  numBytes += sLine_init(&sLine_dZeitjSt);
  numBytes += sLine_init(&sLine_r4SvA1pf);
  numBytes += sLine_init(&sLine_XWFdzROz);
  numBytes += sLine_init(&sLine_GeARnWNh);
  numBytes += sLine_init(&sLine_jZkGFHbA);
  numBytes += sLine_init(&sLine_bLVWCqtx);
  numBytes += sLine_init(&sLine_9HskizCq);
  numBytes += sLine_init(&sLine_XJPZ4dP4);
  numBytes += sLine_init(&sLine_HJ8VGAqS);
  numBytes += sLine_init(&sLine_JNOQDcZc);
  numBytes += sLine_init(&sLine_5nJShd33);
  numBytes += sLine_init(&sLine_ILItmIhh);
  numBytes += sLine_init(&sLine_lUzJ7L0B);
  numBytes += sLine_init(&sLine_6yHMomB5);
  numBytes += sLine_init(&sLine_ex5WzkHe);
  numBytes += sLine_init(&sLine_N24yBwr2);
  numBytes += sEnv_init(&sEnv_HNxBPYug, 512, 256);
  numBytes += sEnv_init(&sEnv_DzKQc4mD, 512, 256);
  numBytes += sLine_init(&sLine_jX4ZQ6vE);
  numBytes += sLine_init(&sLine_ThGM0DTZ);
  numBytes += sLine_init(&sLine_WWKCJHek);
  numBytes += sLine_init(&sLine_FDQL6git);
  numBytes += sLine_init(&sLine_XtwCSIKZ);
  numBytes += sLine_init(&sLine_KKsj5Poa);
  numBytes += sLine_init(&sLine_RuJ0NTsR);
  numBytes += sLine_init(&sLine_FVo9Od1b);
  numBytes += sLine_init(&sLine_sHT0QqiO);
  numBytes += sLine_init(&sLine_1xS2KbNe);
  numBytes += sLine_init(&sLine_FnhbTJOl);
  numBytes += sLine_init(&sLine_V6F7dCFZ);
  numBytes += sLine_init(&sLine_JTwocyq2);
  numBytes += sLine_init(&sLine_VlWyqMrN);
  numBytes += sLine_init(&sLine_IXfG83bu);
  numBytes += sLine_init(&sLine_IcTTtF1K);
  numBytes += sLine_init(&sLine_xdrxI4yx);
  numBytes += sLine_init(&sLine_x6UyTMU5);
  numBytes += sLine_init(&sLine_awq9kSRG);
  numBytes += sLine_init(&sLine_uQomrI8Z);
  numBytes += sEnv_init(&sEnv_YAbtSPPU, 512, 256);
  numBytes += sEnv_init(&sEnv_ILqxuXLg, 512, 256);
  numBytes += sLine_init(&sLine_FmttK2NN);
  numBytes += sLine_init(&sLine_nB3hjMCB);
  numBytes += sLine_init(&sLine_vDCz0vsr);
  numBytes += sLine_init(&sLine_aF8OwE6S);
  numBytes += sLine_init(&sLine_Ei4G7UyD);
  numBytes += sLine_init(&sLine_ex897gix);
  numBytes += sLine_init(&sLine_kwUgVFKH);
  numBytes += sLine_init(&sLine_AmMnkekN);
  numBytes += sLine_init(&sLine_r5jsoVuv);
  numBytes += sLine_init(&sLine_ICVTUUMi);
  numBytes += sLine_init(&sLine_av0Qnxwf);
  numBytes += sLine_init(&sLine_YLynZFV2);
  numBytes += sLine_init(&sLine_53Y1YoUR);
  numBytes += sLine_init(&sLine_LUBmlDLt);
  numBytes += sLine_init(&sLine_vQteJK76);
  numBytes += sLine_init(&sLine_yJPNxfCa);
  numBytes += sLine_init(&sLine_jhbFsZEl);
  numBytes += sLine_init(&sLine_jDIBKC49);
  numBytes += sEnv_init(&sEnv_dnYJh9KV, 512, 256);
  numBytes += sEnv_init(&sEnv_jilBNwLN, 512, 256);
  numBytes += sLine_init(&sLine_KZ1utVkS);
  numBytes += sLine_init(&sLine_2memqOg2);
  numBytes += sLine_init(&sLine_0pQCN5Kc);
  numBytes += sLine_init(&sLine_xbNZdjGY);
  numBytes += sLine_init(&sLine_5tAv0asA);
  numBytes += sLine_init(&sLine_f75shRFM);
  numBytes += cVar_init_f(&cVar_UkvQXLun, 0.0f);
  numBytes += cVar_init_f(&cVar_ANoxoS0D, 0.0f);
  numBytes += cVar_init_f(&cVar_t2srMOuV, 0.0f);
  numBytes += cVar_init_f(&cVar_UNm64l6V, 0.0f);
  numBytes += cVar_init_f(&cVar_hrxvJqeQ, 0.0f);
  numBytes += cVar_init_f(&cVar_aU3F5Jd1, 1.0f);
  numBytes += cVar_init_f(&cVar_x401s5wK, 0.0f);
  numBytes += cVar_init_f(&cVar_dfIeFrSo, 0.0f);
  numBytes += cVar_init_f(&cVar_0VOdPL9A, 0.0f);
  numBytes += cVar_init_f(&cVar_ql6eD9bC, 0.0f);
  numBytes += cSlice_init(&cSlice_l2NG6Akl, 1, -1);
  numBytes += cVar_init_f(&cVar_OTZ2P7km, 1337.0f);
  numBytes += cVar_init_f(&cVar_H9Gi5V0f, 0.0f);
  numBytes += cIf_init(&cIf_4MrpP7WS, false);
  numBytes += cIf_init(&cIf_zkDCQYTV, false);
  numBytes += cBinop_init(&cBinop_CpymegU0, 0.0f); // __pow
  numBytes += cIf_init(&cIf_QqFZ7lwf, false);
  numBytes += cBinop_init(&cBinop_4eejPYHH, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_YSmmOTAk, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_WMx4uUvf, 0.0f);
  numBytes += cIf_init(&cIf_wQq3aRhv, false);
  numBytes += cIf_init(&cIf_Qet4TjMQ, false);
  numBytes += cBinop_init(&cBinop_fO6FGosE, 0.0f); // __pow
  numBytes += cIf_init(&cIf_YPdAtwER, false);
  numBytes += cBinop_init(&cBinop_bU7bCBBw, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_h7mdOOjI, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_SDIKrpL5, 0.0f);
  numBytes += cIf_init(&cIf_YIU2HRGe, false);
  numBytes += cIf_init(&cIf_zNjhkVKK, false);
  numBytes += cBinop_init(&cBinop_jXSvyfAi, 0.0f); // __pow
  numBytes += cIf_init(&cIf_dNRxj8mv, false);
  numBytes += cBinop_init(&cBinop_D5agX6vB, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_GcahQAuU, -15.0f); // __eq
  numBytes += cIf_init(&cIf_E4aVmpqM, false);
  numBytes += cSlice_init(&cSlice_XCJoRbEH, 1, -1);
  numBytes += cVar_init_f(&cVar_pl2tJWT2, 0.0f);
  numBytes += cSlice_init(&cSlice_GDlw24Ih, 1, -1);
  numBytes += cVar_init_f(&cVar_bMHruCBO, 0.0f);
  numBytes += cSlice_init(&cSlice_us6APVtJ, 1, -1);
  numBytes += cVar_init_f(&cVar_3OrgEmYu, 0.0f);
  numBytes += cSlice_init(&cSlice_c5UOmdMJ, 1, -1);
  numBytes += cVar_init_f(&cVar_Sgsf3ZbE, 0.313f);
  numBytes += cBinop_init(&cBinop_NsjVv2gI, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_FcXNMCqN, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_2BNQBuGx, 0.0f);
  numBytes += cVar_init_f(&cVar_1hzxuc6y, 1337.0f);
  numBytes += cVar_init_f(&cVar_CBgs2Usn, 0.3f);
  numBytes += cBinop_init(&cBinop_goAi8gRr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_aBHzMu6H, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ophCGZeH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n7jxP4cG, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Mtcr1NqZ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_C1sUrP1R, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3xsBV9L8, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_PYLVcI15, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_FsHVdiIS, 0.0f);
  numBytes += cVar_init_f(&cVar_SBA0vJMJ, 1337.0f);
  numBytes += cVar_init_f(&cVar_V0H9nEB0, 0.313f);
  numBytes += cBinop_init(&cBinop_Ll55qBgv, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gIcawS0O, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PIl1Xc2m, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_VDptQ2JL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yGYpklJN, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mJOjGH8p, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_aUmGvZgE, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_bTQgIgIP, 0.0f);
  numBytes += cVar_init_f(&cVar_QfWHOMo4, 1037.0f);
  numBytes += cVar_init_f(&cVar_cRnodEW8, 0.4f);
  numBytes += cBinop_init(&cBinop_dWg4uJIT, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_W2FnhjPs, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_h7PNNT6X, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_BTZeY2mF, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_lq1h5Wn9, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_CFlWRvqf, 0.0f); // __mul
  numBytes += cSlice_init(&cSlice_mS3mjczl, 1, -1);
  numBytes += cVar_init_f(&cVar_LoyYGURe, 1337.0f);
  numBytes += cVar_init_f(&cVar_D01V6tuc, 0.0f);
  numBytes += cIf_init(&cIf_cBILNo4O, false);
  numBytes += cIf_init(&cIf_Licd7WAf, false);
  numBytes += cBinop_init(&cBinop_ZXw2EpZY, 0.0f); // __pow
  numBytes += cIf_init(&cIf_NsgBySdI, false);
  numBytes += cBinop_init(&cBinop_3sRw1qal, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_tVz078zR, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_ObQdHxPu, 0.0f);
  numBytes += cIf_init(&cIf_MvQJj3g9, false);
  numBytes += cIf_init(&cIf_2pE7F5rj, false);
  numBytes += cBinop_init(&cBinop_TRuqpaoi, 0.0f); // __pow
  numBytes += cIf_init(&cIf_Gx5RGtAL, false);
  numBytes += cBinop_init(&cBinop_LdEphhkV, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_nmGCaEcj, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_Z2TEJbtH, 0.0f);
  numBytes += cIf_init(&cIf_YOYi5ziX, false);
  numBytes += cIf_init(&cIf_Yk81hubb, false);
  numBytes += cBinop_init(&cBinop_A2Ki5HSK, 0.0f); // __pow
  numBytes += cIf_init(&cIf_3064x8Nq, false);
  numBytes += cBinop_init(&cBinop_NrLWa55y, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_VF3rn5SY, -15.0f); // __eq
  numBytes += cIf_init(&cIf_r9nJ30P5, false);
  numBytes += cSlice_init(&cSlice_iIdnUcBg, 1, -1);
  numBytes += cVar_init_f(&cVar_8jftzPAU, 0.0f);
  numBytes += cSlice_init(&cSlice_HmPjbKBI, 1, -1);
  numBytes += cVar_init_f(&cVar_igAYNggO, 0.0f);
  numBytes += cSlice_init(&cSlice_UFmuYsaF, 1, -1);
  numBytes += cVar_init_f(&cVar_BWypEAXZ, 0.0f);
  numBytes += cSlice_init(&cSlice_M2eG9rZn, 1, -1);
  numBytes += cVar_init_f(&cVar_XwJxRsjH, 0.313f);
  numBytes += cBinop_init(&cBinop_0Wgehjnl, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_YVaE4GZK, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_H07OUEMo, 0.0f);
  numBytes += cVar_init_f(&cVar_f2gVMdop, 1337.0f);
  numBytes += cVar_init_f(&cVar_zevAJZHr, 0.3f);
  numBytes += cBinop_init(&cBinop_bzEQL0sg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_470ztHIg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_p6DHONxi, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F3CehKFM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jgvctNWj, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_SU6XD030, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_o3IcCUoz, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_ehsQYoMl, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lUMWMHhY, 0.0f);
  numBytes += cVar_init_f(&cVar_jTIhYFUW, 1337.0f);
  numBytes += cVar_init_f(&cVar_YwIpXsyv, 0.313f);
  numBytes += cBinop_init(&cBinop_3Cjv9tmM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_m59Rl0cm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mUJXXaD8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3QuZUshB, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_IimmWLPR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_uHaZR2dw, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_yqpSXli0, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lBlb23vL, 0.0f);
  numBytes += cVar_init_f(&cVar_0dyI41HF, 1037.0f);
  numBytes += cVar_init_f(&cVar_V8pKMcG5, 0.4f);
  numBytes += cBinop_init(&cBinop_Kv1LGaau, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9TUcRXI8, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xXE7wWXq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4Dral4M2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DYGAMLlJ, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_8uQIcEFu, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_4fT2c69J, 5705.6f);
  numBytes += cVar_init_f(&cVar_1hUz6JTn, 313.3f);
  numBytes += cBinop_init(&cBinop_OgMvIqfc, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_DzkM9UDr, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_DwnBqS8O, 0.0f); // __div
  numBytes += cSlice_init(&cSlice_sN3f8nh3, 1, -1);
  numBytes += cVar_init_f(&cVar_2aiK2hlL, 0.5f);
  numBytes += cVar_init_f(&cVar_5vBgnkK1, 0.0f);
  numBytes += cVar_init_f(&cVar_pkbtQMxk, 0.0f);
  numBytes += cIf_init(&cIf_zacxcrnV, false);
  numBytes += cIf_init(&cIf_nmYMGTUZ, false);
  numBytes += cDelay_init(this, &cDelay_6AGtiTwU, 10.0f);
  numBytes += cIf_init(&cIf_c0OVn4zC, false);
  numBytes += cIf_init(&cIf_0GCApF5L, false);
  numBytes += cDelay_init(this, &cDelay_KvHGW4z7, 10.0f);
  numBytes += cIf_init(&cIf_h1mQn4Ai, false);
  numBytes += cIf_init(&cIf_ZFlJNBqi, false);
  numBytes += cDelay_init(this, &cDelay_tGqJHwWu, 10.0f);
  numBytes += cIf_init(&cIf_sKkiudFx, false);
  numBytes += cIf_init(&cIf_bDvbezYj, false);
  numBytes += cDelay_init(this, &cDelay_ikVlohNo, 10.0f);
  numBytes += cIf_init(&cIf_c2q1IJze, false);
  numBytes += cIf_init(&cIf_LcRZdcuD, false);
  numBytes += cDelay_init(this, &cDelay_1i4hb90Z, 10.0f);
  numBytes += cIf_init(&cIf_O4LhuDzu, false);
  numBytes += cIf_init(&cIf_waaNUxxe, false);
  numBytes += cDelay_init(this, &cDelay_cF8qXh33, 10.0f);
  numBytes += cIf_init(&cIf_f4REcdOQ, false);
  numBytes += cIf_init(&cIf_VKtG1V8Y, false);
  numBytes += cDelay_init(this, &cDelay_sTFZEcrO, 10.0f);
  numBytes += cIf_init(&cIf_FSSH5lsc, false);
  numBytes += cIf_init(&cIf_J8qCrqmL, false);
  numBytes += cDelay_init(this, &cDelay_vBmkM8qh, 10.0f);
  numBytes += cIf_init(&cIf_QDZO8DUc, false);
  numBytes += cIf_init(&cIf_4bPBliNH, false);
  numBytes += cDelay_init(this, &cDelay_342DfgT0, 10.0f);
  numBytes += cIf_init(&cIf_Tzf6mrC7, false);
  numBytes += cIf_init(&cIf_TnHSqcEv, false);
  numBytes += cDelay_init(this, &cDelay_5g90UroN, 10.0f);
  numBytes += cIf_init(&cIf_tt67qgvo, false);
  numBytes += cIf_init(&cIf_FM1hxvcX, false);
  numBytes += cDelay_init(this, &cDelay_giU8FuRK, 10.0f);
  numBytes += cIf_init(&cIf_Z5HL0Vy2, false);
  numBytes += cIf_init(&cIf_wxI3v4oa, false);
  numBytes += cDelay_init(this, &cDelay_h3rWI0kQ, 10.0f);
  numBytes += sVarf_init(&sVarf_XXUtD7nQ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WLNirjgn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IjEgCF5h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MR9JOta2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gl3fNEa6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mSaYzbMP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Qw4Ashuu, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6F1u4lsb, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_pL5UZ1Is, 0.0f);
  numBytes += cSlice_init(&cSlice_7P3I93Ee, 1, -1);
  numBytes += cVar_init_f(&cVar_z9hPylKB, 1.0f);
  numBytes += cSlice_init(&cSlice_ekA0V07C, 1, -1);
  numBytes += cVar_init_f(&cVar_3gr4lKTW, 0.0f);
  numBytes += cSlice_init(&cSlice_zEdcrHWq, 1, -1);
  numBytes += cVar_init_f(&cVar_92fkXwrb, 512.0f);
  numBytes += cSlice_init(&cSlice_oblMCnoI, 1, -1);
  numBytes += cVar_init_f(&cVar_uCmw2PU5, 1.0f);
  numBytes += cSlice_init(&cSlice_k0GUsCM6, 1, -1);
  numBytes += cVar_init_f(&cVar_HMiy9kLM, 1.0f);
  numBytes += cDelay_init(this, &cDelay_OploP7O7, 20.0f);
  numBytes += cVar_init_f(&cVar_FRRE13iT, 0.0f);
  numBytes += cIf_init(&cIf_ycT9EXVs, false);
  numBytes += cIf_init(&cIf_lDRfg2iR, false);
  numBytes += cBinop_init(&cBinop_B7juqCkG, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_vOQIV2S3, 1, -1);
  numBytes += cVar_init_f(&cVar_FBlTI44G, 0.0f);
  numBytes += sVarf_init(&sVarf_BTpn5a0u, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_aUTsflgY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vk0dlxjF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_3pWqBGAE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2HjApR2h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_09no9Kk7, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_yAedVnxt, 0.0f);
  numBytes += cVar_init_f(&cVar_JM3hY38V, 0.0f);
  numBytes += cIf_init(&cIf_5fRCFvu4, false);
  numBytes += cIf_init(&cIf_cCmJeFnc, false);
  numBytes += cDelay_init(this, &cDelay_v0KvlXOI, 10.0f);
  numBytes += cIf_init(&cIf_TacuFvmU, false);
  numBytes += cIf_init(&cIf_lCnQvep0, false);
  numBytes += cDelay_init(this, &cDelay_MspRSXU7, 10.0f);
  numBytes += cIf_init(&cIf_l2B0zUig, false);
  numBytes += cIf_init(&cIf_R2mT0IIL, false);
  numBytes += cDelay_init(this, &cDelay_UrmJbC38, 10.0f);
  numBytes += cIf_init(&cIf_45plQL05, false);
  numBytes += cIf_init(&cIf_A8Zr6JIS, false);
  numBytes += cDelay_init(this, &cDelay_9giVkct1, 10.0f);
  numBytes += cIf_init(&cIf_tOKxDDBZ, false);
  numBytes += cIf_init(&cIf_Z038PjfK, false);
  numBytes += cDelay_init(this, &cDelay_rWGEtbNz, 10.0f);
  numBytes += cIf_init(&cIf_ze9YD0Lh, false);
  numBytes += cIf_init(&cIf_NAGl4fPS, false);
  numBytes += cDelay_init(this, &cDelay_UGZJbkpr, 10.0f);
  numBytes += cIf_init(&cIf_zRDWkNm3, false);
  numBytes += cIf_init(&cIf_DmkCRs1M, false);
  numBytes += cDelay_init(this, &cDelay_stMQYN8l, 10.0f);
  numBytes += cIf_init(&cIf_VwmBxOHe, false);
  numBytes += cIf_init(&cIf_9Irb7xtY, false);
  numBytes += cDelay_init(this, &cDelay_fklZafgk, 10.0f);
  numBytes += cIf_init(&cIf_DqC5y9O4, false);
  numBytes += cIf_init(&cIf_BTCoBWKc, false);
  numBytes += cDelay_init(this, &cDelay_7224rNhR, 10.0f);
  numBytes += cIf_init(&cIf_Y1GeHyFS, false);
  numBytes += cIf_init(&cIf_4tic66nM, false);
  numBytes += cDelay_init(this, &cDelay_knr7LOG6, 10.0f);
  numBytes += cIf_init(&cIf_jmPcFBZr, false);
  numBytes += cIf_init(&cIf_vhELm55x, false);
  numBytes += cDelay_init(this, &cDelay_EwYQNt2q, 10.0f);
  numBytes += cIf_init(&cIf_bUFL9L9j, false);
  numBytes += cIf_init(&cIf_cvHrlWmD, false);
  numBytes += cDelay_init(this, &cDelay_GTqCtS7I, 10.0f);
  numBytes += sVarf_init(&sVarf_an8zVcKP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_P50ro213, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MH5D78Wk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_TlwMpO2c, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_lj7BKeYJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JqLPif8h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_al4cmFl8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_E2USeYes, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_HJLja1XM, 0.0f);
  numBytes += cSlice_init(&cSlice_llFT4YZA, 1, -1);
  numBytes += cVar_init_f(&cVar_WJJsmunl, 1.0f);
  numBytes += cSlice_init(&cSlice_xqIjzxIC, 1, -1);
  numBytes += cVar_init_f(&cVar_urQ5YvlS, 0.0f);
  numBytes += cSlice_init(&cSlice_2IBRkYLz, 1, -1);
  numBytes += cVar_init_f(&cVar_F6FlagqR, 512.0f);
  numBytes += cSlice_init(&cSlice_zfaKm5Fn, 1, -1);
  numBytes += cVar_init_f(&cVar_X9myvkOo, 1.0f);
  numBytes += cSlice_init(&cSlice_apjnyVnx, 1, -1);
  numBytes += cVar_init_f(&cVar_MwJZ4u8i, 1.0f);
  numBytes += cDelay_init(this, &cDelay_JnLQwW5R, 20.0f);
  numBytes += cVar_init_f(&cVar_QJ2ksOjW, 0.0f);
  numBytes += cIf_init(&cIf_mBCJHjfJ, false);
  numBytes += cIf_init(&cIf_sEK779YJ, false);
  numBytes += cBinop_init(&cBinop_KAu7ZK39, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_LuUBDVnA, 1, -1);
  numBytes += cVar_init_f(&cVar_sbW5KNdv, 0.0f);
  numBytes += sVarf_init(&sVarf_xYXOG4lD, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UIwRAVdB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_antCWRGZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_86J64EOS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vnV661We, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_PRTAcL6O, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xBOaD12J, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_botqymwU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5YQTRUbK, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_G98Ii2OV, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bXYh4yTv, 0.0f);
  numBytes += cVar_init_f(&cVar_Uk3kaKCv, 0.0f);
  numBytes += cVar_init_f(&cVar_WzuETTt3, 0.0f);
  numBytes += cVar_init_f(&cVar_o5IInfu9, 0.0f);
  numBytes += cVar_init_f(&cVar_bBlv1pdg, 0.0f);
  numBytes += cVar_init_f(&cVar_CAgNaqfD, 1.0f);
  numBytes += cSlice_init(&cSlice_xqVj3oQ2, 1, -1);
  numBytes += cVar_init_f(&cVar_JVVr0Q7E, 0.5f);
  numBytes += cVar_init_f(&cVar_tn2ePXqD, 0.0f);
  numBytes += cVar_init_f(&cVar_Q63Yi7sM, 0.0f);
  numBytes += cIf_init(&cIf_MNKXkYdw, false);
  numBytes += cIf_init(&cIf_Q4MJX2wv, false);
  numBytes += cDelay_init(this, &cDelay_52YtQ6uc, 10.0f);
  numBytes += cIf_init(&cIf_Ov1Tki7s, false);
  numBytes += cIf_init(&cIf_FTlsW5dv, false);
  numBytes += cDelay_init(this, &cDelay_PuhnlftT, 10.0f);
  numBytes += cIf_init(&cIf_6Sh2QI8d, false);
  numBytes += cIf_init(&cIf_volgETEt, false);
  numBytes += cDelay_init(this, &cDelay_e0l0RgNs, 10.0f);
  numBytes += cIf_init(&cIf_N6luCJ95, false);
  numBytes += cIf_init(&cIf_gr8s9RXm, false);
  numBytes += cDelay_init(this, &cDelay_ALHcyMFy, 10.0f);
  numBytes += cIf_init(&cIf_XLn2Pfvl, false);
  numBytes += cIf_init(&cIf_G2Wt1WGU, false);
  numBytes += cDelay_init(this, &cDelay_eMxqCY9R, 10.0f);
  numBytes += cIf_init(&cIf_3JcjuiNH, false);
  numBytes += cIf_init(&cIf_c04Lq1Rm, false);
  numBytes += cDelay_init(this, &cDelay_sE3fTqya, 10.0f);
  numBytes += cIf_init(&cIf_nxcwJEEx, false);
  numBytes += cIf_init(&cIf_f8mJhpRC, false);
  numBytes += cDelay_init(this, &cDelay_hjjmAMMC, 10.0f);
  numBytes += cIf_init(&cIf_RyYkvXyJ, false);
  numBytes += cIf_init(&cIf_WMihCLXf, false);
  numBytes += cDelay_init(this, &cDelay_NIAxwE0S, 10.0f);
  numBytes += cIf_init(&cIf_AGVfHqgZ, false);
  numBytes += cIf_init(&cIf_BfSqETYR, false);
  numBytes += cDelay_init(this, &cDelay_quP7hYM7, 10.0f);
  numBytes += cIf_init(&cIf_UWe6Kqb3, false);
  numBytes += cIf_init(&cIf_xNoNKby4, false);
  numBytes += cDelay_init(this, &cDelay_njuhCvhH, 10.0f);
  numBytes += cIf_init(&cIf_ZtNPPhHm, false);
  numBytes += cIf_init(&cIf_OkwdSzDD, false);
  numBytes += cDelay_init(this, &cDelay_B4BVz9mB, 10.0f);
  numBytes += cIf_init(&cIf_8Aj4p442, false);
  numBytes += cIf_init(&cIf_qzQ0eRjR, false);
  numBytes += cDelay_init(this, &cDelay_D1RUCXzt, 10.0f);
  numBytes += sVarf_init(&sVarf_PQ81CEKN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BYY5UH8x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_AcClPwmk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vMer91M8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Tys4FHVn, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZKvaBAy8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_OrOW2xz8, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cNadffxp, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_0QlRTjto, 0.0f);
  numBytes += cSlice_init(&cSlice_5duthp3f, 1, -1);
  numBytes += cVar_init_f(&cVar_dCjjf22c, 1.0f);
  numBytes += cSlice_init(&cSlice_GB2gfwOb, 1, -1);
  numBytes += cVar_init_f(&cVar_v1NcJ2xK, 0.0f);
  numBytes += cSlice_init(&cSlice_8h1wVNrg, 1, -1);
  numBytes += cVar_init_f(&cVar_HwxfjEpU, 512.0f);
  numBytes += cSlice_init(&cSlice_b2GMn6Kf, 1, -1);
  numBytes += cVar_init_f(&cVar_sYIMqyLJ, 1.0f);
  numBytes += cSlice_init(&cSlice_y7sIqsMG, 1, -1);
  numBytes += cVar_init_f(&cVar_vhmyuMDW, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Bq4YylO2, 20.0f);
  numBytes += cVar_init_f(&cVar_4DXSkRZH, 0.0f);
  numBytes += cIf_init(&cIf_pgMppPYg, false);
  numBytes += cIf_init(&cIf_Hke4QqX2, false);
  numBytes += cBinop_init(&cBinop_ldrZ9rsG, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_YOH4ygUq, 1, -1);
  numBytes += cVar_init_f(&cVar_S5fobO4Z, 0.0f);
  numBytes += sVarf_init(&sVarf_EL39LGDp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_nH1s7gdx, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Rc3aHnre, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fcAvfX7E, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_qiJx1YSN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_fwF1hmOs, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_27NkG81R, 0.0f);
  numBytes += cVar_init_f(&cVar_6O8UplwA, 0.0f);
  numBytes += cIf_init(&cIf_bp6tdwH4, false);
  numBytes += cIf_init(&cIf_x1754XSx, false);
  numBytes += cDelay_init(this, &cDelay_qJNtfjoF, 10.0f);
  numBytes += cIf_init(&cIf_MtH6xhcR, false);
  numBytes += cIf_init(&cIf_o1Vhu9s4, false);
  numBytes += cDelay_init(this, &cDelay_nTZVHrLb, 10.0f);
  numBytes += cIf_init(&cIf_oOFNrrWu, false);
  numBytes += cIf_init(&cIf_oh6PTv3O, false);
  numBytes += cDelay_init(this, &cDelay_gRi275Vy, 10.0f);
  numBytes += cIf_init(&cIf_UYhljyAD, false);
  numBytes += cIf_init(&cIf_vyTbcFFo, false);
  numBytes += cDelay_init(this, &cDelay_Lhwnyw2K, 10.0f);
  numBytes += cIf_init(&cIf_aCTYZ0vn, false);
  numBytes += cIf_init(&cIf_U8PRc35n, false);
  numBytes += cDelay_init(this, &cDelay_ixrJbtHy, 10.0f);
  numBytes += cIf_init(&cIf_ahpO7jA6, false);
  numBytes += cIf_init(&cIf_TT3sdx1Z, false);
  numBytes += cDelay_init(this, &cDelay_xPSQm3vf, 10.0f);
  numBytes += cIf_init(&cIf_EMvHVn1h, false);
  numBytes += cIf_init(&cIf_BeZe4l6w, false);
  numBytes += cDelay_init(this, &cDelay_YnPdqH0D, 10.0f);
  numBytes += cIf_init(&cIf_3FSXSRbc, false);
  numBytes += cIf_init(&cIf_mtjVidms, false);
  numBytes += cDelay_init(this, &cDelay_ciEiaseY, 10.0f);
  numBytes += cIf_init(&cIf_HkUFs1r7, false);
  numBytes += cIf_init(&cIf_zbeMvV1m, false);
  numBytes += cDelay_init(this, &cDelay_ih47P2IO, 10.0f);
  numBytes += cIf_init(&cIf_v0qzJq9o, false);
  numBytes += cIf_init(&cIf_XsSc8Rp6, false);
  numBytes += cDelay_init(this, &cDelay_8pHJg0Z0, 10.0f);
  numBytes += cIf_init(&cIf_qrQYYx2g, false);
  numBytes += cIf_init(&cIf_IW8cJSTS, false);
  numBytes += cDelay_init(this, &cDelay_FiWhOrjn, 10.0f);
  numBytes += cIf_init(&cIf_ZzzDYn41, false);
  numBytes += cIf_init(&cIf_DXPQwzA1, false);
  numBytes += cDelay_init(this, &cDelay_BsqrGtXY, 10.0f);
  numBytes += sVarf_init(&sVarf_3x0Xsvww, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZMHXriKY, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_mZM53hdw, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_T6ct2mvE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_gekzwsjk, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wYU2c7XG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_sn0Xj6x2, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BlWG8Y9a, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_PwucdF61, 0.0f);
  numBytes += cSlice_init(&cSlice_651BsW8R, 1, -1);
  numBytes += cVar_init_f(&cVar_yTME66iv, 1.0f);
  numBytes += cSlice_init(&cSlice_ENiVk5Dn, 1, -1);
  numBytes += cVar_init_f(&cVar_3nK0NnTV, 0.0f);
  numBytes += cSlice_init(&cSlice_GhwTfh7M, 1, -1);
  numBytes += cVar_init_f(&cVar_eMhmVhWY, 512.0f);
  numBytes += cSlice_init(&cSlice_GorRxs9K, 1, -1);
  numBytes += cVar_init_f(&cVar_OGLSHQsE, 1.0f);
  numBytes += cSlice_init(&cSlice_zUEhzqAt, 1, -1);
  numBytes += cVar_init_f(&cVar_EVRkzr0V, 1.0f);
  numBytes += cDelay_init(this, &cDelay_25CGGoQR, 20.0f);
  numBytes += cVar_init_f(&cVar_CFcCCsoq, 0.0f);
  numBytes += cIf_init(&cIf_OatQumRP, false);
  numBytes += cIf_init(&cIf_Wk1hJUfY, false);
  numBytes += cBinop_init(&cBinop_vVaBnZVb, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_rTSDh0el, 1, -1);
  numBytes += cVar_init_f(&cVar_9YSxDuk8, 0.0f);
  numBytes += sVarf_init(&sVarf_ceOwrgm6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MlHiJwIG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_byLecGF9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_uc5hb9ge, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_S5QLqQrU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_dzP7yIyW, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_eGEbyY3J, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_f8qhpCoh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1PWQLeu9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_r5gL73B1, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_gtgzGgnA, 0.0f);
  numBytes += cVar_init_f(&cVar_UqRHDobZ, 0.0f);
  numBytes += cVar_init_f(&cVar_tt107kmR, 0.0f);
  numBytes += cVar_init_f(&cVar_J8bNZ8mH, 0.0f);
  numBytes += cVar_init_f(&cVar_B0fzY4Mz, 0.0f);
  numBytes += cVar_init_f(&cVar_3s77ndu3, 1.0f);
  numBytes += cSlice_init(&cSlice_n4rt1Pfz, 1, -1);
  numBytes += cVar_init_f(&cVar_vL5ey5TI, 0.5f);
  numBytes += cVar_init_f(&cVar_OqkApdR3, 0.0f);
  numBytes += cVar_init_f(&cVar_IOeEIrb1, 0.0f);
  numBytes += cIf_init(&cIf_d1WmQ8iC, false);
  numBytes += cIf_init(&cIf_EYM6QwAW, false);
  numBytes += cDelay_init(this, &cDelay_G87vgUkZ, 10.0f);
  numBytes += cIf_init(&cIf_RDfHw8op, false);
  numBytes += cIf_init(&cIf_oHfXoI8Q, false);
  numBytes += cDelay_init(this, &cDelay_fmlFOB5c, 10.0f);
  numBytes += cIf_init(&cIf_uw5Tuh3B, false);
  numBytes += cIf_init(&cIf_gTqkifPz, false);
  numBytes += cDelay_init(this, &cDelay_vQekSCaM, 10.0f);
  numBytes += cIf_init(&cIf_vWFz0485, false);
  numBytes += cIf_init(&cIf_xIyCae3j, false);
  numBytes += cDelay_init(this, &cDelay_YfTALWCr, 10.0f);
  numBytes += cIf_init(&cIf_SECZQnUu, false);
  numBytes += cIf_init(&cIf_niJPg0ke, false);
  numBytes += cDelay_init(this, &cDelay_VgzkNS0W, 10.0f);
  numBytes += cIf_init(&cIf_YBNultCO, false);
  numBytes += cIf_init(&cIf_N4S4fqBa, false);
  numBytes += cDelay_init(this, &cDelay_rUlhusZB, 10.0f);
  numBytes += cIf_init(&cIf_QZmLUAxf, false);
  numBytes += cIf_init(&cIf_agvTTpBo, false);
  numBytes += cDelay_init(this, &cDelay_DnyapFOk, 10.0f);
  numBytes += cIf_init(&cIf_qyh9LH8i, false);
  numBytes += cIf_init(&cIf_Jp0ywQ0i, false);
  numBytes += cDelay_init(this, &cDelay_YU3aguP1, 10.0f);
  numBytes += cIf_init(&cIf_CXv7Csit, false);
  numBytes += cIf_init(&cIf_vbCzD0F9, false);
  numBytes += cDelay_init(this, &cDelay_6fQeVQUy, 10.0f);
  numBytes += cIf_init(&cIf_xl3cyRdl, false);
  numBytes += cIf_init(&cIf_LD27SA3H, false);
  numBytes += cDelay_init(this, &cDelay_cszElQFt, 10.0f);
  numBytes += cIf_init(&cIf_9sHmkl3I, false);
  numBytes += cIf_init(&cIf_G9N2R52V, false);
  numBytes += cDelay_init(this, &cDelay_ptpkT8VM, 10.0f);
  numBytes += cIf_init(&cIf_fauxkW1l, false);
  numBytes += cIf_init(&cIf_dp9p6vgG, false);
  numBytes += cDelay_init(this, &cDelay_27iGHhqD, 10.0f);
  numBytes += sVarf_init(&sVarf_2XiDijXc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_MoUCEgBA, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_w6zqKVKp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ced5X4v1, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Lp695ivl, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Iql0vLIy, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_YlVC8R6I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_DrZxmKbN, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_87s3rjuk, 0.0f);
  numBytes += cSlice_init(&cSlice_7HcZdRYS, 1, -1);
  numBytes += cVar_init_f(&cVar_2l0hewhX, 1.0f);
  numBytes += cSlice_init(&cSlice_vCJiiYM7, 1, -1);
  numBytes += cVar_init_f(&cVar_1PcKOm4d, 0.0f);
  numBytes += cSlice_init(&cSlice_bKGeb7gJ, 1, -1);
  numBytes += cVar_init_f(&cVar_hpRgXWjw, 512.0f);
  numBytes += cSlice_init(&cSlice_v8gTo90r, 1, -1);
  numBytes += cVar_init_f(&cVar_w98lOufV, 1.0f);
  numBytes += cSlice_init(&cSlice_Zr94faKq, 1, -1);
  numBytes += cVar_init_f(&cVar_Rp716uJV, 1.0f);
  numBytes += cDelay_init(this, &cDelay_G0xF1ZvG, 20.0f);
  numBytes += cVar_init_f(&cVar_vG77nfQs, 0.0f);
  numBytes += cIf_init(&cIf_i4quO4mf, false);
  numBytes += cIf_init(&cIf_YP2fhrIJ, false);
  numBytes += cBinop_init(&cBinop_GfEhuX7b, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_wBzxDJyX, 1, -1);
  numBytes += cVar_init_f(&cVar_yGdqV43V, 0.0f);
  numBytes += sVarf_init(&sVarf_073r3Orr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_e820nxqE, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HHobGLy0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4vbUBxbB, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bSIxSwBC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iC5cqjfX, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_ct1PlHLv, 0.0f);
  numBytes += cVar_init_f(&cVar_dAI301q4, 0.0f);
  numBytes += cIf_init(&cIf_4yyyYBpM, false);
  numBytes += cIf_init(&cIf_SMbSmujz, false);
  numBytes += cDelay_init(this, &cDelay_bMDqhBap, 10.0f);
  numBytes += cIf_init(&cIf_9BhaJap6, false);
  numBytes += cIf_init(&cIf_Jpvq0QFT, false);
  numBytes += cDelay_init(this, &cDelay_b889ANYT, 10.0f);
  numBytes += cIf_init(&cIf_ctWIxvkZ, false);
  numBytes += cIf_init(&cIf_vGY4TImD, false);
  numBytes += cDelay_init(this, &cDelay_ss0gUpSR, 10.0f);
  numBytes += cIf_init(&cIf_jdN7NNHt, false);
  numBytes += cIf_init(&cIf_CsoJ8MMV, false);
  numBytes += cDelay_init(this, &cDelay_mGo2rfX5, 10.0f);
  numBytes += cIf_init(&cIf_RW7e0Y5W, false);
  numBytes += cIf_init(&cIf_fKoLHLC4, false);
  numBytes += cDelay_init(this, &cDelay_0sI8c5lv, 10.0f);
  numBytes += cIf_init(&cIf_xDhNsBrj, false);
  numBytes += cIf_init(&cIf_5lN9meyw, false);
  numBytes += cDelay_init(this, &cDelay_Rnwy9Xdh, 10.0f);
  numBytes += cIf_init(&cIf_otYqyaTM, false);
  numBytes += cIf_init(&cIf_wrTBJ62U, false);
  numBytes += cDelay_init(this, &cDelay_LQUtb0Kz, 10.0f);
  numBytes += cIf_init(&cIf_FjOilOoX, false);
  numBytes += cIf_init(&cIf_Jm4Rl3b7, false);
  numBytes += cDelay_init(this, &cDelay_jY3uiEvv, 10.0f);
  numBytes += cIf_init(&cIf_k3OIqH7X, false);
  numBytes += cIf_init(&cIf_AMwN3tME, false);
  numBytes += cDelay_init(this, &cDelay_FR2CEYio, 10.0f);
  numBytes += cIf_init(&cIf_GjTIPuNv, false);
  numBytes += cIf_init(&cIf_M1FuGUsM, false);
  numBytes += cDelay_init(this, &cDelay_67i5e18Q, 10.0f);
  numBytes += cIf_init(&cIf_3ExpUGu9, false);
  numBytes += cIf_init(&cIf_1oAcPXRq, false);
  numBytes += cDelay_init(this, &cDelay_B2krxHXI, 10.0f);
  numBytes += cIf_init(&cIf_2Kb6dEtQ, false);
  numBytes += cIf_init(&cIf_64MJqVbY, false);
  numBytes += cDelay_init(this, &cDelay_bMH0LHYf, 10.0f);
  numBytes += sVarf_init(&sVarf_hKGxsPTG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_BiVv8HHq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_1Azf7Mrq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FsNxEoUM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_xCHKr8lg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_IBnG941I, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4R8JAkCz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_2ebo6TTP, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_JJkreiTf, 0.0f);
  numBytes += cSlice_init(&cSlice_ERXa2bJF, 1, -1);
  numBytes += cVar_init_f(&cVar_od1OwaME, 1.0f);
  numBytes += cSlice_init(&cSlice_0qHDLtrF, 1, -1);
  numBytes += cVar_init_f(&cVar_ZVQfhjrS, 0.0f);
  numBytes += cSlice_init(&cSlice_4h6IWqnl, 1, -1);
  numBytes += cVar_init_f(&cVar_JbhBOW5r, 512.0f);
  numBytes += cSlice_init(&cSlice_pKh7VVQY, 1, -1);
  numBytes += cVar_init_f(&cVar_Bfj9wGP1, 1.0f);
  numBytes += cSlice_init(&cSlice_q71S3QrA, 1, -1);
  numBytes += cVar_init_f(&cVar_YSy0327d, 1.0f);
  numBytes += cDelay_init(this, &cDelay_Kj2LutTn, 20.0f);
  numBytes += cVar_init_f(&cVar_1mhhbBOP, 0.0f);
  numBytes += cIf_init(&cIf_SwV6Xnj2, false);
  numBytes += cIf_init(&cIf_ELY9e30A, false);
  numBytes += cBinop_init(&cBinop_KKAk0kUi, 0.0f); // __sub
  numBytes += cSlice_init(&cSlice_VOZqoH2f, 1, -1);
  numBytes += cVar_init_f(&cVar_SCaqXKRd, 0.0f);
  numBytes += sVarf_init(&sVarf_N0Akvobr, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vuTnGb2l, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_68CWNm3x, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_cZManktZ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_zSmVpUBv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_FzhRXwVz, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_0hOGzVKF, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JJXFAwrs, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_4gesI4YJ, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZEhayyGz, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_F2JUtxO0, 0.0f);
  numBytes += cVar_init_f(&cVar_Gg1N0RoL, 0.0f);
  numBytes += cVar_init_f(&cVar_ZscTOtxg, 0.0f);
  numBytes += sVarf_init(&sVarf_oh7daJb9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_KJpPbryp, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Zm2kcFzT, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_yYu6H3uU, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_HDOTMY0t, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_ZHMLXhTC, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vgma3qb6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_syXf4B0Q, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5MMUiliv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_RxSz7aiq, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_kLi9NjSN, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_5brH23XQ, 0.0f, 0.0f, false);
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_M3NGLR::~Heavy_WSTD_M3NGLR() {
  sEnv_free(&sEnv_SzU1Mg5w);
  sEnv_free(&sEnv_r1AUVe7v);
  sEnv_free(&sEnv_kksJiUaw);
  sEnv_free(&sEnv_ZjkUFwqk);
  sEnv_free(&sEnv_YC3GgUsK);
  sEnv_free(&sEnv_myiR8KhG);
  sEnv_free(&sEnv_HNxBPYug);
  sEnv_free(&sEnv_DzKQc4mD);
  sEnv_free(&sEnv_YAbtSPPU);
  sEnv_free(&sEnv_ILqxuXLg);
  sEnv_free(&sEnv_dnYJh9KV);
  sEnv_free(&sEnv_jilBNwLN);
}

HvTable *Heavy_WSTD_M3NGLR::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_M3NGLR::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_03kgjAGq_sendMessage);
      break;
    }
    case 0xCFF7A234: { // High_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ZKzQYbp2_sendMessage);
      break;
    }
    case 0x12EF45B9: { // High_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PAI1zk1l_sendMessage);
      break;
    }
    case 0xC05E9A15: { // High_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ySwdauha_sendMessage);
      break;
    }
    case 0x8E596A67: { // High_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_PILjxj6R_sendMessage);
      break;
    }
    case 0xAC5FA57F: { // High_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4PrqtyvK_sendMessage);
      break;
    }
    case 0x585E4A54: { // High_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gtI7xczI_sendMessage);
      break;
    }
    case 0x14A9747F: { // High_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zS1Yh3sI_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_H6Vz713m_sendMessage);
      break;
    }
    case 0xEBDB0C5E: { // Low_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bsluRFeX_sendMessage);
      break;
    }
    case 0xF974E926: { // Low_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_aPtwIGci_sendMessage);
      break;
    }
    case 0xBB56D13C: { // Low_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_I55FWOuw_sendMessage);
      break;
    }
    case 0xB4EFBAC1: { // Low_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_J2WCeMQt_sendMessage);
      break;
    }
    case 0x91FEF7A: { // Low_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_QR2c8u53_sendMessage);
      break;
    }
    case 0x1665AEE9: { // Low_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_v7ROWZu7_sendMessage);
      break;
    }
    case 0x860CA1D9: { // Low_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MXUuQtLB_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wQWWqu5Y_sendMessage);
      break;
    }
    case 0xEA9DEF12: { // Mid_Crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BwNKf0cj_sendMessage);
      break;
    }
    case 0xDBF6FE0A: { // Mid_Fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5Q1DBnSF_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BWr4Bhkr_sendMessage);
      break;
    }
    case 0x23F5E910: { // Mid_Gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_et2HKoJq_sendMessage);
      break;
    }
    case 0x33C126B6: { // Mid_Lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P9jUIBmv_sendMessage);
      break;
    }
    case 0x676FE235: { // Mid_Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_FgIWcSwV_sendMessage);
      break;
    }
    case 0x64B1268F: { // Mid_Smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vxcFgJZj_sendMessage);
      break;
    }
    case 0xA91022F8: { // Mid_Sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_q95CCi5Q_sendMessage);
      break;
    }
    case 0x1AFCE6EB: { // 1025-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_F7IKarLw_sendMessage);
      break;
    }
    case 0xD8B5B1DB: { // 1025-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ocn5XkjC_sendMessage);
      break;
    }
    case 0x3794F656: { // 1025-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MbsV1Hv1_sendMessage);
      break;
    }
    case 0x94AE0ED9: { // 1025-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_z96SEoXf_sendMessage);
      break;
    }
    case 0xCC4DB41E: { // 1025-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_2RciBVR6_sendMessage);
      break;
    }
    case 0xAFE114F6: { // 1084-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_MecXVwjQ_sendMessage);
      break;
    }
    case 0x98647BAD: { // 1084-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5oi9trp7_sendMessage);
      break;
    }
    case 0xA4661944: { // 1084-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Sgh3UyTI_sendMessage);
      break;
    }
    case 0x505CED7B: { // 1125-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Tozsa6gb_sendMessage);
      break;
    }
    case 0x82611A6: { // 1125-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hat5UxDB_sendMessage);
      break;
    }
    case 0x1B990984: { // 1125-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_YOG0aCDb_sendMessage);
      break;
    }
    case 0x5F0AFAC5: { // 1166-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WeYFFl5J_sendMessage);
      break;
    }
    case 0x25349984: { // 1166-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JCxtIqmu_sendMessage);
      break;
    }
    case 0x8258EF5C: { // 1166-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_rPnGoAOl_sendMessage);
      break;
    }
    case 0xBC1DF870: { // 1181-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iZbxolyR_sendMessage);
      break;
    }
    case 0x9A5A2ED: { // 1181-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xXx3nCly_sendMessage);
      break;
    }
    case 0x6714DCEB: { // 1181-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0MenaF0f_sendMessage);
      break;
    }
    case 0xE583CFFE: { // 1181-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_cbag8ikB_sendMessage);
      break;
    }
    case 0xA6D36AFA: { // 1181-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qlYy8Qs8_sendMessage);
      break;
    }
    case 0x2AD225: { // 1240-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_NaSUQiIh_sendMessage);
      break;
    }
    case 0x7DD55B03: { // 1240-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_IheAKCyK_sendMessage);
      break;
    }
    case 0xCF4D157B: { // 1240-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hRMSv4lO_sendMessage);
      break;
    }
    case 0x4DF9D195: { // 1281-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xKCW8ttE_sendMessage);
      break;
    }
    case 0x58CB5D1B: { // 1281-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_CGV71T41_sendMessage);
      break;
    }
    case 0xE926ADAA: { // 1281-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_82FIMiGx_sendMessage);
      break;
    }
    case 0x839669AF: { // 1322-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qx1TG3pE_sendMessage);
      break;
    }
    case 0x89AA8991: { // 1322-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lPtc1f28_sendMessage);
      break;
    }
    case 0xC43C6A92: { // 1322-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_WgV3T3a9_sendMessage);
      break;
    }
    case 0x44C46A9A: { // 1345-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_jq610ngy_sendMessage);
      break;
    }
    case 0x5B005CAA: { // 1352-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OdhmSI4S_sendMessage);
      break;
    }
    case 0xBBD23460: { // 1352-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yswX0X1O_sendMessage);
      break;
    }
    case 0x23884B06: { // 1352-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0SLJF6OU_sendMessage);
      break;
    }
    case 0x91BE5650: { // 1352-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SGEMSXmw_sendMessage);
      break;
    }
    case 0x51E8B18D: { // 1352-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3XhBrWas_sendMessage);
      break;
    }
    case 0x2CAD1402: { // 1352-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qIdnTxrl_sendMessage);
      break;
    }
    case 0x8CE949DD: { // 1470-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_N7BQQldX_sendMessage);
      break;
    }
    case 0x1A98A8C5: { // 1470-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_gqODNkav_sendMessage);
      break;
    }
    case 0x4211FC92: { // 1470-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_05LfDfJX_sendMessage);
      break;
    }
    case 0x86F6710B: { // 1470-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Mfy5ktZO_sendMessage);
      break;
    }
    case 0x102FAA7E: { // 1470-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_91S31Xcc_sendMessage);
      break;
    }
    case 0x1A325FAC: { // 1470-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ca30o5aF_sendMessage);
      break;
    }
    case 0x5FF45DD7: { // 1602-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_w0gOPJeG_sendMessage);
      break;
    }
    case 0xA63D49D8: { // 1609-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o47azyYh_sendMessage);
      break;
    }
    case 0xFB1C4FF4: { // 1609-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0CnjV5es_sendMessage);
      break;
    }
    case 0x2D7D2212: { // 1609-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EfoRBQJp_sendMessage);
      break;
    }
    case 0xB4610071: { // 1609-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UT3t97H0_sendMessage);
      break;
    }
    case 0x47BBE59E: { // 1609-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nRBUgCin_sendMessage);
      break;
    }
    case 0xD51403EB: { // 1609-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EZ9IZk07_sendMessage);
      break;
    }
    case 0x559ECA90: { // 1727-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_lER2Hgdo_sendMessage);
      break;
    }
    case 0xB4F19FB9: { // 1727-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zlkrlUsY_sendMessage);
      break;
    }
    case 0x7CE4DF88: { // 1727-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4KLDXSaJ_sendMessage);
      break;
    }
    case 0x9FD7A64D: { // 1727-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_epbM1BCJ_sendMessage);
      break;
    }
    case 0x52C25AFE: { // 1727-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Xi1JeOfi_sendMessage);
      break;
    }
    case 0x801C27A5: { // 1727-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_or9HCeyF_sendMessage);
      break;
    }
    case 0xE5875B65: { // 1859-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_7GJu8k6l_sendMessage);
      break;
    }
    case 0x40898D28: { // 1866-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_dREye3mv_sendMessage);
      break;
    }
    case 0x9D616407: { // 1866-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_nl28EsCH_sendMessage);
      break;
    }
    case 0xE8DBDB0: { // 1866-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_EpCrp4U5_sendMessage);
      break;
    }
    case 0xD770731A: { // 1866-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_E6TOGwJU_sendMessage);
      break;
    }
    case 0x124CD18B: { // 1866-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_P20tFaNQ_sendMessage);
      break;
    }
    case 0x4017FCCD: { // 1866-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4A7w9lRs_sendMessage);
      break;
    }
    case 0x1B1DD5FB: { // 1984-crshr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_INLN09Vu_sendMessage);
      break;
    }
    case 0xA478FA4C: { // 1984-fldr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_W3baB6wG_sendMessage);
      break;
    }
    case 0x97EB3671: { // 1984-gain
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_0VhwiLjE_sendMessage);
      break;
    }
    case 0xF3FECDEE: { // 1984-lmtr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zfNhCLUy_sendMessage);
      break;
    }
    case 0x9558C335: { // 1984-smthr
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_UJ59Bu7P_sendMessage);
      break;
    }
    case 0x4131288C: { // 1984-sqnc
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_A0mbZtMg_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_c2q5pVtI_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_M3NGLR::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "High_Crshr";
        info->hash = 0xCFF7A234;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 2: {
        info->name = "High_Fldr";
        info->hash = 0x12EF45B9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 3: {
        info->name = "High_Gain";
        info->hash = 0xC05E9A15;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "High_Lmtr";
        info->hash = 0x8E596A67;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 5: {
        info->name = "High_Mix";
        info->hash = 0xAC5FA57F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 6: {
        info->name = "High_Smthr";
        info->hash = 0x585E4A54;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 7: {
        info->name = "High_Sqnc";
        info->hash = 0x14A9747F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 8: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 9: {
        info->name = "Low_Crshr";
        info->hash = 0xEBDB0C5E;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 10: {
        info->name = "Low_Fldr";
        info->hash = 0xF974E926;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 11: {
        info->name = "Low_Gain";
        info->hash = 0xBB56D13C;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 12: {
        info->name = "Low_Lmtr";
        info->hash = 0xB4EFBAC1;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 13: {
        info->name = "Low_Mix";
        info->hash = 0x91FEF7A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 14: {
        info->name = "Low_Smthr";
        info->hash = 0x1665AEE9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 15: {
        info->name = "Low_Sqnc";
        info->hash = 0x860CA1D9;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 16: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 17: {
        info->name = "Mid_Crshr";
        info->hash = 0xEA9DEF12;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 2.0f;
        info->maxVal = 512.0f;
        info->defaultVal = 512.0f;
        break;
      }
      case 18: {
        info->name = "Mid_Fldr";
        info->hash = 0xDBF6FE0A;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 19: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      case 20: {
        info->name = "Mid_Gain";
        info->hash = 0x23F5E910;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -25.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 21: {
        info->name = "Mid_Lmtr";
        info->hash = 0x33C126B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 1.0f;
        break;
      }
      case 22: {
        info->name = "Mid_Mix";
        info->hash = 0x676FE235;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 23: {
        info->name = "Mid_Smthr";
        info->hash = 0x64B1268F;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 1.0f;
        info->maxVal = 13.37f;
        info->defaultVal = 1.0f;
        break;
      }
      case 24: {
        info->name = "Mid_Sqnc";
        info->hash = 0xA91022F8;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 5.0f;
        info->defaultVal = 0.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 25;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_M3NGLR::cVar_UkvQXLun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6GjctN8b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ANoxoS0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kfMCPTbY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_t2srMOuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IOX3N6Rw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_UNm64l6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jUyHiKIU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_hrxvJqeQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2TwmBkBu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_aU3F5Jd1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MkSmtmja_sendMessage);
  cMsg_KvU59mpg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_MkSmtmja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aU3F5Jd1, 1, m, &cVar_aU3F5Jd1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q0SjDn7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gpgy4UtF_sendMessage(_c, 0, m);
  cMsg_WCZiDKA9_sendMessage(_c, 0, m);
  cMsg_K7T7FO4t_sendMessage(_c, 0, m);
  cMsg_4bsFDn0v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_x401s5wK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MqDFcBk2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dfIeFrSo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uVSEbXLW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0VOdPL9A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vxLkark2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ql6eD9bC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nAPBExwT_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gwPVRM18_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G8ZloQgA_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6ObidbA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MpmRkBkp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_l2NG6Akl, 0, m, &cSlice_l2NG6Akl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_heJkpFXU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_l2NG6Akl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DsJ4fQXG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DsJ4fQXG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_OTZ2P7km_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DsJ4fQXG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_DsJ4fQXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MbsV1Hv1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_H9Gi5V0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bCbxqnsT_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_4MrpP7WS, 0, m, &cIf_4MrpP7WS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_4MrpP7WS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_JmojBYyS_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zkDCQYTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_bGb1Psri_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_NxoRu3TD_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_NHf9A39C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_CpymegU0, HV_BINOP_POW, 0, m, &cBinop_CpymegU0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CpymegU0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QqFZ7lwf, 0, m, &cIf_QqFZ7lwf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R2cmajcl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_VxS0fiS8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dUCHY1Rd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkDCQYTV, 0, m, &cIf_zkDCQYTV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eTNHxohb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_CA2Nscnx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CA2Nscnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zkDCQYTV, 1, m, &cIf_zkDCQYTV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NxoRu3TD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_R2cmajcl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bGb1Psri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QqFZ7lwf, 0, m, &cIf_QqFZ7lwf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VxS0fiS8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CpymegU0, HV_BINOP_POW, 1, m, &cBinop_CpymegU0_sendMessage);
  cMsg_NHf9A39C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_QqFZ7lwf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E1idNT36_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_bCbxqnsT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4MrpP7WS, 1, m, &cIf_4MrpP7WS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JmojBYyS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dJhPvO4X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_KdwNhaiQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_t6AWuIiL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eTNHxohb_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dUCHY1Rd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4eejPYHH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QqFZ7lwf, 1, m, &cIf_QqFZ7lwf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YSmmOTAk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_97f0K8CS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_97f0K8CS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_E1idNT36_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M1DvRGGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_t6AWuIiL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dJhPvO4X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YSmmOTAk, HV_BINOP_EQ, 1, m, &cBinop_YSmmOTAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KdwNhaiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4eejPYHH, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4eejPYHH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ppibXfJ9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H9Gi5V0f, 0, m, &cVar_H9Gi5V0f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8dgexT31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4eejPYHH, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4eejPYHH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jMT8wgVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YSmmOTAk, HV_BINOP_EQ, 0, m, &cBinop_YSmmOTAk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_F8MMBkyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M1DvRGGv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WMx4uUvf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_bntKZCwD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_wQq3aRhv, 0, m, &cIf_wQq3aRhv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_wQq3aRhv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_Fms6Sqqp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Qet4TjMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_QlfxgerD_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_M9rlk9Hb_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_PoDtAEtD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fO6FGosE, HV_BINOP_POW, 0, m, &cBinop_fO6FGosE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fO6FGosE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YPdAtwER, 0, m, &cIf_YPdAtwER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hq79m4PR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_5MzYmDTG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qFsZvHZo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_6MJzA5C6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IZV5gviT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qet4TjMQ, 0, m, &cIf_Qet4TjMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6MJzA5C6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Qet4TjMQ, 1, m, &cIf_Qet4TjMQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M9rlk9Hb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_hq79m4PR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QlfxgerD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_YPdAtwER, 0, m, &cIf_YPdAtwER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5MzYmDTG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fO6FGosE, HV_BINOP_POW, 1, m, &cBinop_fO6FGosE_sendMessage);
  cMsg_PoDtAEtD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_YPdAtwER_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wAJsBdIo_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YVz1S7JB_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_bntKZCwD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wQq3aRhv, 1, m, &cIf_wQq3aRhv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Fms6Sqqp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mNukIoOe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CLSrAkx9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wAXBd42x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qFsZvHZo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IZV5gviT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bU7bCBBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YPdAtwER, 1, m, &cIf_YPdAtwER_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_h7mdOOjI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fz9CUs2R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fz9CUs2R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wAJsBdIo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YVz1S7JB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qT2BZve1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_wAXBd42x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mNukIoOe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7mdOOjI, HV_BINOP_EQ, 1, m, &cBinop_h7mdOOjI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CLSrAkx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bU7bCBBw, HV_BINOP_GREATER_THAN, 1, m, &cBinop_bU7bCBBw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AA6JqhS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qT2BZve1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GvDS1hJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bU7bCBBw, HV_BINOP_GREATER_THAN, 0, m, &cBinop_bU7bCBBw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FxSk2Ffv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WMx4uUvf, 0, m, &cVar_WMx4uUvf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JgFlA5G4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7mdOOjI, HV_BINOP_EQ, 0, m, &cBinop_h7mdOOjI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_SDIKrpL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ixe60G8N_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YIU2HRGe, 0, m, &cIf_YIU2HRGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_YIU2HRGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_YPUJjYUn_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zNjhkVKK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Xmhe4nlV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_MjFDyy9z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_B4kWrBnm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXSvyfAi, HV_BINOP_POW, 0, m, &cBinop_jXSvyfAi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jXSvyfAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dNRxj8mv, 0, m, &cIf_dNRxj8mv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EnpSPOjZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Wxu43tZe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JHRtpS9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_LORu7oZc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BjPlgp2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNjhkVKK, 0, m, &cIf_zNjhkVKK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LORu7oZc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zNjhkVKK, 1, m, &cIf_zNjhkVKK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MjFDyy9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_EnpSPOjZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Xmhe4nlV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_dNRxj8mv, 0, m, &cIf_dNRxj8mv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Wxu43tZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jXSvyfAi, HV_BINOP_POW, 1, m, &cBinop_jXSvyfAi_sendMessage);
  cMsg_B4kWrBnm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_dNRxj8mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OF9dBCen_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_ixe60G8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YIU2HRGe, 1, m, &cIf_YIU2HRGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YPUJjYUn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cKMfTPrv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BOwskDLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_004KryF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JHRtpS9E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BjPlgp2J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D5agX6vB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dNRxj8mv, 1, m, &cIf_dNRxj8mv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GcahQAuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HF4NDQD6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HF4NDQD6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_OF9dBCen_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bDBSpQh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_004KryF4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BOwskDLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D5agX6vB, HV_BINOP_GREATER_THAN, 1, m, &cBinop_D5agX6vB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cKMfTPrv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GcahQAuU, HV_BINOP_EQ, 1, m, &cBinop_GcahQAuU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LV4FwSja_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_D5agX6vB, HV_BINOP_GREATER_THAN, 0, m, &cBinop_D5agX6vB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FwZr2ReT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bDBSpQh0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_2cH8YKe3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GcahQAuU, HV_BINOP_EQ, 0, m, &cBinop_GcahQAuU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EHPPrcrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SDIKrpL5, 0, m, &cVar_SDIKrpL5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_E4aVmpqM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vBmYPb5C_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qwFdCkyp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XCJoRbEH, 0, m, &cSlice_XCJoRbEH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MhMJm3YQ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_XCJoRbEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_aE4xao4I_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_aE4xao4I_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_pl2tJWT2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_aE4xao4I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_aE4xao4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_F7IKarLw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_MhMJm3YQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GDlw24Ih, 0, m, &cSlice_GDlw24Ih_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MpmRkBkp_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GDlw24Ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_w4jU48S6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_w4jU48S6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_bMHruCBO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_w4jU48S6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_w4jU48S6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_2RciBVR6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_heJkpFXU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_us6APVtJ, 0, m, &cSlice_us6APVtJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ek3aKlq5_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_us6APVtJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_V702H2Zu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_V702H2Zu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3OrgEmYu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_V702H2Zu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_V702H2Zu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ocn5XkjC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ek3aKlq5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_c5UOmdMJ, 0, m, &cSlice_c5UOmdMJ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_c5UOmdMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rd80wo5J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rd80wo5J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Sgsf3ZbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rd80wo5J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rd80wo5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_z96SEoXf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ulxBqZh6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZOeBbbVZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_rWmGuPys_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hGf2FpqY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_mTAIBBQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9Xgar7jj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pbfitIGd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_MKJ09TSf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ato5KzKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hvgeg9sF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KpjeAZEh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_hMi3Cb1o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_hMi3Cb1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NsjVv2gI, HV_BINOP_DIVIDE, 1, m, &cBinop_NsjVv2gI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tnDmG9s0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_ZIwl2bgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_iRiYSeCE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XbDsb12M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_ZIwl2bgA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iRiYSeCE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NsjVv2gI, HV_BINOP_DIVIDE, 0, m, &cBinop_NsjVv2gI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tnDmG9s0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XbDsb12M_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_NsjVv2gI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FcXNMCqN, HV_BINOP_MULTIPLY, 1, m, &cBinop_FcXNMCqN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FcXNMCqN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pGSUmjEZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oWDgzqlI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_wkfdaWSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_l3b7OxhV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_RW9MMzpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ysWP8fJ6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0vr1nCdx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Vs4ZaYmd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Vs4ZaYmd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_FcXNMCqN, HV_BINOP_MULTIPLY, 0, m, &cBinop_FcXNMCqN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_k1lvl0nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_6ti7ieQo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6ti7ieQo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1mbJ60g3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mBHohOiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2BNQBuGx, 1, m, &cVar_2BNQBuGx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_2BNQBuGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_FMmSDMDE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_eQCUgutr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aBHzMu6H, HV_BINOP_MULTIPLY, 1, m, &cBinop_aBHzMu6H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gQSWK4Ri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_eQCUgutr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_zaC2uFZL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_rEXrXnnE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rEXrXnnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ophCGZeH, HV_BINOP_MULTIPLY, 1, m, &cBinop_ophCGZeH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8cdtZhES_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n7jxP4cG, HV_BINOP_MULTIPLY, 1, m, &cBinop_n7jxP4cG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wGs7DW2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8cdtZhES_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F1KrK9G3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mtcr1NqZ, HV_BINOP_MULTIPLY, 1, m, &cBinop_Mtcr1NqZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CmhWF3vP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_WLOI1hBi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WLOI1hBi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C1sUrP1R, HV_BINOP_MULTIPLY, 1, m, &cBinop_C1sUrP1R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1hzxuc6y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QMfoQsT7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_0vr1nCdx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UDK7PcWd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_CBgs2Usn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_k1lvl0nh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oWDgzqlI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_RW9MMzpE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pGSUmjEZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_wkfdaWSa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_l3b7OxhV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Sgh3UyTI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ysWP8fJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5oi9trp7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8e8hVYbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_MecXVwjQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1mbJ60g3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_u5SWN3rF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u5SWN3rF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_goAi8gRr, HV_BINOP_MULTIPLY, 1, m, &cBinop_goAi8gRr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_goAi8gRr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Trrh7pKi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Trrh7pKi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8e8hVYbY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_FMmSDMDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_H5ykZGDs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H5ykZGDs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_czLdkghT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oUq6vnEq_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AbYxyrze_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bHq45kvk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a5uYxIyL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tYKk20L1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aBHzMu6H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ulxBqZh6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_ophCGZeH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rWmGuPys_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_n7jxP4cG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mTAIBBQT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_Mtcr1NqZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pbfitIGd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_C1sUrP1R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ato5KzKw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_nF0scpK2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CBgs2Usn, 1, m, &cVar_CBgs2Usn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nHs7zzph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1hzxuc6y, 0, m, &cVar_1hzxuc6y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a5uYxIyL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ophCGZeH, HV_BINOP_MULTIPLY, 0, m, &cBinop_ophCGZeH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oUq6vnEq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_C1sUrP1R, HV_BINOP_MULTIPLY, 0, m, &cBinop_C1sUrP1R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bHq45kvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n7jxP4cG, HV_BINOP_MULTIPLY, 0, m, &cBinop_n7jxP4cG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_czLdkghT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_tYKk20L1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aBHzMu6H, HV_BINOP_MULTIPLY, 0, m, &cBinop_aBHzMu6H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AbYxyrze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Mtcr1NqZ, HV_BINOP_MULTIPLY, 0, m, &cBinop_Mtcr1NqZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QMfoQsT7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CBgs2Usn, 0, m, &cVar_CBgs2Usn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UDK7PcWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_2BNQBuGx, 0, m, &cVar_2BNQBuGx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QLrHzsRt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WOvgOVEU, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_aj02JPc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aN7Jc6BW, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_WS52PC9Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4vFahpIw, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_itRtjaWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vBUUph3E, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_NBI7xJm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ClF8IYLH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_ClF8IYLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3xsBV9L8, HV_BINOP_DIVIDE, 1, m, &cBinop_3xsBV9L8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eEHqEHBk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_f2U8VoYV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_YWcrzAmP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NsJ2IS87_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_f2U8VoYV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YWcrzAmP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3xsBV9L8, HV_BINOP_DIVIDE, 0, m, &cBinop_3xsBV9L8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eEHqEHBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NsJ2IS87_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3xsBV9L8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PYLVcI15, HV_BINOP_MULTIPLY, 1, m, &cBinop_PYLVcI15_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PYLVcI15_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IAR8EJKp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a5COW4Ng_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_DgBdOqFI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mAAEjJ6n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_QWWHixfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_MEydtguh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_sWUv4fBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_fgVgRZdO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fgVgRZdO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PYLVcI15, HV_BINOP_MULTIPLY, 0, m, &cBinop_PYLVcI15_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CxD8FeIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_0YWAP00V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_0YWAP00V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_piOteg9w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_EerayB2D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PIl1Xc2m, HV_BINOP_MULTIPLY, 1, m, &cBinop_PIl1Xc2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NowfelGT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FsHVdiIS, 1, m, &cVar_FsHVdiIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3gGUE1bV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VDptQ2JL, HV_BINOP_MULTIPLY, 1, m, &cBinop_VDptQ2JL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jaEDejHh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1qGVJ34e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1qGVJ34e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yGYpklJN, HV_BINOP_MULTIPLY, 1, m, &cBinop_yGYpklJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FsHVdiIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bVbX9Tda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_SBA0vJMJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6s9EdsEH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_sWUv4fBo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_k8x5RQJ0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_V0H9nEB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_CxD8FeIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a5COW4Ng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_QWWHixfo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IAR8EJKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_DgBdOqFI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_mAAEjJ6n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_YOG0aCDb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_MEydtguh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hat5UxDB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_K6gpL9Yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Tozsa6gb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_piOteg9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_QS4oNn7F_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QS4oNn7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ll55qBgv, HV_BINOP_MULTIPLY, 1, m, &cBinop_Ll55qBgv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ll55qBgv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_U5rcbG3A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U5rcbG3A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_K6gpL9Yj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bVbX9Tda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_7mH7wOYi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7mH7wOYi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IfRRqSQJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MLYBkcPz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_24PNHR6P_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XYK0Qa8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gIcawS0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QLrHzsRt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_PIl1Xc2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aj02JPc4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_VDptQ2JL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WS52PC9Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_yGYpklJN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_itRtjaWr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_lTvgGQyk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SBA0vJMJ, 0, m, &cVar_SBA0vJMJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XkGZuSHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V0H9nEB0, 1, m, &cVar_V0H9nEB0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_k8x5RQJ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FsHVdiIS, 0, m, &cVar_FsHVdiIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6s9EdsEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V0H9nEB0, 0, m, &cVar_V0H9nEB0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_24PNHR6P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PIl1Xc2m, HV_BINOP_MULTIPLY, 0, m, &cBinop_PIl1Xc2m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MLYBkcPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VDptQ2JL, HV_BINOP_MULTIPLY, 0, m, &cBinop_VDptQ2JL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IfRRqSQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yGYpklJN, HV_BINOP_MULTIPLY, 0, m, &cBinop_yGYpklJN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XYK0Qa8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gIcawS0O, HV_BINOP_MULTIPLY, 0, m, &cBinop_gIcawS0O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EmrT5QBX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rMV9vtvg, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_me1vHhYJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SrI2ZcZI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7jUoEPfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ThP14mLv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sEgG8qzJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8Z45XNva, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zHmeaLYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cO5lWzbm, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4LzNRlmt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_dTEz4LIn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_dTEz4LIn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mJOjGH8p, HV_BINOP_DIVIDE, 1, m, &cBinop_mJOjGH8p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L5bxWsI4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_MP9SlRz3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Iyjw3P8b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aZgAQFUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_MP9SlRz3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Iyjw3P8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mJOjGH8p, HV_BINOP_DIVIDE, 0, m, &cBinop_mJOjGH8p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_L5bxWsI4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aZgAQFUW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mJOjGH8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUmGvZgE, HV_BINOP_MULTIPLY, 1, m, &cBinop_aUmGvZgE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aUmGvZgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iQdeBWik_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_af4ed90e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_RpYsuQ4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JaZ606Sb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_t58RJYDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0Lq8K4Wu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_nR0iiLPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_FzjQrPvl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FzjQrPvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUmGvZgE, HV_BINOP_MULTIPLY, 0, m, &cBinop_aUmGvZgE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Y2ghyxbv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mawK6Un7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mawK6Un7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YnXl0TEE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GsMY7Fhh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2FnhjPs, HV_BINOP_MULTIPLY, 1, m, &cBinop_W2FnhjPs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xuSrrsST_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ddMy4uQF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ddMy4uQF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_GsMY7Fhh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RkY8XwSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3aV5xU7m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3aV5xU7m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7PNNT6X, HV_BINOP_MULTIPLY, 1, m, &cBinop_h7PNNT6X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uxHyzEdc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BTZeY2mF, HV_BINOP_MULTIPLY, 1, m, &cBinop_BTZeY2mF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hs1HHeFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_v4BAMgFs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_v4BAMgFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_uxHyzEdc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rOFwICAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bTQgIgIP, 1, m, &cVar_bTQgIgIP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AeOgBwRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lq1h5Wn9, HV_BINOP_MULTIPLY, 1, m, &cBinop_lq1h5Wn9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K96rd5SY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_5Qlec9wa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5Qlec9wa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CFlWRvqf, HV_BINOP_MULTIPLY, 1, m, &cBinop_CFlWRvqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_bTQgIgIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xombZAcc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_QfWHOMo4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nQrk0J4U_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_nR0iiLPr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vt695faZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_cRnodEW8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Y2ghyxbv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_af4ed90e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_t58RJYDk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iQdeBWik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_RpYsuQ4t_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_JaZ606Sb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_rPnGoAOl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0Lq8K4Wu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JCxtIqmu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_uAgFtjNl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WeYFFl5J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YnXl0TEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_8BRRYC7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8BRRYC7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dWg4uJIT, HV_BINOP_MULTIPLY, 1, m, &cBinop_dWg4uJIT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dWg4uJIT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JJWoeKT3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JJWoeKT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_uAgFtjNl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xombZAcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_znCdkw2e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_znCdkw2e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0BaWjc8d_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nn04aVXt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_j6ULQdGL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hvCyLDGB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2TL8pJ4q_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jXrIyX0e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W2FnhjPs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EmrT5QBX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_h7PNNT6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_me1vHhYJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_BTZeY2mF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7jUoEPfN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_lq1h5Wn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sEgG8qzJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CFlWRvqf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zHmeaLYm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_i5OLL6qP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QfWHOMo4, 0, m, &cVar_QfWHOMo4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pcgL0BDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cRnodEW8, 1, m, &cVar_cRnodEW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hvCyLDGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_BTZeY2mF, HV_BINOP_MULTIPLY, 0, m, &cBinop_BTZeY2mF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2TL8pJ4q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_h7PNNT6X, HV_BINOP_MULTIPLY, 0, m, &cBinop_h7PNNT6X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jXrIyX0e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_W2FnhjPs, HV_BINOP_MULTIPLY, 0, m, &cBinop_W2FnhjPs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Nn04aVXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_CFlWRvqf, HV_BINOP_MULTIPLY, 0, m, &cBinop_CFlWRvqf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_j6ULQdGL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_lq1h5Wn9, HV_BINOP_MULTIPLY, 0, m, &cBinop_lq1h5Wn9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0BaWjc8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_nQrk0J4U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_cRnodEW8, 0, m, &cVar_cRnodEW8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vt695faZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bTQgIgIP, 0, m, &cVar_bTQgIgIP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pCmpvFNY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E4aVmpqM, 1, m, &cIf_E4aVmpqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LvK0Silc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_vBmYPb5C_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_kfh0bpq4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LvK0Silc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_CulhvHnd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E4aVmpqM, 0, m, &cIf_E4aVmpqM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E1idNT36_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Mg9MSduF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vBmYPb5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EQmP72dH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OF9dBCen_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VxqEsrjh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_YVz1S7JB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_CulhvHnd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wAJsBdIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pCmpvFNY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_kfh0bpq4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_WyCO1xwa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_mS3mjczl, 0, m, &cSlice_mS3mjczl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BoujdC5p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_mS3mjczl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_SUinVIEX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_SUinVIEX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_LoyYGURe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_SUinVIEX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_SUinVIEX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0MenaF0f_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_D01V6tuc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_nM3q2YjM_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_cBILNo4O, 0, m, &cIf_cBILNo4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_cBILNo4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_GmUEy7Im_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Licd7WAf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ydGcKZ9S_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_UftO0V5C_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_0SrQN8Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZXw2EpZY, HV_BINOP_POW, 0, m, &cBinop_ZXw2EpZY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZXw2EpZY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NsgBySdI, 0, m, &cIf_NsgBySdI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bmJzBm0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_xVPcc1gv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tsan0S3Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Licd7WAf, 0, m, &cIf_Licd7WAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OdjWLCDd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Zpp29iH3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zpp29iH3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Licd7WAf, 1, m, &cIf_Licd7WAf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UftO0V5C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_bmJzBm0R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ydGcKZ9S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_NsgBySdI, 0, m, &cIf_NsgBySdI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xVPcc1gv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ZXw2EpZY, HV_BINOP_POW, 1, m, &cBinop_ZXw2EpZY_sendMessage);
  cMsg_0SrQN8Z0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_NsgBySdI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_bW5Q0wIQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_nM3q2YjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cBILNo4O, 1, m, &cIf_cBILNo4O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GmUEy7Im_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_okhBLm0E_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pJ0qP6vO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TTzXAccX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OdjWLCDd_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Tsan0S3Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3sRw1qal_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NsgBySdI, 1, m, &cIf_NsgBySdI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tVz078zR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gGIelwtY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gGIelwtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_bW5Q0wIQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rSLF2f3z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_TTzXAccX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pJ0qP6vO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3sRw1qal, HV_BINOP_GREATER_THAN, 1, m, &cBinop_3sRw1qal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_okhBLm0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tVz078zR, HV_BINOP_EQ, 1, m, &cBinop_tVz078zR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_haCla0Yy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_D01V6tuc, 0, m, &cVar_D01V6tuc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Iut9Zp5X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3sRw1qal, HV_BINOP_GREATER_THAN, 0, m, &cBinop_3sRw1qal_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lnA4jiuo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tVz078zR, HV_BINOP_EQ, 0, m, &cBinop_tVz078zR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QdoGSRPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rSLF2f3z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ObQdHxPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IVkjbdwb_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_MvQJj3g9, 0, m, &cIf_MvQJj3g9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_MvQJj3g9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_DBtl3pOU_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_2pE7F5rj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_ClNghqEb_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_mD4aUKS5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_wh0Gkiwy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TRuqpaoi, HV_BINOP_POW, 0, m, &cBinop_TRuqpaoi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TRuqpaoi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gx5RGtAL, 0, m, &cIf_Gx5RGtAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1tqyA2Jj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_ao0TWVaY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aJxovREp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2pE7F5rj, 0, m, &cIf_2pE7F5rj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sq1ivzJW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_4JhqRVO1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_4JhqRVO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2pE7F5rj, 1, m, &cIf_2pE7F5rj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mD4aUKS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_1tqyA2Jj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ClNghqEb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_Gx5RGtAL, 0, m, &cIf_Gx5RGtAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ao0TWVaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TRuqpaoi, HV_BINOP_POW, 1, m, &cBinop_TRuqpaoi_sendMessage);
  cMsg_wh0Gkiwy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_Gx5RGtAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NjLU4G9F_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YpVSr7h5_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_IVkjbdwb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MvQJj3g9, 1, m, &cIf_MvQJj3g9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DBtl3pOU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bAOzaKRL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4zdINMHF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NCaDsJvT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sq1ivzJW_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aJxovREp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LdEphhkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Gx5RGtAL, 1, m, &cIf_Gx5RGtAL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nmGCaEcj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KIZZNAtG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KIZZNAtG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NjLU4G9F_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YpVSr7h5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_zkCAjQKh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_NCaDsJvT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bAOzaKRL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nmGCaEcj, HV_BINOP_EQ, 1, m, &cBinop_nmGCaEcj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4zdINMHF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdEphhkV, HV_BINOP_GREATER_THAN, 1, m, &cBinop_LdEphhkV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Mkdu68qm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zkCAjQKh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Mmo5SnoK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ObQdHxPu, 0, m, &cVar_ObQdHxPu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_doFaraQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nmGCaEcj, HV_BINOP_EQ, 0, m, &cBinop_nmGCaEcj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mmiARB7B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LdEphhkV, HV_BINOP_GREATER_THAN, 0, m, &cBinop_LdEphhkV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_Z2TEJbtH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_15aTXn64_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_YOYi5ziX, 0, m, &cIf_YOYi5ziX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_YOYi5ziX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fkLC7G4K_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Yk81hubb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_1rYPelSr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_02PWK1rc_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cMsg_ixZJJupy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A2Ki5HSK, HV_BINOP_POW, 0, m, &cBinop_A2Ki5HSK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A2Ki5HSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3064x8Nq, 0, m, &cIf_3064x8Nq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B33vJtMW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Btzy6V8g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PAe67lTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yk81hubb, 0, m, &cIf_Yk81hubb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IVYNdqtX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_YvFYLkF2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YvFYLkF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Yk81hubb, 1, m, &cIf_Yk81hubb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_02PWK1rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_B33vJtMW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1rYPelSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_3064x8Nq, 0, m, &cIf_3064x8Nq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Btzy6V8g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A2Ki5HSK, HV_BINOP_POW, 1, m, &cBinop_A2Ki5HSK_sendMessage);
  cMsg_ixZJJupy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_3064x8Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Mzmyvyg8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cBinop_15aTXn64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YOYi5ziX, 1, m, &cIf_YOYi5ziX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fkLC7G4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wuuuWKLO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YNuJK6x9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wqVfssoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IVYNdqtX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_PAe67lTu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NrLWa55y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3064x8Nq, 1, m, &cIf_3064x8Nq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_VF3rn5SY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h3WXpZmM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_h3WXpZmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_Mzmyvyg8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OiaDZuWQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_wqVfssoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YNuJK6x9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NrLWa55y, HV_BINOP_GREATER_THAN, 1, m, &cBinop_NrLWa55y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wuuuWKLO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VF3rn5SY, HV_BINOP_EQ, 1, m, &cBinop_VF3rn5SY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WbVpi0G6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_VF3rn5SY, HV_BINOP_EQ, 0, m, &cBinop_VF3rn5SY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8OBZ3pKO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NrLWa55y, HV_BINOP_GREATER_THAN, 0, m, &cBinop_NrLWa55y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FL0iU4DP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Z2TEJbtH, 0, m, &cVar_Z2TEJbtH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0OgpXSfs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OiaDZuWQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_r9nJ30P5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_A4x0jE0R_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jud91XcT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_iIdnUcBg, 0, m, &cSlice_iIdnUcBg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_UPMIwyyh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_iIdnUcBg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_WBLRreNt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_WBLRreNt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_8jftzPAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_WBLRreNt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_WBLRreNt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iZbxolyR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UPMIwyyh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_HmPjbKBI, 0, m, &cSlice_HmPjbKBI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_WyCO1xwa_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_HmPjbKBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_f8OmiJkR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_f8OmiJkR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_igAYNggO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_f8OmiJkR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_f8OmiJkR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qlYy8Qs8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BoujdC5p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_UFmuYsaF, 0, m, &cSlice_UFmuYsaF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6I21lgCE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_UFmuYsaF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NtH5HDdy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NtH5HDdy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_BWypEAXZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NtH5HDdy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_NtH5HDdy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xXx3nCly_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6I21lgCE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_M2eG9rZn, 0, m, &cSlice_M2eG9rZn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_M2eG9rZn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iVP5Oart_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iVP5Oart_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_XwJxRsjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iVP5Oart_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iVP5Oart_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_cbag8ikB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_xfR6VrhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_cv5YdsnC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MAyDMY4s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xFV4yTk9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZZielq09_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_z24rrDfZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_i4ReSubQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V7LUW4nh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Nk2uGnqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RnPwQuAo, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pJ2a2TEG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_v7QmjOM0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_v7QmjOM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Wgehjnl, HV_BINOP_DIVIDE, 1, m, &cBinop_0Wgehjnl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IkjnEI3R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_5EWjzDM9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_joIGdFfd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XNTg4Nrf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_5EWjzDM9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_joIGdFfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_0Wgehjnl, HV_BINOP_DIVIDE, 0, m, &cBinop_0Wgehjnl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IkjnEI3R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_XNTg4Nrf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0Wgehjnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YVaE4GZK, HV_BINOP_MULTIPLY, 1, m, &cBinop_YVaE4GZK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YVaE4GZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_okU8ZyyF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8WSvOjhw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_SvmGGFk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ORFWi495_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_naojkmCA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_15WJCwIV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_JyeEdwUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_OdPHRsbe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OdPHRsbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YVaE4GZK, HV_BINOP_MULTIPLY, 0, m, &cBinop_YVaE4GZK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9Hd2I1Yj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_n65trkVv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_n65trkVv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OMlUksjC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_71EeiSw1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H07OUEMo, 1, m, &cVar_H07OUEMo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_H07OUEMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sMF8SfBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_0kzs9daF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_470ztHIg, HV_BINOP_MULTIPLY, 1, m, &cBinop_470ztHIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qXELnFEE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_0kzs9daF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AZ6rfaj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_PLN36AMg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PLN36AMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p6DHONxi, HV_BINOP_MULTIPLY, 1, m, &cBinop_p6DHONxi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IIvKUMug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F3CehKFM, HV_BINOP_MULTIPLY, 1, m, &cBinop_F3CehKFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nUkuju3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IIvKUMug_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pOgMFJLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgvctNWj, HV_BINOP_MULTIPLY, 1, m, &cBinop_jgvctNWj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GODCCzmm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_1gMmdumg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1gMmdumg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SU6XD030, HV_BINOP_MULTIPLY, 1, m, &cBinop_SU6XD030_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_f2gVMdop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FZsGT20j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_JyeEdwUm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VSn41yEy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_zevAJZHr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_9Hd2I1Yj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8WSvOjhw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_naojkmCA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_okU8ZyyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_SvmGGFk8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_ORFWi495_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hRMSv4lO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_15WJCwIV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_IheAKCyK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FNtxymTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_NaSUQiIh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OMlUksjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pmSFis9T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pmSFis9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bzEQL0sg, HV_BINOP_MULTIPLY, 1, m, &cBinop_bzEQL0sg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bzEQL0sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JRSU1bQK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JRSU1bQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FNtxymTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sMF8SfBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_OIDhUBXD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OIDhUBXD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w7E5Oboe_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QcgDXOUM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GqdGNF8z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aULTsQFs_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9TUcZZoS_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nLwZYrhf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_470ztHIg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xfR6VrhM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_p6DHONxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MAyDMY4s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_F3CehKFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZZielq09_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_jgvctNWj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_i4ReSubQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_SU6XD030_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Nk2uGnqh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_mdurUOlZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_f2gVMdop, 0, m, &cVar_f2gVMdop_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PzirLOBU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zevAJZHr, 1, m, &cVar_zevAJZHr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aULTsQFs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F3CehKFM, HV_BINOP_MULTIPLY, 0, m, &cBinop_F3CehKFM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GqdGNF8z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jgvctNWj, HV_BINOP_MULTIPLY, 0, m, &cBinop_jgvctNWj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QcgDXOUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_SU6XD030, HV_BINOP_MULTIPLY, 0, m, &cBinop_SU6XD030_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nLwZYrhf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_470ztHIg, HV_BINOP_MULTIPLY, 0, m, &cBinop_470ztHIg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9TUcZZoS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p6DHONxi, HV_BINOP_MULTIPLY, 0, m, &cBinop_p6DHONxi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w7E5Oboe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_VSn41yEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_H07OUEMo, 0, m, &cVar_H07OUEMo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FZsGT20j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zevAJZHr, 0, m, &cVar_zevAJZHr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pmnIduHN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CMani0fC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_SeXMKCzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_PLd9bjgH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_F8PhVdOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VHBmNeoE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EBiMtxNT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1XFfSDBF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dOYbG3EP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_IwToV4nC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_IwToV4nC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o3IcCUoz, HV_BINOP_DIVIDE, 1, m, &cBinop_o3IcCUoz_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IvaDuIWm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_EZ39YDUI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_AlhcEgde_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BdKfy2f6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_EZ39YDUI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AlhcEgde_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_o3IcCUoz, HV_BINOP_DIVIDE, 0, m, &cBinop_o3IcCUoz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IvaDuIWm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BdKfy2f6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_o3IcCUoz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehsQYoMl, HV_BINOP_MULTIPLY, 1, m, &cBinop_ehsQYoMl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ehsQYoMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_t9QR9zTf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x8BLAckY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_jzKjJZr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mTiPvGFN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_jVYvlsyU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UnfrsiMK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_s1j9jIkH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_M5qg2tfu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M5qg2tfu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ehsQYoMl, HV_BINOP_MULTIPLY, 0, m, &cBinop_ehsQYoMl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FquoTqam_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_Bg7eryzh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bg7eryzh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nSgXswg7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_txqrNtCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUJXXaD8, HV_BINOP_MULTIPLY, 1, m, &cBinop_mUJXXaD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_juG8XJbE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lUMWMHhY, 1, m, &cVar_lUMWMHhY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sjqx9HeN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3QuZUshB, HV_BINOP_MULTIPLY, 1, m, &cBinop_3QuZUshB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6U2EFECM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NAECx6YU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NAECx6YU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IimmWLPR, HV_BINOP_MULTIPLY, 1, m, &cBinop_IimmWLPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_lUMWMHhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jG1abGHI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_jTIhYFUW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uaiSemUP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_s1j9jIkH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bKauXeaO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_YwIpXsyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_FquoTqam_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x8BLAckY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jVYvlsyU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t9QR9zTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_jzKjJZr0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_mTiPvGFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_82FIMiGx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UnfrsiMK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_CGV71T41_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HeHizbJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_xKCW8ttE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nSgXswg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_XLfQNNLr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XLfQNNLr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3Cjv9tmM, HV_BINOP_MULTIPLY, 1, m, &cBinop_3Cjv9tmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3Cjv9tmM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_Eet9FzC2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Eet9FzC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HeHizbJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jG1abGHI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_O3NMOKEu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_O3NMOKEu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ma09JR5l_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xAfk9bAi_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sJUyyZj0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_x4AnHHUS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m59Rl0cm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pmnIduHN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mUJXXaD8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SeXMKCzC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_3QuZUshB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F8PhVdOc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_IimmWLPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EBiMtxNT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XM26asc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jTIhYFUW, 0, m, &cVar_jTIhYFUW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6odX7emG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YwIpXsyv, 1, m, &cVar_YwIpXsyv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uaiSemUP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YwIpXsyv, 0, m, &cVar_YwIpXsyv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bKauXeaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lUMWMHhY, 0, m, &cVar_lUMWMHhY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ma09JR5l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IimmWLPR, HV_BINOP_MULTIPLY, 0, m, &cBinop_IimmWLPR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sJUyyZj0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mUJXXaD8, HV_BINOP_MULTIPLY, 0, m, &cBinop_mUJXXaD8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_x4AnHHUS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m59Rl0cm, HV_BINOP_MULTIPLY, 0, m, &cBinop_m59Rl0cm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xAfk9bAi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3QuZUshB, HV_BINOP_MULTIPLY, 0, m, &cBinop_3QuZUshB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QpR9PExq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dNtwdJeF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HOeeb5Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_65gaAlL7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Ox4r666D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BOVxuxvB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VoYGGBcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4LoNRmDL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_xryizy5m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tOpsZd1x, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Lko05aQJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_25YEyIva_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSystem_25YEyIva_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHaZR2dw, HV_BINOP_DIVIDE, 1, m, &cBinop_uHaZR2dw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2ifGVYBs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_FjovUjWL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_Hc6kO3mC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VDAO8nYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_FjovUjWL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Hc6kO3mC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_uHaZR2dw, HV_BINOP_DIVIDE, 0, m, &cBinop_uHaZR2dw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2ifGVYBs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VDAO8nYg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_uHaZR2dw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yqpSXli0, HV_BINOP_MULTIPLY, 1, m, &cBinop_yqpSXli0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yqpSXli0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2cHjKEv5_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Qy1WFU0k_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_njuCcHYk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_kut3O0on_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cUnop_513HvKLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wPVqiSJM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_M2vnK370_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_5y7yOF8P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5y7yOF8P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yqpSXli0, HV_BINOP_MULTIPLY, 0, m, &cBinop_yqpSXli0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y7TEOsrI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_q4F9i6bn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_q4F9i6bn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3QoXNvLp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_y9tUpALM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9TUcRXI8, HV_BINOP_MULTIPLY, 1, m, &cBinop_9TUcRXI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1uLWW5VJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_TzXjdU9p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TzXjdU9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_y9tUpALM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Lfh8GRe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_pNVzE9ed_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pNVzE9ed_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xXE7wWXq, HV_BINOP_MULTIPLY, 1, m, &cBinop_xXE7wWXq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_IPdOTI9C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Dral4M2, HV_BINOP_MULTIPLY, 1, m, &cBinop_4Dral4M2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_82ZEmurv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_o1TFZjnA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_o1TFZjnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_IPdOTI9C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_eylfnoC2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lBlb23vL, 1, m, &cVar_lBlb23vL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tB9rpW9J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DYGAMLlJ, HV_BINOP_MULTIPLY, 1, m, &cBinop_DYGAMLlJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_44d0hBp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_kLMWL53P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kLMWL53P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8uQIcEFu, HV_BINOP_MULTIPLY, 1, m, &cBinop_8uQIcEFu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_lBlb23vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OrjPtyJi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0dyI41HF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_h5naNEdb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_M2vnK370_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hf2vaN56_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_V8pKMcG5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_y7TEOsrI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Qy1WFU0k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_513HvKLG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2cHjKEv5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_njuCcHYk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cSend_kut3O0on_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_WgV3T3a9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_wPVqiSJM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lPtc1f28_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_pnl2cGtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qx1TG3pE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3QoXNvLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_tZHnFskY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tZHnFskY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kv1LGaau, HV_BINOP_MULTIPLY, 1, m, &cBinop_Kv1LGaau_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Kv1LGaau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_l8m5SOUb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_l8m5SOUb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_pnl2cGtp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_OrjPtyJi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_yuzfRray_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yuzfRray_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7UBGyPK6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gpvDRrFP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_sCTvlN3U_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ww3slqTp_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_iuYJ5a4o_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yvdymDZb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9TUcRXI8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QpR9PExq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_xXE7wWXq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HOeeb5Ee_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_4Dral4M2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Ox4r666D_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_DYGAMLlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VoYGGBcR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_8uQIcEFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xryizy5m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_q3en95YW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V8pKMcG5, 1, m, &cVar_V8pKMcG5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dInhfUue_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0dyI41HF, 0, m, &cVar_0dyI41HF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_sCTvlN3U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DYGAMLlJ, HV_BINOP_MULTIPLY, 0, m, &cBinop_DYGAMLlJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ww3slqTp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4Dral4M2, HV_BINOP_MULTIPLY, 0, m, &cBinop_4Dral4M2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gpvDRrFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8uQIcEFu, HV_BINOP_MULTIPLY, 0, m, &cBinop_8uQIcEFu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7UBGyPK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_yvdymDZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9TUcRXI8, HV_BINOP_MULTIPLY, 0, m, &cBinop_9TUcRXI8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iuYJ5a4o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xXE7wWXq, HV_BINOP_MULTIPLY, 0, m, &cBinop_xXE7wWXq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_h5naNEdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_V8pKMcG5, 0, m, &cVar_V8pKMcG5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hf2vaN56_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lBlb23vL, 0, m, &cVar_lBlb23vL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vL07Q5lD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r9nJ30P5, 1, m, &cIf_r9nJ30P5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mx8YJA6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cMsg_A4x0jE0R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_HaoXQCWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mx8YJA6G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_YScOdNJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_r9nJ30P5, 0, m, &cIf_r9nJ30P5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bW5Q0wIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jvbffNYL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_A4x0jE0R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_8RDoSDxF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Mzmyvyg8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BGKMYpVJ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NjLU4G9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_vL07Q5lD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HaoXQCWX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YpVSr7h5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_YScOdNJ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4fT2c69J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzkM9UDr, HV_BINOP_DIVIDE, 0, m, &cBinop_DzkM9UDr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1hUz6JTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OgMvIqfc, HV_BINOP_DIVIDE, 1, m, &cBinop_OgMvIqfc_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_DzkM9UDr, HV_BINOP_DIVIDE, 1, m, &cBinop_DzkM9UDr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_RAJg0KMU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DwnBqS8O, HV_BINOP_DIVIDE, 0, m, &cBinop_DwnBqS8O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_Qdf16jkd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DwnBqS8O, HV_BINOP_DIVIDE, 1, m, &cBinop_DwnBqS8O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gwPVRM18_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1hUz6JTn, 0, m, &cVar_1hUz6JTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6ObidbA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OgMvIqfc, HV_BINOP_DIVIDE, 0, m, &cBinop_OgMvIqfc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G8ZloQgA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4fT2c69J, 0, m, &cVar_4fT2c69J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OgMvIqfc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_RAJg0KMU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DzkM9UDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_Qdf16jkd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DwnBqS8O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_iIZDspAe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cUnop_8wBH3mCI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_59GdQDY5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_y1YCZXkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_hPNW0peW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iIZDspAe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_y1YCZXkv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_hPNW0peW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_8wBH3mCI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_59GdQDY5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pUR6BqWu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_yKmTuSkA_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_sN3f8nh3, 0, m, &cSlice_sN3f8nh3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_sN3f8nh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_7Nrk6jjB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_7Nrk6jjB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_2aiK2hlL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7Nrk6jjB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_7Nrk6jjB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_jq610ngy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_G6p6rTS4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_OioxO5Bh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OioxO5Bh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_L2PdueD4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_L2PdueD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_pjJfMBuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pjJfMBuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6KruVNhD_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MWe8HtIt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MWe8HtIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4OTibOH7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_6KruVNhD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_omFIklw4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_omFIklw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_2RmMc1PZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4OTibOH7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_snRaZvsb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_snRaZvsb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_mB4MFJoj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2RmMc1PZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9uNSlQ8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_mB4MFJoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qXU5jlfd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9uNSlQ8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_j3vHudWM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qXU5jlfd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_M0BhYKdh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_5vBgnkK1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Otn1pQul_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pkbtQMxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B5ZGgijO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SmMxoT4C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K3C4g0fg_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RLJN34uZ_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iHCuiboW_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8N4ek0Ls_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zbR3Lph1_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N2I1ieNn_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_K3C4g0fg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fRSqcmKS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_RLJN34uZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_92uVT1Ze_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_iHCuiboW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_u8ykaxh3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_8N4ek0Ls_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZMF7Lq81_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zbR3Lph1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_BXelaoLt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_N2I1ieNn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rmTeu3Po_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_zacxcrnV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tNi2fYsz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_nmYMGTUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TmfJzokO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0DjLrFtD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8rzVIAyT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8rzVIAyT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6AGtiTwU, 1, m, &cDelay_6AGtiTwU_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6nVT4Fgo_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6AGtiTwU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6AGtiTwU, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zacxcrnV, 0, m, &cIf_zacxcrnV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8rzVIAyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AGtiTwU, 0, m, &cDelay_6AGtiTwU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6nVT4Fgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6AGtiTwU, 0, m, &cDelay_6AGtiTwU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9Fm79izy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ovIDhfBA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YRlYmD1o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qblGg8gD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UkHSxQxf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0bPcDFhI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0bPcDFhI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0DjLrFtD_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_UkHSxQxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zacxcrnV, 1, m, &cIf_zacxcrnV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ovIDhfBA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nmYMGTUZ, 1, m, &cIf_nmYMGTUZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YRlYmD1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nmYMGTUZ, 0, m, &cIf_nmYMGTUZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TmfJzokO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vgk2A29g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tNi2fYsz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vgk2A29g, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_c0OVn4zC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5IX1unes_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_0GCApF5L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ax2phyTb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_SPcWuu2I_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7UCDyOPO_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7UCDyOPO_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_KvHGW4z7, 1, m, &cDelay_KvHGW4z7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iyJvCuNu_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_KvHGW4z7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_KvHGW4z7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_c0OVn4zC, 0, m, &cIf_c0OVn4zC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7UCDyOPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_KvHGW4z7, 0, m, &cDelay_KvHGW4z7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iyJvCuNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_KvHGW4z7, 0, m, &cDelay_KvHGW4z7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OXM8qxsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vMk4wTNP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qFmj6C2u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_REiou9E5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_98FsHeXF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DoVTPbsW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DoVTPbsW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SPcWuu2I_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_98FsHeXF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c0OVn4zC, 1, m, &cIf_c0OVn4zC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qFmj6C2u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0GCApF5L, 0, m, &cIf_0GCApF5L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vMk4wTNP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_0GCApF5L, 1, m, &cIf_0GCApF5L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ax2phyTb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uZVPAFjQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5IX1unes_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uZVPAFjQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_h1mQn4Ai_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_q0eVpObF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ZFlJNBqi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rpIDs9B7_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CQArTnB2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fqaEQqKp_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fqaEQqKp_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_tGqJHwWu, 1, m, &cDelay_tGqJHwWu_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OSh11ofX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_tGqJHwWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_tGqJHwWu, m);
  cIf_onMessage(_c, &Context(_c)->cIf_h1mQn4Ai, 0, m, &cIf_h1mQn4Ai_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fqaEQqKp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGqJHwWu, 0, m, &cDelay_tGqJHwWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OSh11ofX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_tGqJHwWu, 0, m, &cDelay_tGqJHwWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_czAoR15Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zsgX05fC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_I2cTEhBn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g3LbnCsZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rCtTKXyb_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FdeoCDmT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FdeoCDmT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CQArTnB2_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_rCtTKXyb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h1mQn4Ai, 1, m, &cIf_h1mQn4Ai_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zsgX05fC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZFlJNBqi, 1, m, &cIf_ZFlJNBqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_I2cTEhBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZFlJNBqi, 0, m, &cIf_ZFlJNBqi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rpIDs9B7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SUsBlk7q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_q0eVpObF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SUsBlk7q, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_sKkiudFx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fI0HyYri_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_bDvbezYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Sqpgjsc1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vKoNgeEQ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NWhkBo7f_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NWhkBo7f_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ikVlohNo, 1, m, &cDelay_ikVlohNo_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XGE7nJG1_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ikVlohNo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ikVlohNo, m);
  cIf_onMessage(_c, &Context(_c)->cIf_sKkiudFx, 0, m, &cIf_sKkiudFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NWhkBo7f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ikVlohNo, 0, m, &cDelay_ikVlohNo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_XGE7nJG1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ikVlohNo, 0, m, &cDelay_ikVlohNo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_avJLiGGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vPkd7g5h_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8hKpt4F3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_98bTHp6K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hY4f5PZ4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WTsBSt6Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hY4f5PZ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sKkiudFx, 1, m, &cIf_sKkiudFx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WTsBSt6Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vKoNgeEQ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vPkd7g5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bDvbezYj, 1, m, &cIf_bDvbezYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8hKpt4F3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bDvbezYj, 0, m, &cIf_bDvbezYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Sqpgjsc1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5i3cKbwr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fI0HyYri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5i3cKbwr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_c2q1IJze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_JChMyy8m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LcRZdcuD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VieqV8Fy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_L5NUjrDa_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cSO6UTqh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cSO6UTqh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_1i4hb90Z, 1, m, &cDelay_1i4hb90Z_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dKoDDWI6_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_1i4hb90Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_1i4hb90Z, m);
  cIf_onMessage(_c, &Context(_c)->cIf_c2q1IJze, 0, m, &cIf_c2q1IJze_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cSO6UTqh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_1i4hb90Z, 0, m, &cDelay_1i4hb90Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dKoDDWI6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_1i4hb90Z, 0, m, &cDelay_1i4hb90Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_RMz7r8Ma_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zkHF8mbR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ahh1dsrJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CyHIa88M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_n48UoTDF_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AeBS9A0l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AeBS9A0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_L5NUjrDa_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_n48UoTDF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c2q1IJze, 1, m, &cIf_c2q1IJze_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zkHF8mbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LcRZdcuD, 1, m, &cIf_LcRZdcuD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ahh1dsrJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LcRZdcuD, 0, m, &cIf_LcRZdcuD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VieqV8Fy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y2aK6ioQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JChMyy8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Y2aK6ioQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_O4LhuDzu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zmfHmpNH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_waaNUxxe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_it4DMII9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NXYCiR3R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Xc3XDmr4_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Xc3XDmr4_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cF8qXh33, 1, m, &cDelay_cF8qXh33_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5Fl8qkYc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cF8qXh33_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cF8qXh33, m);
  cIf_onMessage(_c, &Context(_c)->cIf_O4LhuDzu, 0, m, &cIf_O4LhuDzu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Xc3XDmr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cF8qXh33, 0, m, &cDelay_cF8qXh33_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Fl8qkYc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cF8qXh33, 0, m, &cDelay_cF8qXh33_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TO2JvMSM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wc9zFXpS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zhdKkpA5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_j6Gn4VnU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zuD3YW42_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VHHyuQIm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VHHyuQIm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NXYCiR3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zuD3YW42_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_O4LhuDzu, 1, m, &cIf_O4LhuDzu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wc9zFXpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_waaNUxxe, 1, m, &cIf_waaNUxxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zhdKkpA5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_waaNUxxe, 0, m, &cIf_waaNUxxe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_it4DMII9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vjWx736Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zmfHmpNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vjWx736Y, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_f4REcdOQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_HT1KxIVR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_VKtG1V8Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hRMMzH8m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8JsKZ1h8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_h29FZGPP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_h29FZGPP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sTFZEcrO, 1, m, &cDelay_sTFZEcrO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iexwggB9_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sTFZEcrO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sTFZEcrO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_f4REcdOQ, 0, m, &cIf_f4REcdOQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_h29FZGPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sTFZEcrO, 0, m, &cDelay_sTFZEcrO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iexwggB9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sTFZEcrO, 0, m, &cDelay_sTFZEcrO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_x96LKxsk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IzAeFEw7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_voosXn7j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u2ozuaRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RzBypGbT_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dYDy6d3v_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dYDy6d3v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8JsKZ1h8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RzBypGbT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f4REcdOQ, 1, m, &cIf_f4REcdOQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IzAeFEw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VKtG1V8Y, 1, m, &cIf_VKtG1V8Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_voosXn7j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VKtG1V8Y, 0, m, &cIf_VKtG1V8Y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hRMMzH8m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_as6iOcEA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_HT1KxIVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_as6iOcEA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FSSH5lsc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IV9oDILJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_J8qCrqmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AsGVDGZ1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qSvE5J86_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NtxeVYCP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NtxeVYCP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vBmkM8qh, 1, m, &cDelay_vBmkM8qh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9G1Wp2Jp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vBmkM8qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vBmkM8qh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FSSH5lsc, 0, m, &cIf_FSSH5lsc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NtxeVYCP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vBmkM8qh, 0, m, &cDelay_vBmkM8qh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9G1Wp2Jp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vBmkM8qh, 0, m, &cDelay_vBmkM8qh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_3bjyl7Ec_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Pj7NMiLW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xZW3vpxN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mFmedXCG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xRNw5hGK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WeH7JFt2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WeH7JFt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qSvE5J86_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xRNw5hGK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FSSH5lsc, 1, m, &cIf_FSSH5lsc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xZW3vpxN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J8qCrqmL, 0, m, &cIf_J8qCrqmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Pj7NMiLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_J8qCrqmL, 1, m, &cIf_J8qCrqmL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AsGVDGZ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rux4Ib7O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IV9oDILJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rux4Ib7O, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QDZO8DUc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_qV3m7JK6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4bPBliNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KlF5470s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_3xI9BqsP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_pREd1V47_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_pREd1V47_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_342DfgT0, 1, m, &cDelay_342DfgT0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c1ulG2gz_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_342DfgT0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_342DfgT0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QDZO8DUc, 0, m, &cIf_QDZO8DUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pREd1V47_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_342DfgT0, 0, m, &cDelay_342DfgT0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c1ulG2gz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_342DfgT0, 0, m, &cDelay_342DfgT0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T1Uf42tF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qIHZstye_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2AURlvwK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wM5NomWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Sc1lmB2C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3GRgrIzz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3GRgrIzz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_3xI9BqsP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Sc1lmB2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QDZO8DUc, 1, m, &cIf_QDZO8DUc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_qIHZstye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4bPBliNH, 1, m, &cIf_4bPBliNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2AURlvwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4bPBliNH, 0, m, &cIf_4bPBliNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KlF5470s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x2v0Xapd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qV3m7JK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x2v0Xapd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Tzf6mrC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3wHBy7bp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TnHSqcEv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DBTlG5vu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tTcLvWX5_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_s3TLdFQv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_s3TLdFQv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_5g90UroN, 1, m, &cDelay_5g90UroN_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mvEBG6Wi_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_5g90UroN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_5g90UroN, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Tzf6mrC7, 0, m, &cIf_Tzf6mrC7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_s3TLdFQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_5g90UroN, 0, m, &cDelay_5g90UroN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mvEBG6Wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_5g90UroN, 0, m, &cDelay_5g90UroN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vSv8F67c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7TynPsoI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Sg2lquJ8_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ngcZRml0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bu9uppNi_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TBGHZ865_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TBGHZ865_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tTcLvWX5_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Bu9uppNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Tzf6mrC7, 1, m, &cIf_Tzf6mrC7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7TynPsoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TnHSqcEv, 1, m, &cIf_TnHSqcEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Sg2lquJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TnHSqcEv, 0, m, &cIf_TnHSqcEv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DBTlG5vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b6JfQ6Yx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3wHBy7bp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_b6JfQ6Yx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tt67qgvo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_G2U0w2My_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FM1hxvcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jCvTXmnE_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hS4c4lUg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_qIpFbd5W_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_qIpFbd5W_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_giU8FuRK, 1, m, &cDelay_giU8FuRK_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Vlfcoxy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_giU8FuRK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_giU8FuRK, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tt67qgvo, 0, m, &cIf_tt67qgvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qIpFbd5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_giU8FuRK, 0, m, &cDelay_giU8FuRK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Vlfcoxy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_giU8FuRK, 0, m, &cDelay_giU8FuRK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vLJ7milF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kYnCYFxV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Y9w5juN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xlkJW7Ht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2ieMuoxR_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vVsNrK9L_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vVsNrK9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hS4c4lUg_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_2ieMuoxR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tt67qgvo, 1, m, &cIf_tt67qgvo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kYnCYFxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FM1hxvcX, 1, m, &cIf_FM1hxvcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Y9w5juN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FM1hxvcX, 0, m, &cIf_FM1hxvcX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jCvTXmnE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TcGiiXx5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_G2U0w2My_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TcGiiXx5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Z5HL0Vy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Gd5GUjMQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wxI3v4oa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Bl0mpriR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Tgf6WUSR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ejpcNT67_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ejpcNT67_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_h3rWI0kQ, 1, m, &cDelay_h3rWI0kQ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GArxD48z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_h3rWI0kQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_h3rWI0kQ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Z5HL0Vy2, 0, m, &cIf_Z5HL0Vy2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ejpcNT67_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_h3rWI0kQ, 0, m, &cDelay_h3rWI0kQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GArxD48z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_h3rWI0kQ, 0, m, &cDelay_h3rWI0kQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a8Vdbzrn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9FXnyGkt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f1964PQe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AoiINfSK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_N3FQ4IZd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZMXncHFw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZMXncHFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Tgf6WUSR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_N3FQ4IZd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z5HL0Vy2, 1, m, &cIf_Z5HL0Vy2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f1964PQe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wxI3v4oa, 0, m, &cIf_wxI3v4oa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9FXnyGkt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wxI3v4oa, 1, m, &cIf_wxI3v4oa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Bl0mpriR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TsrwImJS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Gd5GUjMQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_TsrwImJS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fRSqcmKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_YAx6xCrw_sendMessage(_c, 0, m);
  cMsg_thUlJCM5_sendMessage(_c, 0, m);
  cMsg_jHcGo9Lh_sendMessage(_c, 0, m);
  cMsg_LsZ7z2iM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_92uVT1Ze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_YAx6xCrw_sendMessage(_c, 0, m);
  cMsg_uvq6naqb_sendMessage(_c, 0, m);
  cMsg_H11r1IaX_sendMessage(_c, 0, m);
  cMsg_isFL0jJV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u8ykaxh3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_ps2UlEbM_sendMessage(_c, 0, m);
  cMsg_uvq6naqb_sendMessage(_c, 0, m);
  cMsg_LsZ7z2iM_sendMessage(_c, 0, m);
  cMsg_jXdio7Xe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZMF7Lq81_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_ps2UlEbM_sendMessage(_c, 0, m);
  cMsg_aaAzw9pU_sendMessage(_c, 0, m);
  cMsg_jHcGo9Lh_sendMessage(_c, 0, m);
  cMsg_XkN78BmL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_BXelaoLt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_9GYS7xQg_sendMessage(_c, 0, m);
  cMsg_isFL0jJV_sendMessage(_c, 0, m);
  cMsg_fPGk9L73_sendMessage(_c, 0, m);
  cMsg_jHcGo9Lh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rmTeu3Po_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_9GYS7xQg_sendMessage(_c, 0, m);
  cMsg_XkN78BmL_sendMessage(_c, 0, m);
  cMsg_uvq6naqb_sendMessage(_c, 0, m);
  cMsg_RNi3DiFg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zEVZbklz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qblGg8gD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9Fm79izy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iV3oSlXk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qblGg8gD_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_9Fm79izy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DmFKqGEp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_REiou9E5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OXM8qxsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LY9hfHyT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_REiou9E5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OXM8qxsI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oz74krbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g3LbnCsZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_czAoR15Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_daMAxy52_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g3LbnCsZ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_czAoR15Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YAx6xCrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_zEVZbklz_sendMessage(_c, 0, m);
  cMsg_LY9hfHyT_sendMessage(_c, 0, m);
  cMsg_daMAxy52_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ps2UlEbM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_iV3oSlXk_sendMessage(_c, 0, m);
  cMsg_DmFKqGEp_sendMessage(_c, 0, m);
  cMsg_daMAxy52_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9GYS7xQg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_iV3oSlXk_sendMessage(_c, 0, m);
  cMsg_LY9hfHyT_sendMessage(_c, 0, m);
  cMsg_oz74krbW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mZaegViH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_98bTHp6K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_avJLiGGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XocOp8E2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_98bTHp6K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_avJLiGGe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YlKx3pFw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CyHIa88M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RMz7r8Ma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0vGutzpF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CyHIa88M_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RMz7r8Ma_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZxvmHuan_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j6Gn4VnU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TO2JvMSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2NIWzv1F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_j6Gn4VnU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TO2JvMSM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_uvq6naqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_XocOp8E2_sendMessage(_c, 0, m);
  cMsg_0vGutzpF_sendMessage(_c, 0, m);
  cMsg_2NIWzv1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_thUlJCM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_XocOp8E2_sendMessage(_c, 0, m);
  cMsg_YlKx3pFw_sendMessage(_c, 0, m);
  cMsg_ZxvmHuan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aaAzw9pU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_mZaegViH_sendMessage(_c, 0, m);
  cMsg_0vGutzpF_sendMessage(_c, 0, m);
  cMsg_ZxvmHuan_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fZIkjAGz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ngcZRml0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vSv8F67c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EAIfSz2J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ngcZRml0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vSv8F67c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2fcovr2y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xlkJW7Ht_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vLJ7milF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pGe612C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xlkJW7Ht_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vLJ7milF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4T17cRrq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AoiINfSK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a8Vdbzrn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IOAt9fpz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AoiINfSK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a8Vdbzrn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XkN78BmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_fZIkjAGz_sendMessage(_c, 0, m);
  cMsg_pGe612C7_sendMessage(_c, 0, m);
  cMsg_IOAt9fpz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_isFL0jJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_EAIfSz2J_sendMessage(_c, 0, m);
  cMsg_2fcovr2y_sendMessage(_c, 0, m);
  cMsg_IOAt9fpz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_LsZ7z2iM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_EAIfSz2J_sendMessage(_c, 0, m);
  cMsg_pGe612C7_sendMessage(_c, 0, m);
  cMsg_4T17cRrq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pAlw929L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u2ozuaRg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x96LKxsk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7OYd9Wg9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_u2ozuaRg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_x96LKxsk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oCxwcRUK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mFmedXCG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3bjyl7Ec_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VgIHnjOz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_mFmedXCG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_3bjyl7Ec_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UbW4qrcn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wM5NomWt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T1Uf42tF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rdXAwRQr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wM5NomWt_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T1Uf42tF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jHcGo9Lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_7OYd9Wg9_sendMessage(_c, 0, m);
  cMsg_VgIHnjOz_sendMessage(_c, 0, m);
  cMsg_rdXAwRQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_H11r1IaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_7OYd9Wg9_sendMessage(_c, 0, m);
  cMsg_oCxwcRUK_sendMessage(_c, 0, m);
  cMsg_UbW4qrcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RNi3DiFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_pAlw929L_sendMessage(_c, 0, m);
  cMsg_oCxwcRUK_sendMessage(_c, 0, m);
  cMsg_rdXAwRQr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fPGk9L73_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_mZaegViH_sendMessage(_c, 0, m);
  cMsg_YlKx3pFw_sendMessage(_c, 0, m);
  cMsg_2NIWzv1F_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jXdio7Xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_pAlw929L_sendMessage(_c, 0, m);
  cMsg_VgIHnjOz_sendMessage(_c, 0, m);
  cMsg_UbW4qrcn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_pL5UZ1Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8DzuwsMN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xoExaHAc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7P3I93Ee, 0, m, &cSlice_7P3I93Ee_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Tei3EqHh_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_7P3I93Ee_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zBC5SDlS_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zBC5SDlS_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_z9hPylKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zBC5SDlS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zBC5SDlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_yswX0X1O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_d1gvFEHu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ekA0V07C, 0, m, &cSlice_ekA0V07C_sendMessage);
      break;
    }
    default: {
      cSwitchcase_vvJlOksR_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ekA0V07C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ARJS1NMr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ARJS1NMr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3gr4lKTW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ARJS1NMr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ARJS1NMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qIdnTxrl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vvJlOksR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zEdcrHWq, 0, m, &cSlice_zEdcrHWq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xoExaHAc_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_zEdcrHWq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_xWDjfuXH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_xWDjfuXH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_92fkXwrb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_xWDjfuXH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_xWDjfuXH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_OdhmSI4S_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Tei3EqHh_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_oblMCnoI, 0, m, &cSlice_oblMCnoI_sendMessage);
      break;
    }
    default: {
      cSwitchcase_hHag7t9i_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_oblMCnoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_ISdliAWV_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_ISdliAWV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_uCmw2PU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ISdliAWV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_ISdliAWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3XhBrWas_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hHag7t9i_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_k0GUsCM6, 0, m, &cSlice_k0GUsCM6_sendMessage);
      break;
    }
    default: {
      cSwitchcase_q4NuHSB3_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_k0GUsCM6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AV3A8UF8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AV3A8UF8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_HMiy9kLM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AV3A8UF8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AV3A8UF8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SGEMSXmw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_jcCgiCit_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_rPukzwBd_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_rPukzwBd_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_OploP7O7, 1, m, &cDelay_OploP7O7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y13Ku65G_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_OploP7O7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_OploP7O7, m);
  cMsg_pysjV2fW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_rPukzwBd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_OploP7O7, 0, m, &cDelay_OploP7O7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y13Ku65G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_OploP7O7, 0, m, &cDelay_OploP7O7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_FRRE13iT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7juqCkG, HV_BINOP_SUBTRACT, 0, m, &cBinop_B7juqCkG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_ycT9EXVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i242cVxk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lDRfg2iR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_i242cVxk_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_SzU1Mg5w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FRRE13iT, 0, m, &cVar_FRRE13iT_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_r1AUVe7v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E07m4uze_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OE077dep_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hUlQUY5q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_B7juqCkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_DSDXbqXG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_DSDXbqXG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Zwn4NLvh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Zwn4NLvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_KnuY8XdS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_5czg32lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zn9I2DPj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IZqOw3wl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IZqOw3wl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_VwGe4gkb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Zn9I2DPj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ycT9EXVs, 1, m, &cIf_ycT9EXVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_h9jhDNyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lDRfg2iR, 1, m, &cIf_lDRfg2iR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VwGe4gkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ycT9EXVs, 0, m, &cIf_ycT9EXVs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KnuY8XdS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lDRfg2iR, 0, m, &cIf_lDRfg2iR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_E07m4uze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_OE077dep_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_B7juqCkG, HV_BINOP_SUBTRACT, 1, m, &cBinop_B7juqCkG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hUlQUY5q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_FRRE13iT, 0, m, &cVar_FRRE13iT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i242cVxk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Hl5evBY3, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_q4NuHSB3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vOQIV2S3, 0, m, &cSlice_vOQIV2S3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_vOQIV2S3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_FZJaFkje_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_FZJaFkje_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_FBlTI44G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_FZJaFkje_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_FZJaFkje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0SLJF6OU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Otn1pQul_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BJG1KiGC, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_B5ZGgijO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_haNl1Bjx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_5ltHMUEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pkbtQMxk, 0, m, &cVar_pkbtQMxk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8DzuwsMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JbSmkbzI, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_au2vb1AZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_jcCgiCit_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mylml89H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_o2W0jHw3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_pysjV2fW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9PytLlaS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_o2W0jHw3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9PytLlaS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9c78J1Rc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_rIO3HIko_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rIO3HIko_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jab2k4KG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Jab2k4KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KAuxWufi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_yAedVnxt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v7sXQNoF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_JM3hY38V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IFWjT4at_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kYN7MlIT_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T3NaywO5_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Hj5diHH5_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rJl4dVwj_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vg3nbLjd_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LHWkcXXd_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_m2oAYs1L_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_T3NaywO5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Vyy4iKPR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Hj5diHH5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fuc5ZDY9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rJl4dVwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1uROW54d_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Vg3nbLjd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3skWpFDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_LHWkcXXd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c1VHrktV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_m2oAYs1L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GotdZZ69_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_5fRCFvu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jgX23Aqz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cCmJeFnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Nc27onuJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n4WdKLE8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cILOtyIr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cILOtyIr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_v0KvlXOI, 1, m, &cDelay_v0KvlXOI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_poPaO3pS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_v0KvlXOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_v0KvlXOI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_5fRCFvu4, 0, m, &cIf_5fRCFvu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cILOtyIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_v0KvlXOI, 0, m, &cDelay_v0KvlXOI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_poPaO3pS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_v0KvlXOI, 0, m, &cDelay_v0KvlXOI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_m5iurrew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3oDLygQH_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GZDD5nSh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SKTz8m6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8yFzq4lA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CdphTa8x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CdphTa8x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_n4WdKLE8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8yFzq4lA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5fRCFvu4, 1, m, &cIf_5fRCFvu4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3oDLygQH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cCmJeFnc, 1, m, &cIf_cCmJeFnc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GZDD5nSh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cCmJeFnc, 0, m, &cIf_cCmJeFnc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Nc27onuJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CFcAkCVd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jgX23Aqz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CFcAkCVd, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_TacuFvmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uKW0A4sI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_lCnQvep0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_OPh5wxC8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NqKovFpn_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_LURO17v0_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_LURO17v0_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_MspRSXU7, 1, m, &cDelay_MspRSXU7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OnxIDfBp_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_MspRSXU7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_MspRSXU7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_TacuFvmU, 0, m, &cIf_TacuFvmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_LURO17v0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_MspRSXU7, 0, m, &cDelay_MspRSXU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OnxIDfBp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_MspRSXU7, 0, m, &cDelay_MspRSXU7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JyXUGpwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CY8zq26u_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6HgYjVX9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SLQpR0sf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VnYCbtA3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_vmb0nu8G_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vmb0nu8G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_NqKovFpn_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VnYCbtA3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TacuFvmU, 1, m, &cIf_TacuFvmU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6HgYjVX9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lCnQvep0, 0, m, &cIf_lCnQvep0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CY8zq26u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_lCnQvep0, 1, m, &cIf_lCnQvep0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OPh5wxC8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Iz1IHbn5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uKW0A4sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Iz1IHbn5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_l2B0zUig_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sZnBSW1u_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_R2mT0IIL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3vHQuQWF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6skxxWeb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_X8Om8X1o_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_X8Om8X1o_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UrmJbC38, 1, m, &cDelay_UrmJbC38_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cbtDiD0j_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UrmJbC38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UrmJbC38, m);
  cIf_onMessage(_c, &Context(_c)->cIf_l2B0zUig, 0, m, &cIf_l2B0zUig_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_X8Om8X1o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UrmJbC38, 0, m, &cDelay_UrmJbC38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cbtDiD0j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UrmJbC38, 0, m, &cDelay_UrmJbC38_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_V4fHgDKw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RGEQiiLw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UnhykoQi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pXHnMgg2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mHoaOtzg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SH3uw6Zt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SH3uw6Zt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6skxxWeb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mHoaOtzg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_l2B0zUig, 1, m, &cIf_l2B0zUig_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UnhykoQi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R2mT0IIL, 0, m, &cIf_R2mT0IIL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RGEQiiLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_R2mT0IIL, 1, m, &cIf_R2mT0IIL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3vHQuQWF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WehHQnjj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sZnBSW1u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WehHQnjj, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_45plQL05_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5nAYmnzC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_A8Zr6JIS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_w43Btk9P_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_u3i5lNdN_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3nRiryPu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3nRiryPu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_9giVkct1, 1, m, &cDelay_9giVkct1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l4kJ08VY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_9giVkct1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_9giVkct1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_45plQL05, 0, m, &cIf_45plQL05_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3nRiryPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_9giVkct1, 0, m, &cDelay_9giVkct1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l4kJ08VY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_9giVkct1, 0, m, &cDelay_9giVkct1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iPgdjpNa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Y1235VwN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_v7WikD03_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_C2l7mPnj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1yXeUu7k_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8hfUqa7A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8hfUqa7A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_u3i5lNdN_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1yXeUu7k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_45plQL05, 1, m, &cIf_45plQL05_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_v7WikD03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A8Zr6JIS, 0, m, &cIf_A8Zr6JIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Y1235VwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_A8Zr6JIS, 1, m, &cIf_A8Zr6JIS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w43Btk9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWn3rJPF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5nAYmnzC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fWn3rJPF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_tOKxDDBZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_80Cp335b_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Z038PjfK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mVmCggBn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pqXEUu8c_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ij2RqkGa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ij2RqkGa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rWGEtbNz, 1, m, &cDelay_rWGEtbNz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N29cKT9r_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rWGEtbNz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rWGEtbNz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_tOKxDDBZ, 0, m, &cIf_tOKxDDBZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ij2RqkGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rWGEtbNz, 0, m, &cDelay_rWGEtbNz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N29cKT9r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rWGEtbNz, 0, m, &cDelay_rWGEtbNz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PlPsbTjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CANOq5fu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wDQxOCqO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_rWKZiYIH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_llFc7g2L_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gmybj7Uq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_gmybj7Uq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pqXEUu8c_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_llFc7g2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tOKxDDBZ, 1, m, &cIf_tOKxDDBZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wDQxOCqO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z038PjfK, 0, m, &cIf_Z038PjfK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CANOq5fu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Z038PjfK, 1, m, &cIf_Z038PjfK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mVmCggBn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6UeR09yG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_80Cp335b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6UeR09yG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ze9YD0Lh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_12q989Om_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_NAGl4fPS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rHQecD4h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OzxBkBJP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ENkiD3Av_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ENkiD3Av_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_UGZJbkpr, 1, m, &cDelay_UGZJbkpr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JnW959rH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_UGZJbkpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_UGZJbkpr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ze9YD0Lh, 0, m, &cIf_ze9YD0Lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ENkiD3Av_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGZJbkpr, 0, m, &cDelay_UGZJbkpr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JnW959rH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_UGZJbkpr, 0, m, &cDelay_UGZJbkpr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H3VkWjE1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9GkXmcCh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rIijYJxc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g5UvYme6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mcUbnDeE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bZ6lpCK3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bZ6lpCK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_OzxBkBJP_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_mcUbnDeE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ze9YD0Lh, 1, m, &cIf_ze9YD0Lh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9GkXmcCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NAGl4fPS, 1, m, &cIf_NAGl4fPS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rIijYJxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_NAGl4fPS, 0, m, &cIf_NAGl4fPS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rHQecD4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KteZ0aWz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_12q989Om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KteZ0aWz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_zRDWkNm3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EHXPB4zn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DmkCRs1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tRBXPA9c_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Mi2QiimH_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_L8DpePAG_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_L8DpePAG_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_stMQYN8l, 1, m, &cDelay_stMQYN8l_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fi4Hk7eW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_stMQYN8l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_stMQYN8l, m);
  cIf_onMessage(_c, &Context(_c)->cIf_zRDWkNm3, 0, m, &cIf_zRDWkNm3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L8DpePAG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_stMQYN8l, 0, m, &cDelay_stMQYN8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fi4Hk7eW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_stMQYN8l, 0, m, &cDelay_stMQYN8l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YeVW6BOS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RsAA8kav_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aOLwU0ZC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vlpigaVm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pQn4Hifd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rSPpbcpW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rSPpbcpW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Mi2QiimH_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_pQn4Hifd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zRDWkNm3, 1, m, &cIf_zRDWkNm3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RsAA8kav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DmkCRs1M, 1, m, &cIf_DmkCRs1M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aOLwU0ZC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DmkCRs1M, 0, m, &cIf_DmkCRs1M_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tRBXPA9c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x3BXTbFk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EHXPB4zn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x3BXTbFk, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_VwmBxOHe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_voHnu8yT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_9Irb7xtY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7aY1P1kw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0srV5ika_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_i2RPhH76_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_i2RPhH76_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fklZafgk, 1, m, &cDelay_fklZafgk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WsJ0Eabm_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fklZafgk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fklZafgk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_VwmBxOHe, 0, m, &cIf_VwmBxOHe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_i2RPhH76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fklZafgk, 0, m, &cDelay_fklZafgk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WsJ0Eabm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fklZafgk, 0, m, &cDelay_fklZafgk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ggsY7UNO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SDrp5wUL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VIeJBG8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_odDQYAXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_4396ueX7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eqVUtRWV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eqVUtRWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0srV5ika_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_4396ueX7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_VwmBxOHe, 1, m, &cIf_VwmBxOHe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_SDrp5wUL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Irb7xtY, 1, m, &cIf_9Irb7xtY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_VIeJBG8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9Irb7xtY, 0, m, &cIf_9Irb7xtY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7aY1P1kw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kFMrlk7R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_voHnu8yT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kFMrlk7R, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_DqC5y9O4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_z4IQ3mcX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BTCoBWKc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_jNUFiQfO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_GvDiRqU0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OltTAOnn_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OltTAOnn_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_7224rNhR, 1, m, &cDelay_7224rNhR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_T3BU4D8B_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_7224rNhR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_7224rNhR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_DqC5y9O4, 0, m, &cIf_DqC5y9O4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OltTAOnn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_7224rNhR, 0, m, &cDelay_7224rNhR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T3BU4D8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_7224rNhR, 0, m, &cDelay_7224rNhR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wgSWRijI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PZVWFL2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_A6InS60d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qpYoeOEY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jfE2GhyW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_65efon2C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_65efon2C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_GvDiRqU0_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jfE2GhyW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DqC5y9O4, 1, m, &cIf_DqC5y9O4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1PZVWFL2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BTCoBWKc, 1, m, &cIf_BTCoBWKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A6InS60d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BTCoBWKc, 0, m, &cIf_BTCoBWKc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jNUFiQfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oQ3pGVQP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_z4IQ3mcX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_oQ3pGVQP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Y1GeHyFS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4uitkxQK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_4tic66nM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fUd2WEsg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fieauPrp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nwLBxREX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nwLBxREX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_knr7LOG6, 1, m, &cDelay_knr7LOG6_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lEoSCxlA_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_knr7LOG6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_knr7LOG6, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Y1GeHyFS, 0, m, &cIf_Y1GeHyFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nwLBxREX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_knr7LOG6, 0, m, &cDelay_knr7LOG6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lEoSCxlA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_knr7LOG6, 0, m, &cDelay_knr7LOG6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Cw8WjjAx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Bsd8NMMx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_50WJWhCp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DRif3N2a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3hNlxhqx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GMgMU77a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3hNlxhqx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Y1GeHyFS, 1, m, &cIf_Y1GeHyFS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GMgMU77a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fieauPrp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_50WJWhCp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4tic66nM, 0, m, &cIf_4tic66nM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Bsd8NMMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4tic66nM, 1, m, &cIf_4tic66nM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fUd2WEsg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Amup6ac7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4uitkxQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Amup6ac7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jmPcFBZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_E7Ihbds5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vhELm55x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_r2gMjRM5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9AUHH4Pf_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_c3J02h0l_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_c3J02h0l_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_EwYQNt2q, 1, m, &cDelay_EwYQNt2q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wha7wHdX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_EwYQNt2q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_EwYQNt2q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jmPcFBZr, 0, m, &cIf_jmPcFBZr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c3J02h0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_EwYQNt2q, 0, m, &cDelay_EwYQNt2q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_wha7wHdX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_EwYQNt2q, 0, m, &cDelay_EwYQNt2q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_EmtV3tn2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dLo55RkO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Vn9lNtIe_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U1gZip4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Olbhl3Tj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4wXR6sQ4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Olbhl3Tj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jmPcFBZr, 1, m, &cIf_jmPcFBZr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4wXR6sQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9AUHH4Pf_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_dLo55RkO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vhELm55x, 1, m, &cIf_vhELm55x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Vn9lNtIe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vhELm55x, 0, m, &cIf_vhELm55x_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_r2gMjRM5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5PX6IIL2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_E7Ihbds5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5PX6IIL2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_bUFL9L9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_k4dALmyH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_cvHrlWmD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xgIObn0w_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_emyafKuz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_OxyD1rGS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_OxyD1rGS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_GTqCtS7I, 1, m, &cDelay_GTqCtS7I_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_z0KGfdDR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_GTqCtS7I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GTqCtS7I, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bUFL9L9j, 0, m, &cIf_bUFL9L9j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_OxyD1rGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_GTqCtS7I, 0, m, &cDelay_GTqCtS7I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_z0KGfdDR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_GTqCtS7I, 0, m, &cDelay_GTqCtS7I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_34d2htQD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xAPicxjN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R0BeQlvF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wgz3ZmHA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FswcLyXx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_i2zcqVah_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FswcLyXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bUFL9L9j, 1, m, &cIf_bUFL9L9j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i2zcqVah_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_emyafKuz_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_xAPicxjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cvHrlWmD, 1, m, &cIf_cvHrlWmD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R0BeQlvF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_cvHrlWmD, 0, m, &cIf_cvHrlWmD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xgIObn0w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LE4uBWtt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_k4dALmyH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LE4uBWtt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Vyy4iKPR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_jgdLtVCb_sendMessage(_c, 0, m);
  cMsg_w0Nqebhg_sendMessage(_c, 0, m);
  cMsg_xJeeGHr3_sendMessage(_c, 0, m);
  cMsg_0yEUs7NN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fuc5ZDY9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_jgdLtVCb_sendMessage(_c, 0, m);
  cMsg_m9EJekSW_sendMessage(_c, 0, m);
  cMsg_uZ6V4RAO_sendMessage(_c, 0, m);
  cMsg_HKxMd6oE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_1uROW54d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_k60f2yiX_sendMessage(_c, 0, m);
  cMsg_m9EJekSW_sendMessage(_c, 0, m);
  cMsg_0yEUs7NN_sendMessage(_c, 0, m);
  cMsg_GMiFQyqv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_3skWpFDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_k60f2yiX_sendMessage(_c, 0, m);
  cMsg_jWbiP0BL_sendMessage(_c, 0, m);
  cMsg_xJeeGHr3_sendMessage(_c, 0, m);
  cMsg_U0lSQHE2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_c1VHrktV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_7dIBQinq_sendMessage(_c, 0, m);
  cMsg_HKxMd6oE_sendMessage(_c, 0, m);
  cMsg_W5UHWeVB_sendMessage(_c, 0, m);
  cMsg_xJeeGHr3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GotdZZ69_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_7dIBQinq_sendMessage(_c, 0, m);
  cMsg_U0lSQHE2_sendMessage(_c, 0, m);
  cMsg_m9EJekSW_sendMessage(_c, 0, m);
  cMsg_mp2CKZ9L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AqsEcCIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SKTz8m6l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m5iurrew_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VvY26xHl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SKTz8m6l_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_m5iurrew_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_a2TE0d1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SLQpR0sf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JyXUGpwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gIyX1f7S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SLQpR0sf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JyXUGpwB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Be51VHXO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pXHnMgg2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V4fHgDKw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_44CT0nVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pXHnMgg2_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_V4fHgDKw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_jgdLtVCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_AqsEcCIf_sendMessage(_c, 0, m);
  cMsg_gIyX1f7S_sendMessage(_c, 0, m);
  cMsg_44CT0nVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_k60f2yiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_VvY26xHl_sendMessage(_c, 0, m);
  cMsg_a2TE0d1j_sendMessage(_c, 0, m);
  cMsg_44CT0nVs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7dIBQinq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_VvY26xHl_sendMessage(_c, 0, m);
  cMsg_gIyX1f7S_sendMessage(_c, 0, m);
  cMsg_Be51VHXO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oGscB1bo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C2l7mPnj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iPgdjpNa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oYiTG7op_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_C2l7mPnj_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iPgdjpNa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5y3NUkrw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rWKZiYIH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PlPsbTjt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BUap3GE7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_rWKZiYIH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_PlPsbTjt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Qs1X1YOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g5UvYme6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H3VkWjE1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_H3PdnlC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g5UvYme6_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H3VkWjE1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m9EJekSW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_oYiTG7op_sendMessage(_c, 0, m);
  cMsg_BUap3GE7_sendMessage(_c, 0, m);
  cMsg_H3PdnlC0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_w0Nqebhg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_oYiTG7op_sendMessage(_c, 0, m);
  cMsg_5y3NUkrw_sendMessage(_c, 0, m);
  cMsg_Qs1X1YOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jWbiP0BL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_oGscB1bo_sendMessage(_c, 0, m);
  cMsg_BUap3GE7_sendMessage(_c, 0, m);
  cMsg_Qs1X1YOs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_p1hr84WR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DRif3N2a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Cw8WjjAx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YaYgCAG4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_DRif3N2a_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Cw8WjjAx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vDzTNd03_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U1gZip4E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EmtV3tn2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TqjFzjQq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U1gZip4E_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_EmtV3tn2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3LEmCSY1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wgz3ZmHA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_34d2htQD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_e9W0nFs5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_wgz3ZmHA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_34d2htQD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U0lSQHE2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_p1hr84WR_sendMessage(_c, 0, m);
  cMsg_TqjFzjQq_sendMessage(_c, 0, m);
  cMsg_e9W0nFs5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HKxMd6oE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_YaYgCAG4_sendMessage(_c, 0, m);
  cMsg_vDzTNd03_sendMessage(_c, 0, m);
  cMsg_e9W0nFs5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0yEUs7NN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_YaYgCAG4_sendMessage(_c, 0, m);
  cMsg_TqjFzjQq_sendMessage(_c, 0, m);
  cMsg_3LEmCSY1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8GSRJ9DP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vlpigaVm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YeVW6BOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_djBxlTaC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vlpigaVm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_YeVW6BOS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QoMYdHOR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_odDQYAXO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ggsY7UNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1dvQFsPa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_odDQYAXO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ggsY7UNO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PdaM4G8u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qpYoeOEY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wgSWRijI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yts2i9UK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qpYoeOEY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wgSWRijI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xJeeGHr3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_djBxlTaC_sendMessage(_c, 0, m);
  cMsg_1dvQFsPa_sendMessage(_c, 0, m);
  cMsg_yts2i9UK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_uZ6V4RAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_djBxlTaC_sendMessage(_c, 0, m);
  cMsg_QoMYdHOR_sendMessage(_c, 0, m);
  cMsg_PdaM4G8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mp2CKZ9L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_8GSRJ9DP_sendMessage(_c, 0, m);
  cMsg_QoMYdHOR_sendMessage(_c, 0, m);
  cMsg_yts2i9UK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_W5UHWeVB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_oGscB1bo_sendMessage(_c, 0, m);
  cMsg_5y3NUkrw_sendMessage(_c, 0, m);
  cMsg_H3PdnlC0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GMiFQyqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_8GSRJ9DP_sendMessage(_c, 0, m);
  cMsg_1dvQFsPa_sendMessage(_c, 0, m);
  cMsg_PdaM4G8u_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_HJLja1XM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_hLKqfRbJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BFptjDcl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_llFT4YZA, 0, m, &cSlice_llFT4YZA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Ol1yLq8f_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_llFT4YZA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_O8Ra0D6j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_O8Ra0D6j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_WJJsmunl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_O8Ra0D6j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_O8Ra0D6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_gqODNkav_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CrfFF1Pv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xqIjzxIC, 0, m, &cSlice_xqIjzxIC_sendMessage);
      break;
    }
    default: {
      cSwitchcase_mzcfhml1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xqIjzxIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sAPgyAqw_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sAPgyAqw_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_urQ5YvlS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sAPgyAqw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sAPgyAqw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ca30o5aF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_mzcfhml1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_2IBRkYLz, 0, m, &cSlice_2IBRkYLz_sendMessage);
      break;
    }
    default: {
      cSwitchcase_BFptjDcl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_2IBRkYLz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8bi6vIeF_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8bi6vIeF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_F6FlagqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8bi6vIeF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_8bi6vIeF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_N7BQQldX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Ol1yLq8f_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zfaKm5Fn, 0, m, &cSlice_zfaKm5Fn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_zifOJR6p_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_zfaKm5Fn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_3c2nax7s_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_3c2nax7s_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_X9myvkOo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_3c2nax7s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_3c2nax7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_91S31Xcc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zifOJR6p_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_apjnyVnx, 0, m, &cSlice_apjnyVnx_sendMessage);
      break;
    }
    default: {
      cSwitchcase_psYKOyEF_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_apjnyVnx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_u7xRAUaI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_u7xRAUaI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_MwJZ4u8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_u7xRAUaI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_u7xRAUaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Mfy5ktZO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_B1QgYU6W_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_duDpY8WT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_duDpY8WT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_JnLQwW5R, 1, m, &cDelay_JnLQwW5R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5fJzpwhF_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_JnLQwW5R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_JnLQwW5R, m);
  cMsg_VF6QSt8c_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_duDpY8WT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_JnLQwW5R, 0, m, &cDelay_JnLQwW5R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5fJzpwhF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_JnLQwW5R, 0, m, &cDelay_JnLQwW5R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_QJ2ksOjW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KAu7ZK39, HV_BINOP_SUBTRACT, 0, m, &cBinop_KAu7ZK39_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_mBCJHjfJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1OMW4EeT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_sEK779YJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1OMW4EeT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_kksJiUaw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QJ2ksOjW, 0, m, &cVar_QJ2ksOjW_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ZjkUFwqk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WK7kLrjT_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zB5fGtGm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_xIqbnrgF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KAu7ZK39_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QgG56C1w_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QgG56C1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Ole7Y4Nq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ole7Y4Nq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_kkNKw6vr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_u11X0jZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BFNQtSeg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JbUJDYiB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JbUJDYiB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_k9fjIo7g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_BFNQtSeg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mBCJHjfJ, 1, m, &cIf_mBCJHjfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_AScPSCUs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sEK779YJ, 1, m, &cIf_sEK779YJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k9fjIo7g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mBCJHjfJ, 0, m, &cIf_mBCJHjfJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_kkNKw6vr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_sEK779YJ, 0, m, &cIf_sEK779YJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_xIqbnrgF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_QJ2ksOjW, 0, m, &cVar_QJ2ksOjW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WK7kLrjT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_zB5fGtGm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KAu7ZK39, HV_BINOP_SUBTRACT, 1, m, &cBinop_KAu7ZK39_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1OMW4EeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_q5pfCqxf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_psYKOyEF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_LuUBDVnA, 0, m, &cSlice_LuUBDVnA_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_LuUBDVnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_fRaxDnfH_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_fRaxDnfH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sbW5KNdv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_fRaxDnfH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_fRaxDnfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_05LfDfJX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v7sXQNoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WgWslSHv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IFWjT4at_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rsY2H9Ff, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_lzjb1pTz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JM3hY38V, 0, m, &cVar_JM3hY38V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hLKqfRbJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zREY1SfF, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_JeyrZ9mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8ng0tFkK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_eq3LjMSC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_B1QgYU6W_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_VF6QSt8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RfORtUQ1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_8ng0tFkK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RfORtUQ1, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_9PYeYbaK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_ja58W9Zm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ja58W9Zm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Tpsz11dt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Tpsz11dt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RsX1NoMl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_bXYh4yTv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5nxG9YoM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Uk3kaKCv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EdydHkrE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_WzuETTt3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j8dOkJWd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_o5IInfu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_tmAMycYZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_bBlv1pdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OAC3wJg5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_CAgNaqfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_GrC88SMo_sendMessage);
  cMsg_nlkaU7JX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_GrC88SMo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CAgNaqfD, 1, m, &cVar_CAgNaqfD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fGVlq1m6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YnHXBBzv_sendMessage(_c, 0, m);
  cMsg_WMGXhtEy_sendMessage(_c, 0, m);
  cMsg_MSRaj4hB_sendMessage(_c, 0, m);
  cMsg_5j8dPEcQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_OjbWPjkg_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_xqVj3oQ2, 0, m, &cSlice_xqVj3oQ2_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_xqVj3oQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rJu90RYq_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rJu90RYq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JVVr0Q7E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rJu90RYq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rJu90RYq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_w0gOPJeG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_aN2XPNCh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_mIOcixfI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mIOcixfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_cQkMfuC1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cQkMfuC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_c4oBmAkM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_c4oBmAkM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VQxryQEO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8p8m3lpB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8p8m3lpB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_NhtiUcSQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VQxryQEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mDUgBiZg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_mDUgBiZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_WxmsvLxc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NhtiUcSQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ur1gzdBf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ur1gzdBf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_d54LEgJ5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WxmsvLxc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7sdSrNsL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_d54LEgJ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_AM5vryKR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7sdSrNsL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vLgVHuBp, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AM5vryKR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ocj7vzbK, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_tn2ePXqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jl844U5p_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Q63Yi7sM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZrStmkZw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_gBcyRDqD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tZ1pvQTh_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ijcorw6R_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bzroViaA_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gbVUHfnR_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YTMeFsqR_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KQFhcPp3_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_tZ1pvQTh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dCFteTAU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Ijcorw6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KnkP1Fif_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_bzroViaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GhiaxnoP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_gbVUHfnR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D5htvupk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_YTMeFsqR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_oMpr5Hcp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KQFhcPp3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6JjQ3EcG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_MNKXkYdw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_oStnDGWe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Q4MJX2wv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_xd4OUI7l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VgA16zbY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_4QzYrHhs_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_4QzYrHhs_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_52YtQ6uc, 1, m, &cDelay_52YtQ6uc_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bWsI7K3r_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_52YtQ6uc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_52YtQ6uc, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MNKXkYdw, 0, m, &cIf_MNKXkYdw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4QzYrHhs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_52YtQ6uc, 0, m, &cDelay_52YtQ6uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bWsI7K3r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_52YtQ6uc, 0, m, &cDelay_52YtQ6uc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KA64x3lu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9t9cli0O_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MsbOKqP9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lSc8FYem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HjVfztUZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LYE5xpe1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LYE5xpe1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VgA16zbY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_HjVfztUZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MNKXkYdw, 1, m, &cIf_MNKXkYdw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9t9cli0O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q4MJX2wv, 1, m, &cIf_Q4MJX2wv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MsbOKqP9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Q4MJX2wv, 0, m, &cIf_Q4MJX2wv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xd4OUI7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tJWtFdSf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_oStnDGWe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_tJWtFdSf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_Ov1Tki7s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ehmPRPDi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_FTlsW5dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_mQfPb0xe_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_R39GqS9F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oWsloc3Q_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oWsloc3Q_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_PuhnlftT, 1, m, &cDelay_PuhnlftT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uYiqBEbk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_PuhnlftT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_PuhnlftT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_Ov1Tki7s, 0, m, &cIf_Ov1Tki7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oWsloc3Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_PuhnlftT, 0, m, &cDelay_PuhnlftT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uYiqBEbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_PuhnlftT, 0, m, &cDelay_PuhnlftT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R0m8Bn10_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MBIIdzo8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UppCrZEF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SSWBTVN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vWSYo5Tm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QohktwJY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QohktwJY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_R39GqS9F_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vWSYo5Tm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Ov1Tki7s, 1, m, &cIf_Ov1Tki7s_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MBIIdzo8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FTlsW5dv, 1, m, &cIf_FTlsW5dv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UppCrZEF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FTlsW5dv, 0, m, &cIf_FTlsW5dv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mQfPb0xe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hq1ABSg2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ehmPRPDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hq1ABSg2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_6Sh2QI8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_uNk8lstA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_volgETEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_soULV7WU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_W1krwU10_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZEjAgG7U_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZEjAgG7U_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_e0l0RgNs, 1, m, &cDelay_e0l0RgNs_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pHs9na0g_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_e0l0RgNs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_e0l0RgNs, m);
  cIf_onMessage(_c, &Context(_c)->cIf_6Sh2QI8d, 0, m, &cIf_6Sh2QI8d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZEjAgG7U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_e0l0RgNs, 0, m, &cDelay_e0l0RgNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pHs9na0g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_e0l0RgNs, 0, m, &cDelay_e0l0RgNs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_jUCBZXaN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aZZebkBw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QwE4onfU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_YiQjfOD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BOnaaYbN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1XcvxNLG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1XcvxNLG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_W1krwU10_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BOnaaYbN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_6Sh2QI8d, 1, m, &cIf_6Sh2QI8d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_QwE4onfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_volgETEt, 0, m, &cIf_volgETEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aZZebkBw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_volgETEt, 1, m, &cIf_volgETEt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_soULV7WU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_437k1aT2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uNk8lstA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_437k1aT2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_N6luCJ95_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_p70IByUl_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gr8s9RXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_osrYZdT1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Xt5GlPch_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_ZSBPNk13_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_ZSBPNk13_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ALHcyMFy, 1, m, &cDelay_ALHcyMFy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cWvubc3i_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ALHcyMFy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ALHcyMFy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_N6luCJ95, 0, m, &cIf_N6luCJ95_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZSBPNk13_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ALHcyMFy, 0, m, &cDelay_ALHcyMFy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cWvubc3i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ALHcyMFy, 0, m, &cDelay_ALHcyMFy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vsb2Jx8e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_scOP13s3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oyQtgiUO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pE0Zfi6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rHDlWy4E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fiDT1dI9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rHDlWy4E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N6luCJ95, 1, m, &cIf_N6luCJ95_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fiDT1dI9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Xt5GlPch_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_scOP13s3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gr8s9RXm, 1, m, &cIf_gr8s9RXm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oyQtgiUO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gr8s9RXm, 0, m, &cIf_gr8s9RXm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_osrYZdT1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4oL7ZEfr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_p70IByUl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_4oL7ZEfr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_XLn2Pfvl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_S85ka6BN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G2Wt1WGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_27h8huyy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_VLRhDh3K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_3khu34hJ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_3khu34hJ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_eMxqCY9R, 1, m, &cDelay_eMxqCY9R_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7Q3ML5BN_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_eMxqCY9R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_eMxqCY9R, m);
  cIf_onMessage(_c, &Context(_c)->cIf_XLn2Pfvl, 0, m, &cIf_XLn2Pfvl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3khu34hJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_eMxqCY9R, 0, m, &cDelay_eMxqCY9R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7Q3ML5BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_eMxqCY9R, 0, m, &cDelay_eMxqCY9R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_JoXhAEID_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Wxx9H6dM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bDF4nPPd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_79ghYszg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vOHsi5Na_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Kinx3VsH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Kinx3VsH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_VLRhDh3K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vOHsi5Na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XLn2Pfvl, 1, m, &cIf_XLn2Pfvl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bDF4nPPd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G2Wt1WGU, 0, m, &cIf_G2Wt1WGU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wxx9H6dM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G2Wt1WGU, 1, m, &cIf_G2Wt1WGU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_27h8huyy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zGKQYMr7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_S85ka6BN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_zGKQYMr7, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3JcjuiNH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_7Ig1X7A9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_c04Lq1Rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lvVhnLeT_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_fvUzS4kF_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_2rz8MC5G_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_2rz8MC5G_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_sE3fTqya, 1, m, &cDelay_sE3fTqya_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G5grqABS_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_sE3fTqya_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_sE3fTqya, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3JcjuiNH, 0, m, &cIf_3JcjuiNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2rz8MC5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_sE3fTqya, 0, m, &cDelay_sE3fTqya_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G5grqABS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_sE3fTqya, 0, m, &cDelay_sE3fTqya_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tHRZUzlJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NoksRU5o_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3nfUDCbX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NtwFB4V4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qfFRMrLL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3O2W6I1r_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3O2W6I1r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_fvUzS4kF_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_qfFRMrLL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3JcjuiNH, 1, m, &cIf_3JcjuiNH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3nfUDCbX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c04Lq1Rm, 0, m, &cIf_c04Lq1Rm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NoksRU5o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_c04Lq1Rm, 1, m, &cIf_c04Lq1Rm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lvVhnLeT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EPkRW1uP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7Ig1X7A9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_EPkRW1uP, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_nxcwJEEx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Jbjfp0fj_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_f8mJhpRC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5IZYSD51_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PVUxgxpy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_mYlPUNOl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_mYlPUNOl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_hjjmAMMC, 1, m, &cDelay_hjjmAMMC_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w9f2a9NO_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_hjjmAMMC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_hjjmAMMC, m);
  cIf_onMessage(_c, &Context(_c)->cIf_nxcwJEEx, 0, m, &cIf_nxcwJEEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mYlPUNOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_hjjmAMMC, 0, m, &cDelay_hjjmAMMC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w9f2a9NO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_hjjmAMMC, 0, m, &cDelay_hjjmAMMC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Gxl3xDCq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R4Bz4DSs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tHULAvGJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bCWxUapX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3QCCBCTj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IrFSNvq1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3QCCBCTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_nxcwJEEx, 1, m, &cIf_nxcwJEEx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IrFSNvq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_PVUxgxpy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_R4Bz4DSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f8mJhpRC, 1, m, &cIf_f8mJhpRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tHULAvGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_f8mJhpRC, 0, m, &cIf_f8mJhpRC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5IZYSD51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wq1AhdFy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Jbjfp0fj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wq1AhdFy, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RyYkvXyJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Yugxg5SM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_WMihCLXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_WyG45X8F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_CIduO3D1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_w0OAuO9O_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_w0OAuO9O_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_NIAxwE0S, 1, m, &cDelay_NIAxwE0S_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_406vrZsy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_NIAxwE0S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_NIAxwE0S, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RyYkvXyJ, 0, m, &cIf_RyYkvXyJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w0OAuO9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_NIAxwE0S, 0, m, &cDelay_NIAxwE0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_406vrZsy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_NIAxwE0S, 0, m, &cDelay_NIAxwE0S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_OCUaZdr4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oCt7xNhB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_K9UXPLKr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_edyfff91_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_EwHBKpIy_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IXp0UCef_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IXp0UCef_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_CIduO3D1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_EwHBKpIy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RyYkvXyJ, 1, m, &cIf_RyYkvXyJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_K9UXPLKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMihCLXf, 0, m, &cIf_WMihCLXf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oCt7xNhB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_WMihCLXf, 1, m, &cIf_WMihCLXf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WyG45X8F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AXn5EXnY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Yugxg5SM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AXn5EXnY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_AGVfHqgZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PMESJb9j_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BfSqETYR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_40KjxCFh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cHv1pvs7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_xoiRSahX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_xoiRSahX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_quP7hYM7, 1, m, &cDelay_quP7hYM7_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BMMJsrTZ_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_quP7hYM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_quP7hYM7, m);
  cIf_onMessage(_c, &Context(_c)->cIf_AGVfHqgZ, 0, m, &cIf_AGVfHqgZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xoiRSahX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_quP7hYM7, 0, m, &cDelay_quP7hYM7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BMMJsrTZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_quP7hYM7, 0, m, &cDelay_quP7hYM7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_76xnRDye_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RJtoe406_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R2b67bwj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_A6qJAGdq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_83ALDIZK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aFGvLSiU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aFGvLSiU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cHv1pvs7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_83ALDIZK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AGVfHqgZ, 1, m, &cIf_AGVfHqgZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R2b67bwj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BfSqETYR, 0, m, &cIf_BfSqETYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RJtoe406_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BfSqETYR, 1, m, &cIf_BfSqETYR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_40KjxCFh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hxeeEjSG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PMESJb9j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_hxeeEjSG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UWe6Kqb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_AaCCBiPG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xNoNKby4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YRI2k4j9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Bv7oHB3R_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_HcaTzlFt_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_HcaTzlFt_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_njuhCvhH, 1, m, &cDelay_njuhCvhH_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0IrkZX8n_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_njuhCvhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_njuhCvhH, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UWe6Kqb3, 0, m, &cIf_UWe6Kqb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HcaTzlFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_njuhCvhH, 0, m, &cDelay_njuhCvhH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0IrkZX8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_njuhCvhH, 0, m, &cDelay_njuhCvhH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MPcislDJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_11W8ZJpE_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7iEJNlJD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fn7NWpur_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vWkW4Pcf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MD9XY8gC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MD9XY8gC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Bv7oHB3R_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_vWkW4Pcf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UWe6Kqb3, 1, m, &cIf_UWe6Kqb3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7iEJNlJD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xNoNKby4, 0, m, &cIf_xNoNKby4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_11W8ZJpE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xNoNKby4, 1, m, &cIf_xNoNKby4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YRI2k4j9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_33yab13v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_AaCCBiPG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_33yab13v, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZtNPPhHm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1MPq2FwV_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_OkwdSzDD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hchENcZD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vQeMKqDq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wORqE9Xl_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wORqE9Xl_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B4BVz9mB, 1, m, &cDelay_B4BVz9mB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_79bISsAw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_B4BVz9mB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B4BVz9mB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZtNPPhHm, 0, m, &cIf_ZtNPPhHm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wORqE9Xl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B4BVz9mB, 0, m, &cDelay_B4BVz9mB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_79bISsAw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B4BVz9mB, 0, m, &cDelay_B4BVz9mB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1RNcNOn0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7ZrQ4SWr_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fa7itCbR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_sRXgbTgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Nt19zDwZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_w8vjdmid_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Nt19zDwZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZtNPPhHm, 1, m, &cIf_ZtNPPhHm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_w8vjdmid_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vQeMKqDq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_7ZrQ4SWr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OkwdSzDD, 1, m, &cIf_OkwdSzDD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fa7itCbR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OkwdSzDD, 0, m, &cIf_OkwdSzDD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hchENcZD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nEOA8aI9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1MPq2FwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nEOA8aI9, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_8Aj4p442_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fIxFOgdf_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_qzQ0eRjR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_U9muHJ3d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_cI2648sL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_RBOOjh5K_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_RBOOjh5K_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_D1RUCXzt, 1, m, &cDelay_D1RUCXzt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kdy6LQP5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_D1RUCXzt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_D1RUCXzt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_8Aj4p442, 0, m, &cIf_8Aj4p442_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_RBOOjh5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_D1RUCXzt, 0, m, &cDelay_D1RUCXzt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kdy6LQP5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_D1RUCXzt, 0, m, &cDelay_D1RUCXzt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ghGTARPH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dQtnaWr7_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_c4BTDTRi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nXIyQKf3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ypt9tPXf_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Ara5D8vL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Ara5D8vL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_cI2648sL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ypt9tPXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_8Aj4p442, 1, m, &cIf_8Aj4p442_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_c4BTDTRi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qzQ0eRjR, 0, m, &cIf_qzQ0eRjR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dQtnaWr7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qzQ0eRjR, 1, m, &cIf_qzQ0eRjR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_U9muHJ3d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HkB7Kaxa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_fIxFOgdf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HkB7Kaxa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dCFteTAU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_mJsrM9K1_sendMessage(_c, 0, m);
  cMsg_hs5Kav7N_sendMessage(_c, 0, m);
  cMsg_K70BR3wi_sendMessage(_c, 0, m);
  cMsg_g0vfxdPM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KnkP1Fif_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_mJsrM9K1_sendMessage(_c, 0, m);
  cMsg_2RWpyqu4_sendMessage(_c, 0, m);
  cMsg_UniZWDZr_sendMessage(_c, 0, m);
  cMsg_zBExYgCz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_GhiaxnoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_RwzE4Myb_sendMessage(_c, 0, m);
  cMsg_2RWpyqu4_sendMessage(_c, 0, m);
  cMsg_g0vfxdPM_sendMessage(_c, 0, m);
  cMsg_NYTX5cNy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_D5htvupk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_RwzE4Myb_sendMessage(_c, 0, m);
  cMsg_QRIa52mh_sendMessage(_c, 0, m);
  cMsg_K70BR3wi_sendMessage(_c, 0, m);
  cMsg_Pdc3CDM7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_oMpr5Hcp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_twNRNKOj_sendMessage(_c, 0, m);
  cMsg_zBExYgCz_sendMessage(_c, 0, m);
  cMsg_S1QomBS0_sendMessage(_c, 0, m);
  cMsg_K70BR3wi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6JjQ3EcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_twNRNKOj_sendMessage(_c, 0, m);
  cMsg_Pdc3CDM7_sendMessage(_c, 0, m);
  cMsg_2RWpyqu4_sendMessage(_c, 0, m);
  cMsg_Tps0qw8Z_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KBvoMNgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lSc8FYem_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KA64x3lu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o0Sgkyn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lSc8FYem_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KA64x3lu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_t4YmJulT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SSWBTVN5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R0m8Bn10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AwNmr64C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_SSWBTVN5_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_R0m8Bn10_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lKVo5zG8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YiQjfOD0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jUCBZXaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_n6FrLamK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_YiQjfOD0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_jUCBZXaN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mJsrM9K1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_KBvoMNgN_sendMessage(_c, 0, m);
  cMsg_AwNmr64C_sendMessage(_c, 0, m);
  cMsg_n6FrLamK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RwzE4Myb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_o0Sgkyn6_sendMessage(_c, 0, m);
  cMsg_t4YmJulT_sendMessage(_c, 0, m);
  cMsg_n6FrLamK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_twNRNKOj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_o0Sgkyn6_sendMessage(_c, 0, m);
  cMsg_AwNmr64C_sendMessage(_c, 0, m);
  cMsg_lKVo5zG8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jlU64pGe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pE0Zfi6g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vsb2Jx8e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wDiH82u1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_pE0Zfi6g_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_vsb2Jx8e_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_CyZtMLYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_79ghYszg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JoXhAEID_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_E0waatgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_79ghYszg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_JoXhAEID_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9G8279JI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NtwFB4V4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tHRZUzlJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lSwCCFJ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NtwFB4V4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tHRZUzlJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_2RWpyqu4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_wDiH82u1_sendMessage(_c, 0, m);
  cMsg_E0waatgG_sendMessage(_c, 0, m);
  cMsg_lSwCCFJ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_hs5Kav7N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_wDiH82u1_sendMessage(_c, 0, m);
  cMsg_CyZtMLYg_sendMessage(_c, 0, m);
  cMsg_9G8279JI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QRIa52mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_jlU64pGe_sendMessage(_c, 0, m);
  cMsg_E0waatgG_sendMessage(_c, 0, m);
  cMsg_9G8279JI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HgAorwKf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fn7NWpur_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MPcislDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_c7UtJ17Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fn7NWpur_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MPcislDJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nIIs7bph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sRXgbTgX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1RNcNOn0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ts04Fnyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_sRXgbTgX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_1RNcNOn0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GCnT0if5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nXIyQKf3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ghGTARPH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_epN3Oc54_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nXIyQKf3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ghGTARPH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Pdc3CDM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_HgAorwKf_sendMessage(_c, 0, m);
  cMsg_ts04Fnyh_sendMessage(_c, 0, m);
  cMsg_epN3Oc54_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_zBExYgCz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_c7UtJ17Q_sendMessage(_c, 0, m);
  cMsg_nIIs7bph_sendMessage(_c, 0, m);
  cMsg_epN3Oc54_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_g0vfxdPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_c7UtJ17Q_sendMessage(_c, 0, m);
  cMsg_ts04Fnyh_sendMessage(_c, 0, m);
  cMsg_GCnT0if5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JJ0G2Hk1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bCWxUapX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Gxl3xDCq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_k7WX7uMr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_bCWxUapX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Gxl3xDCq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5NMwGjmo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_edyfff91_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OCUaZdr4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HX6e70mX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_edyfff91_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_OCUaZdr4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dSjv7YuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A6qJAGdq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_76xnRDye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3TSAFjvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_A6qJAGdq_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_76xnRDye_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K70BR3wi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_k7WX7uMr_sendMessage(_c, 0, m);
  cMsg_HX6e70mX_sendMessage(_c, 0, m);
  cMsg_3TSAFjvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_UniZWDZr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_k7WX7uMr_sendMessage(_c, 0, m);
  cMsg_5NMwGjmo_sendMessage(_c, 0, m);
  cMsg_dSjv7YuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Tps0qw8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_JJ0G2Hk1_sendMessage(_c, 0, m);
  cMsg_5NMwGjmo_sendMessage(_c, 0, m);
  cMsg_3TSAFjvR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_S1QomBS0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_jlU64pGe_sendMessage(_c, 0, m);
  cMsg_CyZtMLYg_sendMessage(_c, 0, m);
  cMsg_lSwCCFJ8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NYTX5cNy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_JJ0G2Hk1_sendMessage(_c, 0, m);
  cMsg_HX6e70mX_sendMessage(_c, 0, m);
  cMsg_dSjv7YuL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_0QlRTjto_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wB5ss3R0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_IEYp68Yi_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5duthp3f, 0, m, &cSlice_5duthp3f_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wXEvCYrZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_5duthp3f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Aex09S2m_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Aex09S2m_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_dCjjf22c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Aex09S2m_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_Aex09S2m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0CnjV5es_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_y1wv3DDc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GB2gfwOb, 0, m, &cSlice_GB2gfwOb_sendMessage);
      break;
    }
    default: {
      cSwitchcase_X7GdrW73_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GB2gfwOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_sc47i4vX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_sc47i4vX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_v1NcJ2xK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sc47i4vX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_sc47i4vX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EZ9IZk07_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_X7GdrW73_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_8h1wVNrg, 0, m, &cSlice_8h1wVNrg_sendMessage);
      break;
    }
    default: {
      cSwitchcase_IEYp68Yi_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_8h1wVNrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UX8Ep7pt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UX8Ep7pt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_HwxfjEpU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UX8Ep7pt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_UX8Ep7pt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o47azyYh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wXEvCYrZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_b2GMn6Kf, 0, m, &cSlice_b2GMn6Kf_sendMessage);
      break;
    }
    default: {
      cSwitchcase_wGIQf7or_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_b2GMn6Kf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_iR0mZOyh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_iR0mZOyh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_sYIMqyLJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_iR0mZOyh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_iR0mZOyh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nRBUgCin_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_wGIQf7or_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_y7sIqsMG, 0, m, &cSlice_y7sIqsMG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_1uqrBv2F_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_y7sIqsMG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_t4yGAOFR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_t4yGAOFR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_vhmyuMDW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_t4yGAOFR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_t4yGAOFR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UT3t97H0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Y2F9svU6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_YJma5dDS_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_YJma5dDS_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Bq4YylO2, 1, m, &cDelay_Bq4YylO2_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oXnAc2r8_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Bq4YylO2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Bq4YylO2, m);
  cMsg_S9rFprYB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YJma5dDS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bq4YylO2, 0, m, &cDelay_Bq4YylO2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oXnAc2r8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Bq4YylO2, 0, m, &cDelay_Bq4YylO2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_4DXSkRZH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ldrZ9rsG, HV_BINOP_SUBTRACT, 0, m, &cBinop_ldrZ9rsG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_pgMppPYg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o5ovvh4l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Hke4QqX2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_o5ovvh4l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_YC3GgUsK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4DXSkRZH, 0, m, &cVar_4DXSkRZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_myiR8KhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0GkMAa8Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vxWEM3cS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Minom7rE_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ldrZ9rsG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7WBTsiNC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_7WBTsiNC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_ZJSmgfW0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZJSmgfW0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_nfXW4Y4j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_UnSl8Uc3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Ao35OD9E_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dz5eUmCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dz5eUmCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qUsTpXfD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Ao35OD9E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_pgMppPYg, 1, m, &cIf_pgMppPYg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nkM1BnvJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hke4QqX2, 1, m, &cIf_Hke4QqX2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qUsTpXfD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_pgMppPYg, 0, m, &cIf_pgMppPYg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_nfXW4Y4j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Hke4QqX2, 0, m, &cIf_Hke4QqX2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0GkMAa8Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_Minom7rE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_4DXSkRZH, 0, m, &cVar_4DXSkRZH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_vxWEM3cS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ldrZ9rsG, HV_BINOP_SUBTRACT, 1, m, &cBinop_ldrZ9rsG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_o5ovvh4l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Cebs6eJz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1uqrBv2F_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_YOH4ygUq, 0, m, &cSlice_YOH4ygUq_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_YOH4ygUq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AitklUiI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AitklUiI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_S5fobO4Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AitklUiI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AitklUiI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EfoRBQJp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Jl844U5p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_GeARnWNh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ZrStmkZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r4SvA1pf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_xdCVIDFu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q63Yi7sM, 0, m, &cVar_Q63Yi7sM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wB5ss3R0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XWFdzROz, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LBcdQk3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gNPOyjNQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Y6fcNLl2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Y2F9svU6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_S9rFprYB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o8S4vgbQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_gNPOyjNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_o8S4vgbQ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cXuFOwnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_bIX2m9cF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_bIX2m9cF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_IpYhaS7y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_IpYhaS7y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_dZeitjSt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_27NkG81R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fx4CIeGX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_6O8UplwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_yW63TQX1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kX8nGbrB_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GZDYg2hD_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XV4RKUg3_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GehKkR5W_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KBNwvKhY_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jjqMYmDh_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_IpIGNX9p_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_GZDYg2hD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cJQDnOlD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_XV4RKUg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qkFk5THL_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_GehKkR5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4FoZPl8s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KBNwvKhY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PmhfUGqa_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_jjqMYmDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZEzliAXY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_IpIGNX9p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v1e7bfVQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_bp6tdwH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_zzpa8eLm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_x1754XSx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rh9rEIFC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FE4IZ60C_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hWZwAJ8j_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hWZwAJ8j_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_qJNtfjoF, 1, m, &cDelay_qJNtfjoF_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eQk9ofmg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_qJNtfjoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_qJNtfjoF, m);
  cIf_onMessage(_c, &Context(_c)->cIf_bp6tdwH4, 0, m, &cIf_bp6tdwH4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hWZwAJ8j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_qJNtfjoF, 0, m, &cDelay_qJNtfjoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eQk9ofmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_qJNtfjoF, 0, m, &cDelay_qJNtfjoF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ldU6JB6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0osdvm5c_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r5JRr712_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_R1UE9Cgu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_yg9Kx09P_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RkEUwtMd_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yg9Kx09P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_bp6tdwH4, 1, m, &cIf_bp6tdwH4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RkEUwtMd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FE4IZ60C_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_0osdvm5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x1754XSx, 1, m, &cIf_x1754XSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_r5JRr712_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_x1754XSx, 0, m, &cIf_x1754XSx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rh9rEIFC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XJPZ4dP4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_zzpa8eLm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XJPZ4dP4, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_MtH6xhcR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5fVjJcSs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_o1Vhu9s4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NQFN3NNi_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_lDs7sE3e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_bfaGVdxi_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_bfaGVdxi_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_nTZVHrLb, 1, m, &cDelay_nTZVHrLb_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iK0qh7xt_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_nTZVHrLb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_nTZVHrLb, m);
  cIf_onMessage(_c, &Context(_c)->cIf_MtH6xhcR, 0, m, &cIf_MtH6xhcR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_bfaGVdxi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_nTZVHrLb, 0, m, &cDelay_nTZVHrLb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iK0qh7xt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_nTZVHrLb, 0, m, &cDelay_nTZVHrLb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HcbJume2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZSYHiPy6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yIuHKifr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xfkzyXtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NGvuMSNu_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TtJB5z0N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_TtJB5z0N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_lDs7sE3e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_NGvuMSNu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MtH6xhcR, 1, m, &cIf_MtH6xhcR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_yIuHKifr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o1Vhu9s4, 0, m, &cIf_o1Vhu9s4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZSYHiPy6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_o1Vhu9s4, 1, m, &cIf_o1Vhu9s4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NQFN3NNi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5nJShd33, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5fVjJcSs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5nJShd33, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_oOFNrrWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4Vvr2FPp_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oh6PTv3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Z11uHgeq_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8ijfHzbm_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_9cDSicWN_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_9cDSicWN_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_gRi275Vy, 1, m, &cDelay_gRi275Vy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OVEJQmre_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_gRi275Vy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_gRi275Vy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_oOFNrrWu, 0, m, &cIf_oOFNrrWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9cDSicWN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_gRi275Vy, 0, m, &cDelay_gRi275Vy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OVEJQmre_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_gRi275Vy, 0, m, &cDelay_gRi275Vy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NLoMZgqH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R0TvgSWo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_NV4LXOT3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_g2t7yijO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Om5n1b3N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZTKYvsYj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Om5n1b3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oOFNrrWu, 1, m, &cIf_oOFNrrWu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZTKYvsYj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8ijfHzbm_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_R0TvgSWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oh6PTv3O, 1, m, &cIf_oh6PTv3O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_NV4LXOT3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oh6PTv3O, 0, m, &cIf_oh6PTv3O_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Z11uHgeq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6yHMomB5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4Vvr2FPp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6yHMomB5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_UYhljyAD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IBt84zFY_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vyTbcFFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_87Ta8S3g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_zu3vDg7O_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_oJLRODKu_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_oJLRODKu_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Lhwnyw2K, 1, m, &cDelay_Lhwnyw2K_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WU08zvgd_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Lhwnyw2K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Lhwnyw2K, m);
  cIf_onMessage(_c, &Context(_c)->cIf_UYhljyAD, 0, m, &cIf_UYhljyAD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oJLRODKu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lhwnyw2K, 0, m, &cDelay_Lhwnyw2K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WU08zvgd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Lhwnyw2K, 0, m, &cDelay_Lhwnyw2K_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_MDg6Ri59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XiFoujFK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AzapKXKl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FPezIi37_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fMAubQcU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Q1DTrRDj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fMAubQcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_UYhljyAD, 1, m, &cIf_UYhljyAD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Q1DTrRDj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_zu3vDg7O_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_XiFoujFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vyTbcFFo, 1, m, &cIf_vyTbcFFo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_AzapKXKl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vyTbcFFo, 0, m, &cIf_vyTbcFFo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_87Ta8S3g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HJ8VGAqS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_IBt84zFY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_HJ8VGAqS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_aCTYZ0vn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tUyXQHsX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_U8PRc35n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4yX6TvjQ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_kv566OG6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Jz9cMi5E_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Jz9cMi5E_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ixrJbtHy, 1, m, &cDelay_ixrJbtHy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KdiIURYW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ixrJbtHy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ixrJbtHy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_aCTYZ0vn, 0, m, &cIf_aCTYZ0vn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Jz9cMi5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ixrJbtHy, 0, m, &cDelay_ixrJbtHy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_KdiIURYW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ixrJbtHy, 0, m, &cDelay_ixrJbtHy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iK5kCu8B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ckVqWKjt_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nU3AH1hx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2qLFWTuU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cZtpafho_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EAeRMbPm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_EAeRMbPm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kv566OG6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_cZtpafho_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_aCTYZ0vn, 1, m, &cIf_aCTYZ0vn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nU3AH1hx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8PRc35n, 0, m, &cIf_U8PRc35n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ckVqWKjt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_U8PRc35n, 1, m, &cIf_U8PRc35n_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4yX6TvjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ILItmIhh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tUyXQHsX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ILItmIhh, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ahpO7jA6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lQbkLAIO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_TT3sdx1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_utegr99v_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_JLtnV4ZC_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sqU3P1Nh_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sqU3P1Nh_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_xPSQm3vf, 1, m, &cDelay_xPSQm3vf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ch3cBOcB_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_xPSQm3vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_xPSQm3vf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ahpO7jA6, 0, m, &cIf_ahpO7jA6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sqU3P1Nh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_xPSQm3vf, 0, m, &cDelay_xPSQm3vf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ch3cBOcB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_xPSQm3vf, 0, m, &cDelay_xPSQm3vf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LXVl4R5y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_aVaSpmwV_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WWurBjlp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ihqwm9vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5uoPnCzP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aMaS4rZS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5uoPnCzP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ahpO7jA6, 1, m, &cIf_ahpO7jA6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aMaS4rZS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_JLtnV4ZC_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_WWurBjlp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TT3sdx1Z, 0, m, &cIf_TT3sdx1Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aVaSpmwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TT3sdx1Z, 1, m, &cIf_TT3sdx1Z_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_utegr99v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ex5WzkHe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_lQbkLAIO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ex5WzkHe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_EMvHVn1h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_dpm4xxNI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_BeZe4l6w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_81hmGY6d_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_FpkI6Zmb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_wVqA2lGa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_wVqA2lGa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YnPdqH0D, 1, m, &cDelay_YnPdqH0D_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Tyo0mp5t_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YnPdqH0D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YnPdqH0D, m);
  cIf_onMessage(_c, &Context(_c)->cIf_EMvHVn1h, 0, m, &cIf_EMvHVn1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wVqA2lGa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YnPdqH0D, 0, m, &cDelay_YnPdqH0D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Tyo0mp5t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YnPdqH0D, 0, m, &cDelay_YnPdqH0D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_N5qCYv51_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ps40nv6t_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UjbpQFD0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_M74Ic8WP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8NgbLFqm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pOWw9cGP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pOWw9cGP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_FpkI6Zmb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8NgbLFqm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EMvHVn1h, 1, m, &cIf_EMvHVn1h_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UjbpQFD0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BeZe4l6w, 0, m, &cIf_BeZe4l6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ps40nv6t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_BeZe4l6w, 1, m, &cIf_BeZe4l6w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_81hmGY6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JNOQDcZc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_dpm4xxNI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JNOQDcZc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3FSXSRbc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1lJivCdB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_mtjVidms_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NISDyTCa_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qqPKBFwe_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_Py4JJYHx_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_Py4JJYHx_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ciEiaseY, 1, m, &cDelay_ciEiaseY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DFo1ahRy_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ciEiaseY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ciEiaseY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3FSXSRbc, 0, m, &cIf_3FSXSRbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Py4JJYHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ciEiaseY, 0, m, &cDelay_ciEiaseY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DFo1ahRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ciEiaseY, 0, m, &cDelay_ciEiaseY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_tdL7Ln5E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_g9kPqgxd_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7ayjUbEH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_p1oql7to_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_i5BM5pvk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_iL4ubRVk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_i5BM5pvk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3FSXSRbc, 1, m, &cIf_3FSXSRbc_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_iL4ubRVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qqPKBFwe_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_g9kPqgxd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mtjVidms, 1, m, &cIf_mtjVidms_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7ayjUbEH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mtjVidms, 0, m, &cIf_mtjVidms_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NISDyTCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lUzJ7L0B, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1lJivCdB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lUzJ7L0B, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_HkUFs1r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LeoKiFmN_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_zbeMvV1m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FfQ0uCHC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_UQmQVwC7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0bQP0rfv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0bQP0rfv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ih47P2IO, 1, m, &cDelay_ih47P2IO_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RlRPlzyY_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ih47P2IO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ih47P2IO, m);
  cIf_onMessage(_c, &Context(_c)->cIf_HkUFs1r7, 0, m, &cIf_HkUFs1r7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0bQP0rfv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ih47P2IO, 0, m, &cDelay_ih47P2IO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RlRPlzyY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ih47P2IO, 0, m, &cDelay_ih47P2IO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KWq8WNQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FZ3mWMbp_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WIp7BVJF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_W4ijij4u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VwKEt3wx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Stn6ZVQV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Stn6ZVQV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_UQmQVwC7_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VwKEt3wx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_HkUFs1r7, 1, m, &cIf_HkUFs1r7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WIp7BVJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zbeMvV1m, 0, m, &cIf_zbeMvV1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_FZ3mWMbp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_zbeMvV1m, 1, m, &cIf_zbeMvV1m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FfQ0uCHC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N24yBwr2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LeoKiFmN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_N24yBwr2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_v0qzJq9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_EtAtXlXJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_XsSc8Rp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YpJgqoZb_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e4risQmd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_7eu7G0KT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_7eu7G0KT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_8pHJg0Z0, 1, m, &cDelay_8pHJg0Z0_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_R4SdkXJU_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_8pHJg0Z0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_8pHJg0Z0, m);
  cIf_onMessage(_c, &Context(_c)->cIf_v0qzJq9o, 0, m, &cIf_v0qzJq9o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7eu7G0KT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pHJg0Z0, 0, m, &cDelay_8pHJg0Z0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_R4SdkXJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_8pHJg0Z0, 0, m, &cDelay_8pHJg0Z0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CXjgZq32_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CDjLIEbq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MskunKzv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xMeyuRKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_81tG63Gh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_av3L8Emt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_81tG63Gh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_v0qzJq9o, 1, m, &cIf_v0qzJq9o_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_av3L8Emt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e4risQmd_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_CDjLIEbq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XsSc8Rp6, 1, m, &cIf_XsSc8Rp6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_MskunKzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_XsSc8Rp6, 0, m, &cIf_XsSc8Rp6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YpJgqoZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jZkGFHbA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_EtAtXlXJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jZkGFHbA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qrQYYx2g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_DjkibA77_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_IW8cJSTS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1e52U8rn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4bj5JCv3_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_l0KfqKHa_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_l0KfqKHa_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FiWhOrjn, 1, m, &cDelay_FiWhOrjn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dayOf5Ij_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FiWhOrjn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FiWhOrjn, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qrQYYx2g, 0, m, &cIf_qrQYYx2g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l0KfqKHa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FiWhOrjn, 0, m, &cDelay_FiWhOrjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dayOf5Ij_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FiWhOrjn, 0, m, &cDelay_FiWhOrjn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_wRtNHcbW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mAgfuCoW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_GPtnkTIC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_iGa9WqlT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RSAZzoTj_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3ZYIk9rW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3ZYIk9rW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_4bj5JCv3_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_RSAZzoTj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qrQYYx2g, 1, m, &cIf_qrQYYx2g_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_GPtnkTIC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IW8cJSTS, 0, m, &cIf_IW8cJSTS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mAgfuCoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_IW8cJSTS, 1, m, &cIf_IW8cJSTS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_1e52U8rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bLVWCqtx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_DjkibA77_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_bLVWCqtx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ZzzDYn41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nLauWx5S_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_DXPQwzA1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_9ydmeRGU_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_nlVvR4jJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_cf9kLzmg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_cf9kLzmg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_BsqrGtXY, 1, m, &cDelay_BsqrGtXY_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_tg2VQHFg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_BsqrGtXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_BsqrGtXY, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ZzzDYn41, 0, m, &cIf_ZzzDYn41_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_cf9kLzmg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_BsqrGtXY, 0, m, &cDelay_BsqrGtXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_tg2VQHFg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_BsqrGtXY, 0, m, &cDelay_BsqrGtXY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qV0R2gje_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6dPNJjLU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_37elrrWx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_CVS7S9pN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u5lSfKkh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_aBeZeNq0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_aBeZeNq0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_nlVvR4jJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_u5lSfKkh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZzzDYn41, 1, m, &cIf_ZzzDYn41_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_37elrrWx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DXPQwzA1, 0, m, &cIf_DXPQwzA1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6dPNJjLU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_DXPQwzA1, 1, m, &cIf_DXPQwzA1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9ydmeRGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9HskizCq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nLauWx5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_9HskizCq, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_cJQDnOlD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_evumtfGJ_sendMessage(_c, 0, m);
  cMsg_sS8UreJU_sendMessage(_c, 0, m);
  cMsg_751qaiiN_sendMessage(_c, 0, m);
  cMsg_aOKQwwm4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qkFk5THL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_evumtfGJ_sendMessage(_c, 0, m);
  cMsg_w8HXMslp_sendMessage(_c, 0, m);
  cMsg_lyureRpZ_sendMessage(_c, 0, m);
  cMsg_6xsQZLaB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4FoZPl8s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_Wh4lek48_sendMessage(_c, 0, m);
  cMsg_w8HXMslp_sendMessage(_c, 0, m);
  cMsg_aOKQwwm4_sendMessage(_c, 0, m);
  cMsg_G4mOy2KG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_PmhfUGqa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_Wh4lek48_sendMessage(_c, 0, m);
  cMsg_YrzMUQVg_sendMessage(_c, 0, m);
  cMsg_751qaiiN_sendMessage(_c, 0, m);
  cMsg_eTwW8469_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZEzliAXY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_jRmDlnkc_sendMessage(_c, 0, m);
  cMsg_6xsQZLaB_sendMessage(_c, 0, m);
  cMsg_eCXG3WKV_sendMessage(_c, 0, m);
  cMsg_751qaiiN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_v1e7bfVQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_jRmDlnkc_sendMessage(_c, 0, m);
  cMsg_eTwW8469_sendMessage(_c, 0, m);
  cMsg_w8HXMslp_sendMessage(_c, 0, m);
  cMsg_qJ1KSmFd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_iY29vQvO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R1UE9Cgu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ldU6JB6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_agabgCn3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_R1UE9Cgu_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ldU6JB6d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GyHrSHcG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xfkzyXtr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HcbJume2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_l5z1DqKI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xfkzyXtr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_HcbJume2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qJDRTKfG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g2t7yijO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NLoMZgqH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_GIadHUIN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_g2t7yijO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_NLoMZgqH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_evumtfGJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_iY29vQvO_sendMessage(_c, 0, m);
  cMsg_l5z1DqKI_sendMessage(_c, 0, m);
  cMsg_GIadHUIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Wh4lek48_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_agabgCn3_sendMessage(_c, 0, m);
  cMsg_GyHrSHcG_sendMessage(_c, 0, m);
  cMsg_GIadHUIN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_jRmDlnkc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_agabgCn3_sendMessage(_c, 0, m);
  cMsg_l5z1DqKI_sendMessage(_c, 0, m);
  cMsg_qJDRTKfG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_S8X9OCGi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FPezIi37_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MDg6Ri59_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_pXzP1unr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_FPezIi37_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_MDg6Ri59_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_3wIsK4Fk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2qLFWTuU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iK5kCu8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DG48xMXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2qLFWTuU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_iK5kCu8B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_gd392Edg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ihqwm9vf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LXVl4R5y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rnPKVZri_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ihqwm9vf_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_LXVl4R5y_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_w8HXMslp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_pXzP1unr_sendMessage(_c, 0, m);
  cMsg_DG48xMXE_sendMessage(_c, 0, m);
  cMsg_rnPKVZri_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_sS8UreJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_pXzP1unr_sendMessage(_c, 0, m);
  cMsg_3wIsK4Fk_sendMessage(_c, 0, m);
  cMsg_gd392Edg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YrzMUQVg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_S8X9OCGi_sendMessage(_c, 0, m);
  cMsg_DG48xMXE_sendMessage(_c, 0, m);
  cMsg_gd392Edg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dZa4W3Vd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xMeyuRKB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CXjgZq32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Wg6jloNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_xMeyuRKB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_CXjgZq32_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qejQC5mK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iGa9WqlT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wRtNHcbW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vEafBjRT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_iGa9WqlT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_wRtNHcbW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_JzmV59Zk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CVS7S9pN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qV0R2gje_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fl2VeBvD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_CVS7S9pN_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qV0R2gje_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eTwW8469_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_dZa4W3Vd_sendMessage(_c, 0, m);
  cMsg_vEafBjRT_sendMessage(_c, 0, m);
  cMsg_fl2VeBvD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6xsQZLaB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Wg6jloNR_sendMessage(_c, 0, m);
  cMsg_qejQC5mK_sendMessage(_c, 0, m);
  cMsg_fl2VeBvD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_aOKQwwm4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Wg6jloNR_sendMessage(_c, 0, m);
  cMsg_vEafBjRT_sendMessage(_c, 0, m);
  cMsg_JzmV59Zk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B7imrkKs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M74Ic8WP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N5qCYv51_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HZiGzi14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_M74Ic8WP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_N5qCYv51_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ft9aTWYl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p1oql7to_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tdL7Ln5E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_19aErbUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_p1oql7to_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_tdL7Ln5E_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BXwLxbr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W4ijij4u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KWq8WNQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vgDm2fwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_W4ijij4u_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_KWq8WNQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_751qaiiN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_HZiGzi14_sendMessage(_c, 0, m);
  cMsg_19aErbUu_sendMessage(_c, 0, m);
  cMsg_vgDm2fwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_lyureRpZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_HZiGzi14_sendMessage(_c, 0, m);
  cMsg_Ft9aTWYl_sendMessage(_c, 0, m);
  cMsg_BXwLxbr5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qJ1KSmFd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_B7imrkKs_sendMessage(_c, 0, m);
  cMsg_Ft9aTWYl_sendMessage(_c, 0, m);
  cMsg_vgDm2fwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_eCXG3WKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_S8X9OCGi_sendMessage(_c, 0, m);
  cMsg_3wIsK4Fk_sendMessage(_c, 0, m);
  cMsg_rnPKVZri_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_G4mOy2KG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_B7imrkKs_sendMessage(_c, 0, m);
  cMsg_19aErbUu_sendMessage(_c, 0, m);
  cMsg_BXwLxbr5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_PwucdF61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UWX1kWQP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_YSliNqbd_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_651BsW8R, 0, m, &cSlice_651BsW8R_sendMessage);
      break;
    }
    default: {
      cSwitchcase_4gxaoYWl_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_651BsW8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zeJoLAmv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zeJoLAmv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yTME66iv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zeJoLAmv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zeJoLAmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zlkrlUsY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_U6TnF0VU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ENiVk5Dn, 0, m, &cSlice_ENiVk5Dn_sendMessage);
      break;
    }
    default: {
      cSwitchcase_XLr1kRq1_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ENiVk5Dn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zBC81jj2_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zBC81jj2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_3nK0NnTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zBC81jj2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zBC81jj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_or9HCeyF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_XLr1kRq1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GhwTfh7M, 0, m, &cSlice_GhwTfh7M_sendMessage);
      break;
    }
    default: {
      cSwitchcase_YSliNqbd_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GhwTfh7M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_OYs83fAu_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_OYs83fAu_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_eMhmVhWY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_OYs83fAu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_OYs83fAu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_lER2Hgdo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_4gxaoYWl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_GorRxs9K, 0, m, &cSlice_GorRxs9K_sendMessage);
      break;
    }
    default: {
      cSwitchcase_7ZDTMABP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_GorRxs9K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_lAD62EeZ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_lAD62EeZ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_OGLSHQsE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_lAD62EeZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_lAD62EeZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Xi1JeOfi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_7ZDTMABP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_zUEhzqAt, 0, m, &cSlice_zUEhzqAt_sendMessage);
      break;
    }
    default: {
      cSwitchcase_afMSGwt0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_zUEhzqAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_BIWoljwo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_BIWoljwo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_EVRkzr0V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_BIWoljwo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_BIWoljwo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_epbM1BCJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_BpdRoi2d_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_V1C6Sw80_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_V1C6Sw80_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_25CGGoQR, 1, m, &cDelay_25CGGoQR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JdYekXCk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_25CGGoQR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_25CGGoQR, m);
  cMsg_UvPJvYJf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V1C6Sw80_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_25CGGoQR, 0, m, &cDelay_25CGGoQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JdYekXCk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_25CGGoQR, 0, m, &cDelay_25CGGoQR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_CFcCCsoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vVaBnZVb, HV_BINOP_SUBTRACT, 0, m, &cBinop_vVaBnZVb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_OatQumRP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Vl5m7jx5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Wk1hJUfY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Vl5m7jx5_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_HNxBPYug_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CFcCCsoq, 0, m, &cVar_CFcCCsoq_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_DzKQc4mD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_84Z90i6G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DT4vE84q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jzsdgKkC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vVaBnZVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_krKDMQJI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_krKDMQJI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Bx1SHVoI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bx1SHVoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_6sIuz1Qt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ok65OL5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7i1Xa5qh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UH2t3aoj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UH2t3aoj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nPNpEnRv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_7i1Xa5qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_OatQumRP, 1, m, &cIf_OatQumRP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cPj2Cr9a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wk1hJUfY, 1, m, &cIf_Wk1hJUfY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nPNpEnRv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_OatQumRP, 0, m, &cIf_OatQumRP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6sIuz1Qt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Wk1hJUfY, 0, m, &cIf_Wk1hJUfY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_DT4vE84q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_vVaBnZVb, HV_BINOP_SUBTRACT, 1, m, &cBinop_vVaBnZVb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_84Z90i6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_jzsdgKkC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CFcCCsoq, 0, m, &cVar_CFcCCsoq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Vl5m7jx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jX4ZQ6vE, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_afMSGwt0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_rTSDh0el, 0, m, &cSlice_rTSDh0el_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_rTSDh0el_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_6GyGer4h_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_6GyGer4h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_9YSxDuk8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_6GyGer4h_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_6GyGer4h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4KLDXSaJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_fx4CIeGX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KKsj5Poa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yW63TQX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FDQL6git, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_PlTub9oI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_6O8UplwA, 0, m, &cVar_6O8UplwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UWX1kWQP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_XtwCSIKZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_Yjbf21c8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Cag043Dv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_EVztSda2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_BpdRoi2d_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UvPJvYJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ThGM0DTZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Cag043Dv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ThGM0DTZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_w0TgU317_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_SE2qYujS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SE2qYujS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EHp9FSmK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_EHp9FSmK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_WWKCJHek, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_gtgzGgnA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_JCLT5GMX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_UqRHDobZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nhL0BKb2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_tt107kmR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0NwREtS1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_J8bNZ8mH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_7Uxf0fBB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_B0fzY4Mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Z1eLQHLP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_3s77ndu3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qLxvUW7F_sendMessage);
  cMsg_JjxjDK7X_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_qLxvUW7F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3s77ndu3, 1, m, &cVar_3s77ndu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CkdO755a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_UK7pc5TS_sendMessage(_c, 0, m);
  cMsg_K2NiRv2I_sendMessage(_c, 0, m);
  cMsg_mK1gyyqo_sendMessage(_c, 0, m);
  cMsg_FEy2u4VR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_sDkBdLMt_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_n4rt1Pfz, 0, m, &cSlice_n4rt1Pfz_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_n4rt1Pfz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rbgbS1sh_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rbgbS1sh_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_vL5ey5TI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rbgbS1sh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rbgbS1sh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_7GJu8k6l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_WCkUPhg6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_GotGScUm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GotGScUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_fXObePkv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fXObePkv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_HhLLjRcq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_HhLLjRcq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VUNkG9HB_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nd0VHL5u_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_nd0VHL5u_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_soNRRdSw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_VUNkG9HB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_D6Zxuhht_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D6Zxuhht_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_dKy8h29m_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_soNRRdSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_XdwdBcR1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_XdwdBcR1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_wxs4jsRQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_dKy8h29m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_B9PPnRMP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cBinop_wxs4jsRQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_MLVr927I_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_B9PPnRMP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FVo9Od1b, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MLVr927I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RuJ0NTsR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_OqkApdR3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4awGVsrp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_IOeEIrb1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p1KZVfN8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_pj6OQGnb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_dkiED4Tf_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CJmlvD4G_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Pbjv0O2U_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KHmYMc0n_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_AsLChY7b_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Or0V18Uk_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_dkiED4Tf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_H39sPZO1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_CJmlvD4G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F3L8WRwh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Pbjv0O2U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HHl4E7mk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_KHmYMc0n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_wo8ryKgH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_AsLChY7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YfFdyYMl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_Or0V18Uk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KydQHYZs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_d1WmQ8iC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tInd4K7O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_EYM6QwAW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lPNOUseW_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_paNTyoXo_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nTwSAqi5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nTwSAqi5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G87vgUkZ, 1, m, &cDelay_G87vgUkZ_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zjssSXwX_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_G87vgUkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G87vgUkZ, m);
  cIf_onMessage(_c, &Context(_c)->cIf_d1WmQ8iC, 0, m, &cIf_d1WmQ8iC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nTwSAqi5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G87vgUkZ, 0, m, &cDelay_G87vgUkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zjssSXwX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G87vgUkZ, 0, m, &cDelay_G87vgUkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ak99N0Dy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3j1FZjOq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BMYP154S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_clSIKDwa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9tJhrf8N_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1rh1JJew_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9tJhrf8N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_d1WmQ8iC, 1, m, &cIf_d1WmQ8iC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1rh1JJew_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_paNTyoXo_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_BMYP154S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EYM6QwAW, 0, m, &cIf_EYM6QwAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3j1FZjOq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_EYM6QwAW, 1, m, &cIf_EYM6QwAW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lPNOUseW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V6F7dCFZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tInd4K7O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_V6F7dCFZ, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RDfHw8op_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_YHDspTYy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_oHfXoI8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fjKDkYcm_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_6DpCwkY6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_XSJ9oVDC_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_XSJ9oVDC_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_fmlFOB5c, 1, m, &cDelay_fmlFOB5c_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3pbiHpg3_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_fmlFOB5c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_fmlFOB5c, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RDfHw8op, 0, m, &cIf_RDfHw8op_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_XSJ9oVDC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_fmlFOB5c, 0, m, &cDelay_fmlFOB5c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3pbiHpg3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_fmlFOB5c, 0, m, &cDelay_fmlFOB5c_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_coaxUlZZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5Y79iJOl_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Jfjy4efj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_9hNHDbqe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zMRyYUdk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jtl85Nyx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jtl85Nyx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_6DpCwkY6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_zMRyYUdk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RDfHw8op, 1, m, &cIf_RDfHw8op_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5Y79iJOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oHfXoI8Q, 1, m, &cIf_oHfXoI8Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Jfjy4efj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oHfXoI8Q, 0, m, &cIf_oHfXoI8Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fjKDkYcm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IXfG83bu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YHDspTYy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IXfG83bu, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_uw5Tuh3B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PCZhRkVF_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_gTqkifPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_aofXGtly_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_HCOsWSzI_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lQWUlqDg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lQWUlqDg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_vQekSCaM, 1, m, &cDelay_vQekSCaM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pPjbcaQW_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_vQekSCaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_vQekSCaM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_uw5Tuh3B, 0, m, &cIf_uw5Tuh3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lQWUlqDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQekSCaM, 0, m, &cDelay_vQekSCaM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pPjbcaQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_vQekSCaM, 0, m, &cDelay_vQekSCaM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_a9D2VZbI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jKyvcS8a_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3yLpKKPL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_lYv5lYNV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oNKf2MHQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6YRPzJZq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6YRPzJZq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_HCOsWSzI_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_oNKf2MHQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_uw5Tuh3B, 1, m, &cIf_uw5Tuh3B_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_jKyvcS8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gTqkifPz, 1, m, &cIf_gTqkifPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3yLpKKPL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_gTqkifPz, 0, m, &cIf_gTqkifPz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aofXGtly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x6UyTMU5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PCZhRkVF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_x6UyTMU5, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_vWFz0485_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CXnzAwkG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_xIyCae3j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_IFBcbB9O_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_vSoxh9d6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_hWzy7gE9_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_hWzy7gE9_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YfTALWCr, 1, m, &cDelay_YfTALWCr_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_N2a2KeIf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YfTALWCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YfTALWCr, m);
  cIf_onMessage(_c, &Context(_c)->cIf_vWFz0485, 0, m, &cIf_vWFz0485_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hWzy7gE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YfTALWCr, 0, m, &cDelay_YfTALWCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_N2a2KeIf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YfTALWCr, 0, m, &cDelay_YfTALWCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Bd13O43C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ERceMAYo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ytjbUQev_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qJumT8C7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LpNReM7i_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WgV6NA5d_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WgV6NA5d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_vSoxh9d6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_LpNReM7i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vWFz0485, 1, m, &cIf_vWFz0485_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ytjbUQev_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xIyCae3j, 0, m, &cIf_xIyCae3j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ERceMAYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xIyCae3j, 1, m, &cIf_xIyCae3j_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IFBcbB9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JTwocyq2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CXnzAwkG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_JTwocyq2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_SECZQnUu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_4bTLqd3h_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_niJPg0ke_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_W6d4CH9N_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_iJkYjUJb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_0YS9cSDf_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_0YS9cSDf_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_VgzkNS0W, 1, m, &cDelay_VgzkNS0W_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WEB00Gkg_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_VgzkNS0W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_VgzkNS0W, m);
  cIf_onMessage(_c, &Context(_c)->cIf_SECZQnUu, 0, m, &cIf_SECZQnUu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0YS9cSDf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_VgzkNS0W, 0, m, &cDelay_VgzkNS0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WEB00Gkg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_VgzkNS0W, 0, m, &cDelay_VgzkNS0W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Pv1klAmB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_M0NRSGFK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8oxZI8Dj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fNrH4R7d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_fPRnHrVX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_s0U57SqQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_fPRnHrVX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SECZQnUu, 1, m, &cIf_SECZQnUu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_s0U57SqQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_iJkYjUJb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_M0NRSGFK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_niJPg0ke, 1, m, &cIf_niJPg0ke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_8oxZI8Dj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_niJPg0ke, 0, m, &cIf_niJPg0ke_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_W6d4CH9N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IcTTtF1K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4bTLqd3h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IcTTtF1K, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_YBNultCO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_BwdwbOBM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_N4S4fqBa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5jg513Ez_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_tuKELOKJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_QvFtYFnX_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_QvFtYFnX_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_rUlhusZB, 1, m, &cDelay_rUlhusZB_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zQjCQpnP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_rUlhusZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_rUlhusZB, m);
  cIf_onMessage(_c, &Context(_c)->cIf_YBNultCO, 0, m, &cIf_YBNultCO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_QvFtYFnX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_rUlhusZB, 0, m, &cDelay_rUlhusZB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zQjCQpnP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_rUlhusZB, 0, m, &cDelay_rUlhusZB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_cg5M8VCR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_dIyNoP9v_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_cpsOsf7P_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ENSBJRZg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VrPV1qPB_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3Gp7ld1w_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3Gp7ld1w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_tuKELOKJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VrPV1qPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YBNultCO, 1, m, &cIf_YBNultCO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_dIyNoP9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N4S4fqBa, 1, m, &cIf_N4S4fqBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_cpsOsf7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_N4S4fqBa, 0, m, &cIf_N4S4fqBa_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5jg513Ez_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_awq9kSRG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_BwdwbOBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_awq9kSRG, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_QZmLUAxf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_MxTNfIQ6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_agvTTpBo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_VJRQR0zc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_rFNo8X0K_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_aMmjFaSP_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_aMmjFaSP_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_DnyapFOk, 1, m, &cDelay_DnyapFOk_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_870XS5bI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_DnyapFOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_DnyapFOk, m);
  cIf_onMessage(_c, &Context(_c)->cIf_QZmLUAxf, 0, m, &cIf_QZmLUAxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_aMmjFaSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_DnyapFOk, 0, m, &cDelay_DnyapFOk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_870XS5bI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_DnyapFOk, 0, m, &cDelay_DnyapFOk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_T0fFHMo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_T5CuCThA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eQIc838l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZsgF4YVb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8YZHYIBk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_l4rnxeWg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_l4rnxeWg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_rFNo8X0K_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_8YZHYIBk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QZmLUAxf, 1, m, &cIf_QZmLUAxf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_eQIc838l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_agvTTpBo, 0, m, &cIf_agvTTpBo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_T5CuCThA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_agvTTpBo, 1, m, &cIf_agvTTpBo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_VJRQR0zc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VlWyqMrN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_MxTNfIQ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_VlWyqMrN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_qyh9LH8i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Rpwo8C46_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Jp0ywQ0i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nbANs0C4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QRArTnIq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_N4Vd6OFQ_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_N4Vd6OFQ_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_YU3aguP1, 1, m, &cDelay_YU3aguP1_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YLv1QH6Q_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_YU3aguP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_YU3aguP1, m);
  cIf_onMessage(_c, &Context(_c)->cIf_qyh9LH8i, 0, m, &cIf_qyh9LH8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_N4Vd6OFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_YU3aguP1, 0, m, &cDelay_YU3aguP1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_YLv1QH6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_YU3aguP1, 0, m, &cDelay_YU3aguP1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_gfcU2xiO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_A0WSaGJQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_0SZTFPnD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ZtoVjS6i_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jCCQhlPO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PLNzVld4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PLNzVld4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QRArTnIq_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jCCQhlPO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qyh9LH8i, 1, m, &cIf_qyh9LH8i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_A0WSaGJQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jp0ywQ0i, 1, m, &cIf_Jp0ywQ0i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_0SZTFPnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jp0ywQ0i, 0, m, &cIf_Jp0ywQ0i_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nbANs0C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xdrxI4yx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Rpwo8C46_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xdrxI4yx, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_CXv7Csit_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_makRIlnt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vbCzD0F9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Fu040T96_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_DrsTuoFL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yCOnxZtr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yCOnxZtr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_6fQeVQUy, 1, m, &cDelay_6fQeVQUy_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Xuanxasf_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_6fQeVQUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_6fQeVQUy, m);
  cIf_onMessage(_c, &Context(_c)->cIf_CXv7Csit, 0, m, &cIf_CXv7Csit_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yCOnxZtr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_6fQeVQUy, 0, m, &cDelay_6fQeVQUy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Xuanxasf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_6fQeVQUy, 0, m, &cDelay_6fQeVQUy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_xcKeMJV2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_oHg2W53C_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZtWckLuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_2UzCa44W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GeMNoLvn_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mrJqgbOI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_mrJqgbOI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_DrsTuoFL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GeMNoLvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CXv7Csit, 1, m, &cIf_CXv7Csit_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oHg2W53C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbCzD0F9, 1, m, &cIf_vbCzD0F9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZtWckLuV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vbCzD0F9, 0, m, &cIf_vbCzD0F9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Fu040T96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uQomrI8Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_makRIlnt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uQomrI8Z, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xl3cyRdl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_3zpM784U_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_LD27SA3H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_6NFOMPKB_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_G0I1Ig2e_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_M7u4PMse_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_M7u4PMse_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_cszElQFt, 1, m, &cDelay_cszElQFt_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_B9fAfrjk_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_cszElQFt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_cszElQFt, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xl3cyRdl, 0, m, &cIf_xl3cyRdl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M7u4PMse_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_cszElQFt, 0, m, &cDelay_cszElQFt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_B9fAfrjk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_cszElQFt, 0, m, &cDelay_cszElQFt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_7Jvr61zr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CXPHjGM8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JbjvnFIi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_D7aN9fRy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GNUOYn7p_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6HqynTnG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6HqynTnG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_G0I1Ig2e_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_GNUOYn7p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xl3cyRdl, 1, m, &cIf_xl3cyRdl_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JbjvnFIi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LD27SA3H, 0, m, &cIf_LD27SA3H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CXPHjGM8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_LD27SA3H, 1, m, &cIf_LD27SA3H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_6NFOMPKB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sHT0QqiO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_3zpM784U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sHT0QqiO, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9sHmkl3I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_H0LsjqHz_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_G9N2R52V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_lfjgy8jt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_hl4SKgYJ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_yjwZWEBM_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_yjwZWEBM_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ptpkT8VM, 1, m, &cDelay_ptpkT8VM_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5me2AS5b_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ptpkT8VM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ptpkT8VM, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9sHmkl3I, 0, m, &cIf_9sHmkl3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_yjwZWEBM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ptpkT8VM, 0, m, &cDelay_ptpkT8VM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5me2AS5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ptpkT8VM, 0, m, &cDelay_ptpkT8VM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_WdxgRTq6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_51xlgDhG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LLsZuHPu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Kh08trba_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1PSbY8SC_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RpzooWkx_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RpzooWkx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hl4SKgYJ_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_1PSbY8SC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9sHmkl3I, 1, m, &cIf_9sHmkl3I_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LLsZuHPu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G9N2R52V, 0, m, &cIf_G9N2R52V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_51xlgDhG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_G9N2R52V, 1, m, &cIf_G9N2R52V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lfjgy8jt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1xS2KbNe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H0LsjqHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_1xS2KbNe, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_fauxkW1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ga2PimjM_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_dp9p6vgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_5Lqha2Cs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_e7r7sSt1_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_5vgI7fUR_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_5vgI7fUR_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_27iGHhqD, 1, m, &cDelay_27iGHhqD_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_pK6iP0tq_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_27iGHhqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_27iGHhqD, m);
  cIf_onMessage(_c, &Context(_c)->cIf_fauxkW1l, 0, m, &cIf_fauxkW1l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5vgI7fUR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_27iGHhqD, 0, m, &cDelay_27iGHhqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_pK6iP0tq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_27iGHhqD, 0, m, &cDelay_27iGHhqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_yUgksSWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IBB6LTn4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WKPTYUWt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_U9N1rvVc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_kS8d1QIh_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oqz2mfo2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_oqz2mfo2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_e7r7sSt1_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_kS8d1QIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fauxkW1l, 1, m, &cIf_fauxkW1l_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WKPTYUWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dp9p6vgG, 0, m, &cIf_dp9p6vgG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_IBB6LTn4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_dp9p6vgG, 1, m, &cIf_dp9p6vgG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5Lqha2Cs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FnhbTJOl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_ga2PimjM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FnhbTJOl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_H39sPZO1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_xjkBVyWt_sendMessage(_c, 0, m);
  cMsg_Hl65mDAL_sendMessage(_c, 0, m);
  cMsg_imTpXNGu_sendMessage(_c, 0, m);
  cMsg_6GAIHBmU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_F3L8WRwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_xjkBVyWt_sendMessage(_c, 0, m);
  cMsg_tmCizO3o_sendMessage(_c, 0, m);
  cMsg_WQPsWTH2_sendMessage(_c, 0, m);
  cMsg_ZUbhqlet_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_HHl4E7mk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_dKx1hiMy_sendMessage(_c, 0, m);
  cMsg_tmCizO3o_sendMessage(_c, 0, m);
  cMsg_6GAIHBmU_sendMessage(_c, 0, m);
  cMsg_RCQHhmKH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wo8ryKgH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_dKx1hiMy_sendMessage(_c, 0, m);
  cMsg_NgMPITGG_sendMessage(_c, 0, m);
  cMsg_imTpXNGu_sendMessage(_c, 0, m);
  cMsg_8rnqJXJZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_YfFdyYMl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_bSpJYBo3_sendMessage(_c, 0, m);
  cMsg_ZUbhqlet_sendMessage(_c, 0, m);
  cMsg_gHfio3FX_sendMessage(_c, 0, m);
  cMsg_imTpXNGu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_KydQHYZs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_bSpJYBo3_sendMessage(_c, 0, m);
  cMsg_8rnqJXJZ_sendMessage(_c, 0, m);
  cMsg_tmCizO3o_sendMessage(_c, 0, m);
  cMsg_mF3E4fLI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_5c05KNd9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_clSIKDwa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ak99N0Dy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EU5COcO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_clSIKDwa_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ak99N0Dy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_AmWHOYXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9hNHDbqe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_coaxUlZZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_168vaglf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_9hNHDbqe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_coaxUlZZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5kpfRZrW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lYv5lYNV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a9D2VZbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fiKNJdda_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_lYv5lYNV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_a9D2VZbI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xjkBVyWt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_5c05KNd9_sendMessage(_c, 0, m);
  cMsg_168vaglf_sendMessage(_c, 0, m);
  cMsg_fiKNJdda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_dKx1hiMy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_EU5COcO0_sendMessage(_c, 0, m);
  cMsg_AmWHOYXM_sendMessage(_c, 0, m);
  cMsg_fiKNJdda_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_bSpJYBo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_EU5COcO0_sendMessage(_c, 0, m);
  cMsg_168vaglf_sendMessage(_c, 0, m);
  cMsg_5kpfRZrW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_kbQy5vkJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qJumT8C7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Bd13O43C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kDQTJ3na_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_qJumT8C7_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Bd13O43C_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_dMT1ebJz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fNrH4R7d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pv1klAmB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_BEYXtrrx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_fNrH4R7d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Pv1klAmB_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_L33c4Pll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ENSBJRZg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cg5M8VCR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_iDcmQKvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ENSBJRZg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_cg5M8VCR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tmCizO3o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_kDQTJ3na_sendMessage(_c, 0, m);
  cMsg_BEYXtrrx_sendMessage(_c, 0, m);
  cMsg_iDcmQKvn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Hl65mDAL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_kDQTJ3na_sendMessage(_c, 0, m);
  cMsg_dMT1ebJz_sendMessage(_c, 0, m);
  cMsg_L33c4Pll_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_NgMPITGG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_kbQy5vkJ_sendMessage(_c, 0, m);
  cMsg_BEYXtrrx_sendMessage(_c, 0, m);
  cMsg_L33c4Pll_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4RypkKrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D7aN9fRy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7Jvr61zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KxLuHFyG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_D7aN9fRy_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_7Jvr61zr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_4WIjYTkV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Kh08trba_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WdxgRTq6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_5cD0JIKD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Kh08trba_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WdxgRTq6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7PNZsqzT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U9N1rvVc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yUgksSWK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_13BpmjU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_U9N1rvVc_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_yUgksSWK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8rnqJXJZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_4RypkKrA_sendMessage(_c, 0, m);
  cMsg_5cD0JIKD_sendMessage(_c, 0, m);
  cMsg_13BpmjU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ZUbhqlet_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_KxLuHFyG_sendMessage(_c, 0, m);
  cMsg_4WIjYTkV_sendMessage(_c, 0, m);
  cMsg_13BpmjU1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6GAIHBmU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_KxLuHFyG_sendMessage(_c, 0, m);
  cMsg_5cD0JIKD_sendMessage(_c, 0, m);
  cMsg_7PNZsqzT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JgtCintM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZsgF4YVb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T0fFHMo3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_HKopAYnr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZsgF4YVb_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_T0fFHMo3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nLSbxu9F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZtoVjS6i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gfcU2xiO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_91lZRvOB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_ZtoVjS6i_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_gfcU2xiO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_oOYzvvx5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2UzCa44W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xcKeMJV2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_tUmFDrIr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_2UzCa44W_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_xcKeMJV2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_imTpXNGu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_HKopAYnr_sendMessage(_c, 0, m);
  cMsg_91lZRvOB_sendMessage(_c, 0, m);
  cMsg_tUmFDrIr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_WQPsWTH2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_HKopAYnr_sendMessage(_c, 0, m);
  cMsg_nLSbxu9F_sendMessage(_c, 0, m);
  cMsg_oOYzvvx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_mF3E4fLI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_JgtCintM_sendMessage(_c, 0, m);
  cMsg_nLSbxu9F_sendMessage(_c, 0, m);
  cMsg_tUmFDrIr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_gHfio3FX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_kbQy5vkJ_sendMessage(_c, 0, m);
  cMsg_dMT1ebJz_sendMessage(_c, 0, m);
  cMsg_iDcmQKvn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_RCQHhmKH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_JgtCintM_sendMessage(_c, 0, m);
  cMsg_91lZRvOB_sendMessage(_c, 0, m);
  cMsg_oOYzvvx5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_87s3rjuk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PzlP92jX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ZzJEhx6Q_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7HcZdRYS, 0, m, &cSlice_7HcZdRYS_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ythatNYu_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_7HcZdRYS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_rSJ3CbIt_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_rSJ3CbIt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_2l0hewhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_rSJ3CbIt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_rSJ3CbIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_nl28EsCH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_H5y9rPwl_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_vCJiiYM7, 0, m, &cSlice_vCJiiYM7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_n9y2PTKk_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_vCJiiYM7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_yLMajvb9_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_yLMajvb9_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_1PcKOm4d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_yLMajvb9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_yLMajvb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_4A7w9lRs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_n9y2PTKk_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_bKGeb7gJ, 0, m, &cSlice_bKGeb7gJ_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ZzJEhx6Q_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_bKGeb7gJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_zDYqnCSX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_zDYqnCSX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_hpRgXWjw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_zDYqnCSX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_zDYqnCSX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_dREye3mv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ythatNYu_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_v8gTo90r, 0, m, &cSlice_v8gTo90r_sendMessage);
      break;
    }
    default: {
      cSwitchcase_PkbTXv80_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_v8gTo90r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_0SepET6J_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_0SepET6J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_w98lOufV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_0SepET6J_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_0SepET6J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_P20tFaNQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_PkbTXv80_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Zr94faKq, 0, m, &cSlice_Zr94faKq_sendMessage);
      break;
    }
    default: {
      cSwitchcase_xyE6QJYU_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_Zr94faKq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hyjbLQRn_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hyjbLQRn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Rp716uJV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hyjbLQRn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hyjbLQRn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_E6TOGwJU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_69biqLAy_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_AlLy2e3Z_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_AlLy2e3Z_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_G0xF1ZvG, 1, m, &cDelay_G0xF1ZvG_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ls63qvMR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_G0xF1ZvG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_G0xF1ZvG, m);
  cMsg_6cBQ4Tf9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_AlLy2e3Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_G0xF1ZvG, 0, m, &cDelay_G0xF1ZvG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ls63qvMR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_G0xF1ZvG, 0, m, &cDelay_G0xF1ZvG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_vG77nfQs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GfEhuX7b, HV_BINOP_SUBTRACT, 0, m, &cBinop_GfEhuX7b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_i4quO4mf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hcuIxqSr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_YP2fhrIJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_hcuIxqSr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_YAbtSPPU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vG77nfQs, 0, m, &cVar_vG77nfQs_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_ILqxuXLg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_G2ZlOb43_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uu09FVoe_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_28YotJx9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_GfEhuX7b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QRoufaVp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_QRoufaVp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_LDCd1Gjy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_LDCd1Gjy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_qVpkqaSm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_pSiFhhGF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DNlbWrgo_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_UK15DL60_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_UK15DL60_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_sCQFNZxn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_DNlbWrgo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_i4quO4mf, 1, m, &cIf_i4quO4mf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KjACgIhX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YP2fhrIJ, 1, m, &cIf_YP2fhrIJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sCQFNZxn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_i4quO4mf, 0, m, &cIf_i4quO4mf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qVpkqaSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_YP2fhrIJ, 0, m, &cIf_YP2fhrIJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_G2ZlOb43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_uu09FVoe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_GfEhuX7b, HV_BINOP_SUBTRACT, 1, m, &cBinop_GfEhuX7b_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_28YotJx9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_vG77nfQs, 0, m, &cVar_vG77nfQs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hcuIxqSr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_FmttK2NN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_xyE6QJYU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_wBzxDJyX, 0, m, &cSlice_wBzxDJyX_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_wBzxDJyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HEPwAwIo_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HEPwAwIo_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_yGdqV43V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HEPwAwIo_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HEPwAwIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_EpCrp4U5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4awGVsrp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ex897gix, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_p1KZVfN8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aF8OwE6S, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_tbdvPbCr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IOeEIrb1, 0, m, &cVar_IOeEIrb1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PzlP92jX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Ei4G7UyD, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_9QXUv1cw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jOuGmxCZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_HzXHnm8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_69biqLAy_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_6cBQ4Tf9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nB3hjMCB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jOuGmxCZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_nB3hjMCB, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_GGCCxM6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_vbfdl37H_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vbfdl37H_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_M6XPd6O6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_M6XPd6O6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vDCz0vsr, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_ct1PlHLv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6148qt08_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_dAI301q4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_noiBVB7T_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_8muSC8KU_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6RZG7S0J_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zLhvWihW_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_wGKYX6dE_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_O4fgUWL1_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rEYdpGqD_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_QipObWoI_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cCast_6RZG7S0J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_s7qQrvi6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_zLhvWihW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ixOfYBdb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_wGKYX6dE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nxc9jXB7_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_O4fgUWL1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_I3Is7RId_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_rEYdpGqD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_99R8XjBQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_QipObWoI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_8MwUYxWc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cIf_4yyyYBpM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_KbIbYzB3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_SMbSmujz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_rwNSXe6g_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_qGTNzil8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_nRaGxqQT_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_nRaGxqQT_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bMDqhBap, 1, m, &cDelay_bMDqhBap_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_2KwqrSTM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bMDqhBap_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bMDqhBap, m);
  cIf_onMessage(_c, &Context(_c)->cIf_4yyyYBpM, 0, m, &cIf_4yyyYBpM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nRaGxqQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bMDqhBap, 0, m, &cDelay_bMDqhBap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2KwqrSTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bMDqhBap, 0, m, &cDelay_bMDqhBap_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_I0wHh1C4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O7FOTioA_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_bDrKuTOy_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_1JXGfDwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3pCWYR6Q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_6lyOvRF4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_6lyOvRF4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_qGTNzil8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_3pCWYR6Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_4yyyYBpM, 1, m, &cIf_4yyyYBpM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_O7FOTioA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMbSmujz, 1, m, &cIf_SMbSmujz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bDrKuTOy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SMbSmujz, 0, m, &cIf_SMbSmujz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rwNSXe6g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ICVTUUMi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KbIbYzB3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ICVTUUMi, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_9BhaJap6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_tGvmoJnD_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Jpvq0QFT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_NNFVzD7J_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_KbyrBKBb_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_sY96mybL_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_sY96mybL_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_b889ANYT, 1, m, &cDelay_b889ANYT_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WdBe95sc_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_b889ANYT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_b889ANYT, m);
  cIf_onMessage(_c, &Context(_c)->cIf_9BhaJap6, 0, m, &cIf_9BhaJap6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sY96mybL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_b889ANYT, 0, m, &cDelay_b889ANYT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WdBe95sc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_b889ANYT, 0, m, &cDelay_b889ANYT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_H5G7eeSL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LoAkltD4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZUn5WBpI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_8p9v99Pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5ynlYCAO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_a60jOVwC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5ynlYCAO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_9BhaJap6, 1, m, &cIf_9BhaJap6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_a60jOVwC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_KbyrBKBb_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ZUn5WBpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jpvq0QFT, 0, m, &cIf_Jpvq0QFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LoAkltD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jpvq0QFT, 1, m, &cIf_Jpvq0QFT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NNFVzD7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_53Y1YoUR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tGvmoJnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_53Y1YoUR, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_ctWIxvkZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_vyYoWK2B_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_vGY4TImD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nk9QAFSt_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_acoK4d9D_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_fMvrs79X_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_fMvrs79X_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_ss0gUpSR, 1, m, &cDelay_ss0gUpSR_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9ofYrRp5_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_ss0gUpSR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_ss0gUpSR, m);
  cIf_onMessage(_c, &Context(_c)->cIf_ctWIxvkZ, 0, m, &cIf_ctWIxvkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fMvrs79X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_ss0gUpSR, 0, m, &cDelay_ss0gUpSR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9ofYrRp5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_ss0gUpSR, 0, m, &cDelay_ss0gUpSR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Kd3TfG5N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H6Sf6LWK_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_t5jMk02Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Uewqwh0C_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a3ZUWS2Z_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_onteAyFJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_onteAyFJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_acoK4d9D_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_a3ZUWS2Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ctWIxvkZ, 1, m, &cIf_ctWIxvkZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_t5jMk02Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGY4TImD, 0, m, &cIf_vGY4TImD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_H6Sf6LWK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_vGY4TImD, 1, m, &cIf_vGY4TImD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nk9QAFSt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yJPNxfCa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vyYoWK2B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_yJPNxfCa, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_jdN7NNHt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_0Q1dD5UJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_CsoJ8MMV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Ep6JhD3x_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_EQaww9ca_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vtmQQ2Mz_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vtmQQ2Mz_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_mGo2rfX5, 1, m, &cDelay_mGo2rfX5_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_zNPwfLGH_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_mGo2rfX5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mGo2rfX5, m);
  cIf_onMessage(_c, &Context(_c)->cIf_jdN7NNHt, 0, m, &cIf_jdN7NNHt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vtmQQ2Mz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_mGo2rfX5, 0, m, &cDelay_mGo2rfX5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_zNPwfLGH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mGo2rfX5, 0, m, &cDelay_mGo2rfX5_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_ekAdL1QF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9oG6PpQZ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RiZUtDpk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NHNV42eg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OhmNPJx3_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4wNxmQpS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4wNxmQpS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_EQaww9ca_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_OhmNPJx3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_jdN7NNHt, 1, m, &cIf_jdN7NNHt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_RiZUtDpk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CsoJ8MMV, 0, m, &cIf_CsoJ8MMV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9oG6PpQZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_CsoJ8MMV, 1, m, &cIf_CsoJ8MMV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Ep6JhD3x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_av0Qnxwf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_0Q1dD5UJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_av0Qnxwf, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_RW7e0Y5W_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_nk52yDOc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_fKoLHLC4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_M2hZtQ0E_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_x7NPxBy8_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_vhtXq42c_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_vhtXq42c_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_0sI8c5lv, 1, m, &cDelay_0sI8c5lv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_WUpm1dH4_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_0sI8c5lv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_0sI8c5lv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_RW7e0Y5W, 0, m, &cIf_RW7e0Y5W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_vhtXq42c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_0sI8c5lv, 0, m, &cDelay_0sI8c5lv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_WUpm1dH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_0sI8c5lv, 0, m, &cDelay_0sI8c5lv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_TlmyOwfr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXVBRk25_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4LIukiuX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_PYZGBP0d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_VaNJDAzG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_f5YgTU64_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_f5YgTU64_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_x7NPxBy8_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_VaNJDAzG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_RW7e0Y5W, 1, m, &cIf_RW7e0Y5W_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_hXVBRk25_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKoLHLC4, 1, m, &cIf_fKoLHLC4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_4LIukiuX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_fKoLHLC4, 0, m, &cIf_fKoLHLC4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_M2hZtQ0E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUBmlDLt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nk52yDOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_LUBmlDLt, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_xDhNsBrj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_LrOu1BF0_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_5lN9meyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_ueA5pcd3_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_0ocXzAbp_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_KocUYQ9w_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_KocUYQ9w_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Rnwy9Xdh, 1, m, &cDelay_Rnwy9Xdh_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ckq4nLVR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Rnwy9Xdh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Rnwy9Xdh, m);
  cIf_onMessage(_c, &Context(_c)->cIf_xDhNsBrj, 0, m, &cIf_xDhNsBrj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_KocUYQ9w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rnwy9Xdh, 0, m, &cDelay_Rnwy9Xdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ckq4nLVR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Rnwy9Xdh, 0, m, &cDelay_Rnwy9Xdh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_f6BNtz5S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JTEY9tuL_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Wfskm2js_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_6Hvup7BG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_y8r0M9ac_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LdlNz0eK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_LdlNz0eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_0ocXzAbp_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_y8r0M9ac_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_xDhNsBrj, 1, m, &cIf_xDhNsBrj_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JTEY9tuL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lN9meyw, 1, m, &cIf_5lN9meyw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Wfskm2js_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5lN9meyw, 0, m, &cIf_5lN9meyw_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ueA5pcd3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jhbFsZEl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_LrOu1BF0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jhbFsZEl, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_otYqyaTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_Tf1pWpQ4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_wrTBJ62U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_UwNPRRDH_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_F9O4cwa6_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_8Ex30Eyv_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_8Ex30Eyv_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_LQUtb0Kz, 1, m, &cDelay_LQUtb0Kz_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_geyv9GFM_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_LQUtb0Kz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_LQUtb0Kz, m);
  cIf_onMessage(_c, &Context(_c)->cIf_otYqyaTM, 0, m, &cIf_otYqyaTM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8Ex30Eyv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_LQUtb0Kz, 0, m, &cDelay_LQUtb0Kz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_geyv9GFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_LQUtb0Kz, 0, m, &cDelay_LQUtb0Kz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DNU7ymjb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_e6LNmbR6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BZCwNzcU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KJI4y0nH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_q2qiKtml_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lqLERgU9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_q2qiKtml_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_otYqyaTM, 1, m, &cIf_otYqyaTM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_lqLERgU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_F9O4cwa6_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_e6LNmbR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wrTBJ62U, 1, m, &cIf_wrTBJ62U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_BZCwNzcU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_wrTBJ62U, 0, m, &cIf_wrTBJ62U_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_UwNPRRDH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YLynZFV2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Tf1pWpQ4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_YLynZFV2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_FjOilOoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_1B9mXGFn_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_Jm4Rl3b7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_fTpjFRih_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_9Vt6ocqc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_lh8KwdLE_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_lh8KwdLE_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_jY3uiEvv, 1, m, &cDelay_jY3uiEvv_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9zfKmF1Z_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_jY3uiEvv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_jY3uiEvv, m);
  cIf_onMessage(_c, &Context(_c)->cIf_FjOilOoX, 0, m, &cIf_FjOilOoX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_lh8KwdLE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_jY3uiEvv, 0, m, &cDelay_jY3uiEvv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_9zfKmF1Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_jY3uiEvv, 0, m, &cDelay_jY3uiEvv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_fBuZV20T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2k1S8V8n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_1AHa6nJf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_vMs1uDdg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jnXDx7n6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ne17wGNW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ne17wGNW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_9Vt6ocqc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_jnXDx7n6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_FjOilOoX, 1, m, &cIf_FjOilOoX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1AHa6nJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jm4Rl3b7, 0, m, &cIf_Jm4Rl3b7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_2k1S8V8n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_Jm4Rl3b7, 1, m, &cIf_Jm4Rl3b7_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fTpjFRih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vQteJK76, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_1B9mXGFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_vQteJK76, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_k3OIqH7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_yqnVzIgJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_AMwN3tME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_PJ0f8E5F_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_brscfm2v_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_IDyClcDr_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_IDyClcDr_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_FR2CEYio, 1, m, &cDelay_FR2CEYio_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_uGYXCYtI_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_FR2CEYio_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_FR2CEYio, m);
  cIf_onMessage(_c, &Context(_c)->cIf_k3OIqH7X, 0, m, &cIf_k3OIqH7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IDyClcDr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_FR2CEYio, 0, m, &cDelay_FR2CEYio_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_uGYXCYtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_FR2CEYio, 0, m, &cDelay_FR2CEYio_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_SuNGaSax_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_OVO3wQBG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_exZdKPZz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_F9kyeKcO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_5zznYGVk_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PoKxwFE0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_5zznYGVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_k3OIqH7X, 1, m, &cIf_k3OIqH7X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PoKxwFE0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_brscfm2v_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_exZdKPZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AMwN3tME, 0, m, &cIf_AMwN3tME_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_OVO3wQBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_AMwN3tME, 1, m, &cIf_AMwN3tME_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_PJ0f8E5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jDIBKC49, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_yqnVzIgJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jDIBKC49, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_GjTIPuNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_g6JWdat4_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_M1FuGUsM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_SgdljnaI_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Fll0NiZR_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_kjBXhVrg_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_kjBXhVrg_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_67i5e18Q, 1, m, &cDelay_67i5e18Q_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CblyBakP_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_67i5e18Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_67i5e18Q, m);
  cIf_onMessage(_c, &Context(_c)->cIf_GjTIPuNv, 0, m, &cIf_GjTIPuNv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kjBXhVrg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_67i5e18Q, 0, m, &cDelay_67i5e18Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_CblyBakP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_67i5e18Q, 0, m, &cDelay_67i5e18Q_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_qMRMJ6Sg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_bFK6kTXP_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7OLQrAOD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_QukupdgB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_l9P1sFng_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7TFPiDNU_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7TFPiDNU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Fll0NiZR_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_l9P1sFng_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_GjTIPuNv, 1, m, &cIf_GjTIPuNv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_bFK6kTXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1FuGUsM, 1, m, &cIf_M1FuGUsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_7OLQrAOD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_M1FuGUsM, 0, m, &cIf_M1FuGUsM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_SgdljnaI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kwUgVFKH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_g6JWdat4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_kwUgVFKH, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_3ExpUGu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_sgS2uD8a_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_1oAcPXRq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_FbOqXgfA_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_QACI7KGL_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_NLN9ANJ6_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_NLN9ANJ6_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_B2krxHXI, 1, m, &cDelay_B2krxHXI_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZaAG48rr_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_B2krxHXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_B2krxHXI, m);
  cIf_onMessage(_c, &Context(_c)->cIf_3ExpUGu9, 0, m, &cIf_3ExpUGu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_NLN9ANJ6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2krxHXI, 0, m, &cDelay_B2krxHXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_ZaAG48rr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_B2krxHXI, 0, m, &cDelay_B2krxHXI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Ee2JhsQ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JDciVZaU_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_MKgyvEjX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_d4ObRejk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fyzf6n8T_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_u3nC6NiQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Fyzf6n8T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3ExpUGu9, 1, m, &cIf_3ExpUGu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_u3nC6NiQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QACI7KGL_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_MKgyvEjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1oAcPXRq, 0, m, &cIf_1oAcPXRq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_JDciVZaU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1oAcPXRq, 1, m, &cIf_1oAcPXRq_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_FbOqXgfA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AmMnkekN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_sgS2uD8a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_AmMnkekN, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cIf_2Kb6dEtQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_CY4U6mFc_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_64MJqVbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_eRRjux9z_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cSwitchcase_1a3oStTY_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_78rM1P4a_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_78rM1P4a_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_bMH0LHYf, 1, m, &cDelay_bMH0LHYf_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_3YmKwhSw_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_bMH0LHYf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_bMH0LHYf, m);
  cIf_onMessage(_c, &Context(_c)->cIf_2Kb6dEtQ, 0, m, &cIf_2Kb6dEtQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_78rM1P4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_bMH0LHYf, 0, m, &cDelay_bMH0LHYf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_3YmKwhSw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_bMH0LHYf, 0, m, &cDelay_bMH0LHYf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_DVjemPTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Oqgd0dfN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_itmO0d8f_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_clyMwTGU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ybWjhmcs_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_rZEh3Q7D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_rZEh3Q7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_1a3oStTY_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_ybWjhmcs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Kb6dEtQ, 1, m, &cIf_2Kb6dEtQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_Oqgd0dfN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_64MJqVbY, 1, m, &cIf_64MJqVbY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_itmO0d8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_64MJqVbY, 0, m, &cIf_64MJqVbY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_eRRjux9z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r5jsoVuv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_CY4U6mFc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_r5jsoVuv, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_s7qQrvi6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CFS");
  cMsg_IYEcCQeB_sendMessage(_c, 0, m);
  cMsg_ep9GF2ZJ_sendMessage(_c, 0, m);
  cMsg_ONn9k8Gy_sendMessage(_c, 0, m);
  cMsg_s0DQrUfn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ixOfYBdb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "CSF");
  cMsg_IYEcCQeB_sendMessage(_c, 0, m);
  cMsg_fHKLcLnw_sendMessage(_c, 0, m);
  cMsg_4egA35I8_sendMessage(_c, 0, m);
  cMsg_S5X8fnGS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_nxc9jXB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FCS");
  cMsg_0hKgFF5F_sendMessage(_c, 0, m);
  cMsg_fHKLcLnw_sendMessage(_c, 0, m);
  cMsg_s0DQrUfn_sendMessage(_c, 0, m);
  cMsg_JCfRRCaM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_I3Is7RId_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "FSC");
  cMsg_0hKgFF5F_sendMessage(_c, 0, m);
  cMsg_wuThpAtT_sendMessage(_c, 0, m);
  cMsg_ONn9k8Gy_sendMessage(_c, 0, m);
  cMsg_9qVQPB6V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_99R8XjBQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SCF");
  cMsg_TzYLfCem_sendMessage(_c, 0, m);
  cMsg_S5X8fnGS_sendMessage(_c, 0, m);
  cMsg_Q4zv3v9T_sendMessage(_c, 0, m);
  cMsg_ONn9k8Gy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_8MwUYxWc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "SFC");
  cMsg_TzYLfCem_sendMessage(_c, 0, m);
  cMsg_9qVQPB6V_sendMessage(_c, 0, m);
  cMsg_fHKLcLnw_sendMessage(_c, 0, m);
  cMsg_SCei1SMq_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_u78qfw6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1JXGfDwl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_I0wHh1C4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qR8DjK4I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_1JXGfDwl_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_I0wHh1C4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TX3HopXM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8p9v99Pr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H5G7eeSL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_wFNOUGE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_8p9v99Pr_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_H5G7eeSL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_C3D6WXfO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Uewqwh0C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kd3TfG5N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_7imXomnO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_Uewqwh0C_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Kd3TfG5N_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IYEcCQeB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_u78qfw6r_sendMessage(_c, 0, m);
  cMsg_wFNOUGE9_sendMessage(_c, 0, m);
  cMsg_7imXomnO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_0hKgFF5F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_qR8DjK4I_sendMessage(_c, 0, m);
  cMsg_TX3HopXM_sendMessage(_c, 0, m);
  cMsg_7imXomnO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_TzYLfCem_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_qR8DjK4I_sendMessage(_c, 0, m);
  cMsg_wFNOUGE9_sendMessage(_c, 0, m);
  cMsg_C3D6WXfO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_9FKrGKCm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NHNV42eg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ekAdL1QF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qQH8ul0q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_NHNV42eg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ekAdL1QF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_sugHDxaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PYZGBP0d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TlmyOwfr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m7d1FnaO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_PYZGBP0d_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_TlmyOwfr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Lb9e2vRI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6Hvup7BG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f6BNtz5S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_m3ynx1Nu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_6Hvup7BG_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_f6BNtz5S_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fHKLcLnw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_qQH8ul0q_sendMessage(_c, 0, m);
  cMsg_m7d1FnaO_sendMessage(_c, 0, m);
  cMsg_m3ynx1Nu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ep9GF2ZJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_qQH8ul0q_sendMessage(_c, 0, m);
  cMsg_sugHDxaY_sendMessage(_c, 0, m);
  cMsg_Lb9e2vRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_wuThpAtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_9FKrGKCm_sendMessage(_c, 0, m);
  cMsg_m7d1FnaO_sendMessage(_c, 0, m);
  cMsg_Lb9e2vRI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_qJcCA0aa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QukupdgB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qMRMJ6Sg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_Tiyw2Cok_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_QukupdgB_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_qMRMJ6Sg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kcPJ5yoV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d4ObRejk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ee2JhsQ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_YqSZybNv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_d4ObRejk_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_Ee2JhsQ1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mhEOi6YD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_clyMwTGU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DVjemPTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_xldyr3V3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_clyMwTGU_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DVjemPTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_9qVQPB6V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_100");
  cMsg_qJcCA0aa_sendMessage(_c, 0, m);
  cMsg_YqSZybNv_sendMessage(_c, 0, m);
  cMsg_xldyr3V3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_S5X8fnGS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_010");
  cMsg_Tiyw2Cok_sendMessage(_c, 0, m);
  cMsg_kcPJ5yoV_sendMessage(_c, 0, m);
  cMsg_xldyr3V3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_s0DQrUfn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_001");
  cMsg_Tiyw2Cok_sendMessage(_c, 0, m);
  cMsg_YqSZybNv_sendMessage(_c, 0, m);
  cMsg_mhEOi6YD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_ugJm7Kni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KJI4y0nH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DNU7ymjb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0Ir5vVPe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KJI4y0nH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_DNU7ymjb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kdoHpuhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vMs1uDdg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fBuZV20T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_8zvD7nov_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_vMs1uDdg_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_fBuZV20T_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_hSjKAd8t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_F9kyeKcO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SuNGaSax_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_DCmsvnnH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_F9kyeKcO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_SuNGaSax_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ONn9k8Gy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_000");
  cMsg_0Ir5vVPe_sendMessage(_c, 0, m);
  cMsg_8zvD7nov_sendMessage(_c, 0, m);
  cMsg_DCmsvnnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_4egA35I8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_011");
  cMsg_0Ir5vVPe_sendMessage(_c, 0, m);
  cMsg_kdoHpuhL_sendMessage(_c, 0, m);
  cMsg_hSjKAd8t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_SCei1SMq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_ugJm7Kni_sendMessage(_c, 0, m);
  cMsg_kdoHpuhL_sendMessage(_c, 0, m);
  cMsg_DCmsvnnH_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_Q4zv3v9T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_110");
  cMsg_9FKrGKCm_sendMessage(_c, 0, m);
  cMsg_sugHDxaY_sendMessage(_c, 0, m);
  cMsg_m3ynx1Nu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_JCfRRCaM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "_101");
  cMsg_ugJm7Kni_sendMessage(_c, 0, m);
  cMsg_8zvD7nov_sendMessage(_c, 0, m);
  cMsg_hSjKAd8t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_JJkreiTf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EmvnDv1Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_NhZZeXqz_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x3934C683: { // "fldr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_ERXa2bJF, 0, m, &cSlice_ERXa2bJF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TV76RkbE_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_ERXa2bJF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_hJgrhnGC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_hJgrhnGC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_od1OwaME_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_hJgrhnGC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_hJgrhnGC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_W3baB6wG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_ffXB19DS_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x17E7AF38: { // "sqnc"
      cSlice_onMessage(_c, &Context(_c)->cSlice_0qHDLtrF, 0, m, &cSlice_0qHDLtrF_sendMessage);
      break;
    }
    default: {
      cSwitchcase_Q8tetHgq_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_0qHDLtrF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_G9s7HDJP_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_G9s7HDJP_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_ZVQfhjrS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_G9s7HDJP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_G9s7HDJP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_A0mbZtMg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Q8tetHgq_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x941862B0: { // "crshr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_4h6IWqnl, 0, m, &cSlice_4h6IWqnl_sendMessage);
      break;
    }
    default: {
      cSwitchcase_NhZZeXqz_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_4h6IWqnl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_4OrgwXc8_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_4OrgwXc8_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_JbhBOW5r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_4OrgwXc8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_4OrgwXc8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_INLN09Vu_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_TV76RkbE_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xAB63864D: { // "smthr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_pKh7VVQY, 0, m, &cSlice_pKh7VVQY_sendMessage);
      break;
    }
    default: {
      cSwitchcase_p6WjAqG7_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_pKh7VVQY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_HzM2M3Hr_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_HzM2M3Hr_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_Bfj9wGP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_HzM2M3Hr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_HzM2M3Hr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_UJ59Bu7P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_p6WjAqG7_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC4C86346: { // "lmtr"
      cSlice_onMessage(_c, &Context(_c)->cSlice_q71S3QrA, 0, m, &cSlice_q71S3QrA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_57xGissZ_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_q71S3QrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_W6RkxfvK_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_W6RkxfvK_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_YSy0327d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_W6RkxfvK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_W6RkxfvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zfNhCLUy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_Va9bdA3V_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x7A5B032D: { // "stop"
      cMsg_MAkw2EE5_sendMessage(_c, 0, m);
      break;
    }
    default: {
      cMsg_MAkw2EE5_sendMessage(_c, 0, m);
      cDelay_onMessage(_c, &Context(_c)->cDelay_Kj2LutTn, 1, m, &cDelay_Kj2LutTn_sendMessage);
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_refG2UiR_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cDelay_Kj2LutTn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_Kj2LutTn, m);
  cMsg_KEwjTPJO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_MAkw2EE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kj2LutTn, 0, m, &cDelay_Kj2LutTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_refG2UiR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_Kj2LutTn, 0, m, &cDelay_Kj2LutTn_sendMessage);
}

void Heavy_WSTD_M3NGLR::cVar_1mhhbBOP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KKAk0kUi, HV_BINOP_SUBTRACT, 0, m, &cBinop_KKAk0kUi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cIf_SwV6Xnj2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TGGIPoS2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cIf_ELY9e30A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cMsg_TGGIPoS2_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::sEnv_dnYJh9KV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1mhhbBOP, 0, m, &cVar_1mhhbBOP_sendMessage);
}

void Heavy_WSTD_M3NGLR::sEnv_jilBNwLN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1szdnKKQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_vLeNRJ31_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kNn7slwA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_KKAk0kUi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_V9yPHehe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_V9yPHehe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_NIDx9iPk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_NIDx9iPk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_FxzXrzOs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_uZJkJIJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_NkqJh3VO_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PXTf34q6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_PXTf34q6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rkwLuhQv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_NkqJh3VO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_SwV6Xnj2, 1, m, &cIf_SwV6Xnj2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_aAqicyU9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ELY9e30A, 1, m, &cIf_ELY9e30A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_rkwLuhQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_SwV6Xnj2, 0, m, &cIf_SwV6Xnj2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_FxzXrzOs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ELY9e30A, 0, m, &cIf_ELY9e30A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_1szdnKKQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_M3NGLR::cCast_vLeNRJ31_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_KKAk0kUi, HV_BINOP_SUBTRACT, 1, m, &cBinop_KKAk0kUi_sendMessage);
}

void Heavy_WSTD_M3NGLR::cCast_kNn7slwA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1mhhbBOP, 0, m, &cVar_1mhhbBOP_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_TGGIPoS2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KZ1utVkS, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cSwitchcase_57xGissZ_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x811CC33F: { // "gain"
      cSlice_onMessage(_c, &Context(_c)->cSlice_VOZqoH2f, 0, m, &cSlice_VOZqoH2f_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_M3NGLR::cSlice_VOZqoH2f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_AhFkNeP6_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_AhFkNeP6_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_M3NGLR::cVar_SCaqXKRd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_AhFkNeP6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cSend_AhFkNeP6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_0VhwiLjE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6148qt08_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_f75shRFM, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_noiBVB7T_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_xbNZdjGY, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_bOj9m5Mo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dAI301q4, 0, m, &cVar_dAI301q4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EmvnDv1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5tAv0asA, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cCast_L8hcSFkX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_qzyIpJhP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cCast_ZrHtvFZG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_Va9bdA3V_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KEwjTPJO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2memqOg2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_qzyIpJhP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  msg_setFloat(m, 1, 20.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2memqOg2, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_PaMjJiKr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0f, 0, m, &cBinop_Msrb8Z9X_sendMessage);
}

void Heavy_WSTD_M3NGLR::cBinop_Msrb8Z9X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f1jzZtjQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_f1jzZtjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_0pQCN5Kc, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cVar_F2JUtxO0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_J2Ge1SIj_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_Gg1N0RoL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fNsobbve_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cVar_ZscTOtxg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZLKR3ElN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cMsg_6GjctN8b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_jUyHiKIU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_1lumehQ2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ANoxoS0D, 0, m, &cVar_ANoxoS0D_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_IOX3N6Rw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_2TwmBkBu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_KvU59mpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Gpgy4UtF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_UNm64l6V, 0, m, &cVar_UNm64l6V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WCZiDKA9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_t2srMOuV, 0, m, &cVar_t2srMOuV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hrxvJqeQ, 0, m, &cVar_hrxvJqeQ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_aU3F5Jd1, 0, m, &cVar_aU3F5Jd1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K7T7FO4t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1lumehQ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MqDFcBk2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qwFdCkyp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jud91XcT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_uVSEbXLW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qwFdCkyp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jud91XcT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_vxLkark2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qwFdCkyp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jud91XcT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nAPBExwT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qwFdCkyp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jud91XcT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_pUR6BqWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_qwFdCkyp_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_jud91XcT_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_QbwaTmSS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ql6eD9bC, 0, m, &cVar_ql6eD9bC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_qiXPYBhH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_x401s5wK, 0, m, &cVar_x401s5wK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dfIeFrSo, 0, m, &cVar_dfIeFrSo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0VOdPL9A, 0, m, &cVar_0VOdPL9A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_kfMCPTbY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5nxG9YoM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_tmAMycYZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_DqPoVFlM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Uk3kaKCv, 0, m, &cVar_Uk3kaKCv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_j8dOkJWd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_OAC3wJg5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_nlkaU7JX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_YnHXBBzv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_o5IInfu9, 0, m, &cVar_o5IInfu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_WMGXhtEy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_WzuETTt3, 0, m, &cVar_WzuETTt3_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bBlv1pdg, 0, m, &cVar_bBlv1pdg_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_CAgNaqfD, 0, m, &cVar_CAgNaqfD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_MSRaj4hB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DqPoVFlM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_EdydHkrE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JCLT5GMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "sqnc");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_7Uxf0fBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "crshr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cBinop_ixlYq5wp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UqRHDobZ, 0, m, &cVar_UqRHDobZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_0NwREtS1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "fldr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_Z1eLQHLP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "smthr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_JjxjDK7X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lmtr");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_UK7pc5TS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 512.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_J8bNZ8mH, 0, m, &cVar_J8bNZ8mH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_K2NiRv2I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_tt107kmR, 0, m, &cVar_tt107kmR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_B0fzY4Mz, 0, m, &cVar_B0fzY4Mz_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3s77ndu3, 0, m, &cVar_3s77ndu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_mK1gyyqo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 50.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ixlYq5wp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_nhL0BKb2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_4bsFDn0v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_F2JUtxO0, 0, m, &cVar_F2JUtxO0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_J2Ge1SIj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_yKmTuSkA_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_d1gvFEHu_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_CrfFF1Pv_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_5j8dPEcQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_Gg1N0RoL, 0, m, &cVar_Gg1N0RoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_fNsobbve_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_OjbWPjkg_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_y1wv3DDc_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_U6TnF0VU_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cMsg_FEy2u4VR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_ZscTOtxg, 0, m, &cVar_ZscTOtxg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cMsg_ZLKR3ElN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "gain");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_sDkBdLMt_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_H5y9rPwl_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_ffXB19DS_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_M3NGLR::cReceive_c2q5pVtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KpjeAZEh_sendMessage(_c, 0, m);
  cMsg_NBI7xJm4_sendMessage(_c, 0, m);
  cMsg_4LzNRlmt_sendMessage(_c, 0, m);
  cMsg_pJ2a2TEG_sendMessage(_c, 0, m);
  cMsg_dOYbG3EP_sendMessage(_c, 0, m);
  cMsg_Lko05aQJ_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1hzxuc6y, 0, m, &cVar_1hzxuc6y_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SBA0vJMJ, 0, m, &cVar_SBA0vJMJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QfWHOMo4, 0, m, &cVar_QfWHOMo4_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_f2gVMdop, 0, m, &cVar_f2gVMdop_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_jTIhYFUW, 0, m, &cVar_jTIhYFUW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_0dyI41HF, 0, m, &cVar_0dyI41HF_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OTZ2P7km, 0, m, &cVar_OTZ2P7km_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_H9Gi5V0f, 0, m, &cVar_H9Gi5V0f_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WMx4uUvf, 0, m, &cVar_WMx4uUvf_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SDIKrpL5, 0, m, &cVar_SDIKrpL5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_pl2tJWT2, 0, m, &cVar_pl2tJWT2_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bMHruCBO, 0, m, &cVar_bMHruCBO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3OrgEmYu, 0, m, &cVar_3OrgEmYu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Sgsf3ZbE, 0, m, &cVar_Sgsf3ZbE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_LoyYGURe, 0, m, &cVar_LoyYGURe_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_D01V6tuc, 0, m, &cVar_D01V6tuc_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ObQdHxPu, 0, m, &cVar_ObQdHxPu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Z2TEJbtH, 0, m, &cVar_Z2TEJbtH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_8jftzPAU, 0, m, &cVar_8jftzPAU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_igAYNggO, 0, m, &cVar_igAYNggO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_BWypEAXZ, 0, m, &cVar_BWypEAXZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_XwJxRsjH, 0, m, &cVar_XwJxRsjH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_z9hPylKB, 0, m, &cVar_z9hPylKB_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3gr4lKTW, 0, m, &cVar_3gr4lKTW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_92fkXwrb, 0, m, &cVar_92fkXwrb_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_uCmw2PU5, 0, m, &cVar_uCmw2PU5_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HMiy9kLM, 0, m, &cVar_HMiy9kLM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_FBlTI44G, 0, m, &cVar_FBlTI44G_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_WJJsmunl, 0, m, &cVar_WJJsmunl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_urQ5YvlS, 0, m, &cVar_urQ5YvlS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_F6FlagqR, 0, m, &cVar_F6FlagqR_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_X9myvkOo, 0, m, &cVar_X9myvkOo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MwJZ4u8i, 0, m, &cVar_MwJZ4u8i_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sbW5KNdv, 0, m, &cVar_sbW5KNdv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dCjjf22c, 0, m, &cVar_dCjjf22c_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_v1NcJ2xK, 0, m, &cVar_v1NcJ2xK_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_HwxfjEpU, 0, m, &cVar_HwxfjEpU_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_sYIMqyLJ, 0, m, &cVar_sYIMqyLJ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vhmyuMDW, 0, m, &cVar_vhmyuMDW_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_S5fobO4Z, 0, m, &cVar_S5fobO4Z_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yTME66iv, 0, m, &cVar_yTME66iv_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_3nK0NnTV, 0, m, &cVar_3nK0NnTV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_eMhmVhWY, 0, m, &cVar_eMhmVhWY_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_OGLSHQsE, 0, m, &cVar_OGLSHQsE_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_EVRkzr0V, 0, m, &cVar_EVRkzr0V_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_9YSxDuk8, 0, m, &cVar_9YSxDuk8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2l0hewhX, 0, m, &cVar_2l0hewhX_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1PcKOm4d, 0, m, &cVar_1PcKOm4d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hpRgXWjw, 0, m, &cVar_hpRgXWjw_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_w98lOufV, 0, m, &cVar_w98lOufV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Rp716uJV, 0, m, &cVar_Rp716uJV_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_yGdqV43V, 0, m, &cVar_yGdqV43V_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_od1OwaME, 0, m, &cVar_od1OwaME_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ZVQfhjrS, 0, m, &cVar_ZVQfhjrS_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JbhBOW5r, 0, m, &cVar_JbhBOW5r_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Bfj9wGP1, 0, m, &cVar_Bfj9wGP1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_YSy0327d, 0, m, &cVar_YSy0327d_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_SCaqXKRd, 0, m, &cVar_SCaqXKRd_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_2aiK2hlL, 0, m, &cVar_2aiK2hlL_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_JVVr0Q7E, 0, m, &cVar_JVVr0Q7E_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vL5ey5TI, 0, m, &cVar_vL5ey5TI_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_q0SjDn7o_sendMessage);
  cMsg_qiXPYBhH_sendMessage(_c, 0, m);
  cMsg_QbwaTmSS_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_fGVlq1m6_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CkdO755a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_03kgjAGq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_x401s5wK, 0, m, &cVar_x401s5wK_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_wQWWqu5Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dfIeFrSo, 0, m, &cVar_dfIeFrSo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_H6Vz713m_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0VOdPL9A, 0, m, &cVar_0VOdPL9A_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MbsV1Hv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_SBA0vJMJ, 0, m, &cVar_SBA0vJMJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_z96SEoXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XkGZuSHD_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_lTvgGQyk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_F7IKarLw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ppibXfJ9_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jMT8wgVI_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8dgexT31_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_F8MMBkyb_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ocn5XkjC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EHPPrcrN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2cH8YKe3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LV4FwSja_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FwZr2ReT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_2RciBVR6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FxSk2Ffv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JgFlA5G4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GvDS1hJl_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_AA6JqhS2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Sgh3UyTI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_goAi8gRr, HV_BINOP_MULTIPLY, 0, m, &cBinop_goAi8gRr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5oi9trp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gQSWK4Ri_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zaC2uFZL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_wGs7DW2K_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_F1KrK9G3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_MecXVwjQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_mBHohOiA_sendMessage);
  cMsg_CmhWF3vP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_YOG0aCDb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Ll55qBgv, HV_BINOP_MULTIPLY, 0, m, &cBinop_Ll55qBgv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hat5UxDB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_3gGUE1bV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Tozsa6gb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gIcawS0O, HV_BINOP_MULTIPLY, 1, m, &cBinop_gIcawS0O_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_EerayB2D_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_NowfelGT_sendMessage);
  cMsg_jaEDejHh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_rPnGoAOl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dWg4uJIT, HV_BINOP_MULTIPLY, 0, m, &cBinop_dWg4uJIT_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_JCxtIqmu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xuSrrsST_sendMessage(_c, 0, m);
  cMsg_RkY8XwSe_sendMessage(_c, 0, m);
  cMsg_hs1HHeFu_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_AeOgBwRI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_WeYFFl5J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_rOFwICAn_sendMessage);
  cMsg_K96rd5SY_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_0MenaF0f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_jTIhYFUW, 0, m, &cVar_jTIhYFUW_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_cbag8ikB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6odX7emG_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XM26asc1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_iZbxolyR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_haCla0Yy_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lnA4jiuo_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Iut9Zp5X_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_QdoGSRPS_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_xXx3nCly_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FL0iU4DP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WbVpi0G6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8OBZ3pKO_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_0OgpXSfs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qlYy8Qs8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Mmo5SnoK_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_doFaraQg_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_mmiARB7B_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Mkdu68qm_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_hRMSv4lO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bzEQL0sg, HV_BINOP_MULTIPLY, 0, m, &cBinop_bzEQL0sg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_IheAKCyK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_qXELnFEE_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_AZ6rfaj0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nUkuju3r_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_pOgMFJLF_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_NaSUQiIh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_71EeiSw1_sendMessage);
  cMsg_GODCCzmm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_82FIMiGx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3Cjv9tmM, HV_BINOP_MULTIPLY, 0, m, &cBinop_3Cjv9tmM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_CGV71T41_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_sjqx9HeN_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_xKCW8ttE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_m59Rl0cm, HV_BINOP_MULTIPLY, 1, m, &cBinop_m59Rl0cm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_txqrNtCx_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_juG8XJbE_sendMessage);
  cMsg_6U2EFECM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_WgV3T3a9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Kv1LGaau, HV_BINOP_MULTIPLY, 0, m, &cBinop_Kv1LGaau_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lPtc1f28_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_1uLWW5VJ_sendMessage(_c, 0, m);
  cMsg_Lfh8GRe6_sendMessage(_c, 0, m);
  cMsg_82ZEmurv_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_tB9rpW9J_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qx1TG3pE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_eylfnoC2_sendMessage);
  cMsg_44d0hBp5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_BWr4Bhkr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ql6eD9bC, 0, m, &cVar_ql6eD9bC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zS1Yh3sI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UkvQXLun, 0, m, &cVar_UkvQXLun_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ZKzQYbp2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_UNm64l6V, 0, m, &cVar_UNm64l6V_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PAI1zk1l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_t2srMOuV, 0, m, &cVar_t2srMOuV_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_gtI7xczI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hrxvJqeQ, 0, m, &cVar_hrxvJqeQ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_PILjxj6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aU3F5Jd1, 0, m, &cVar_aU3F5Jd1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4PrqtyvK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_1lumehQ2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_jq610ngy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_G6p6rTS4_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_yswX0X1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5vBgnkK1, 0, m, &cVar_5vBgnkK1_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_3XhBrWas_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_pL5UZ1Is, 0, m, &cVar_pL5UZ1Is_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_OdhmSI4S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_5ltHMUEO_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_qIdnTxrl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_SmMxoT4C_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mylml89H_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_au2vb1AZ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_SGEMSXmw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_5czg32lv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_h9jhDNyY_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0SLJF6OU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9c78J1Rc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_gqODNkav_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_yAedVnxt, 0, m, &cVar_yAedVnxt_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_91S31Xcc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_HJLja1XM, 0, m, &cVar_HJLja1XM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_N7BQQldX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_lzjb1pTz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ca30o5aF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kYN7MlIT_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_JeyrZ9mW_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_eq3LjMSC_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Mfy5ktZO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_u11X0jZT_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_AScPSCUs_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_05LfDfJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9PYeYbaK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_w0gOPJeG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_aN2XPNCh_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0CnjV5es_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tn2ePXqD, 0, m, &cVar_tn2ePXqD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nRBUgCin_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_0QlRTjto, 0, m, &cVar_0QlRTjto_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_o47azyYh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_xdCVIDFu_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_EZ9IZk07_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_gBcyRDqD_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LBcdQk3I_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y6fcNLl2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UT3t97H0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_UnSl8Uc3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_nkM1BnvJ_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_EfoRBQJp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_cXuFOwnO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_zlkrlUsY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_27NkG81R, 0, m, &cVar_27NkG81R_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_Xi1JeOfi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PwucdF61, 0, m, &cVar_PwucdF61_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_lER2Hgdo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_PlTub9oI_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_or9HCeyF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_kX8nGbrB_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Yjbf21c8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EVztSda2_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_epbM1BCJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_ok65OL5j_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_cPj2Cr9a_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4KLDXSaJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_w0TgU317_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_q95CCi5Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bXYh4yTv, 0, m, &cVar_bXYh4yTv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_BwNKf0cj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_o5IInfu9, 0, m, &cVar_o5IInfu9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_5Q1DBnSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_WzuETTt3, 0, m, &cVar_WzuETTt3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_vxcFgJZj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_bBlv1pdg, 0, m, &cVar_bBlv1pdg_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_P9jUIBmv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CAgNaqfD, 0, m, &cVar_CAgNaqfD_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_FgIWcSwV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_DqPoVFlM_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_7GJu8k6l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_WCkUPhg6_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_nl28EsCH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_OqkApdR3, 0, m, &cVar_OqkApdR3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_P20tFaNQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_87s3rjuk, 0, m, &cVar_87s3rjuk_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_dREye3mv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_tbdvPbCr_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_4A7w9lRs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_pj6OQGnb_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9QXUv1cw_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_HzXHnm8p_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_E6TOGwJU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_pSiFhhGF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_KjACgIhX_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_EpCrp4U5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GGCCxM6e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_W3baB6wG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ct1PlHLv, 0, m, &cVar_ct1PlHLv_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_UJ59Bu7P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_JJkreiTf, 0, m, &cVar_JJkreiTf_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_INLN09Vu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 2.0f, 0, m, &cBinop_bOj9m5Mo_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_A0mbZtMg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_8muSC8KU_onMessage(_c, NULL, 0, m, NULL);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_L8hcSFkX_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ZrHtvFZG_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_zfNhCLUy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_uZJkJIJe_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 1.0f, 0, m, &cBinop_aAqicyU9_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_0VhwiLjE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PaMjJiKr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_M3NGLR::cReceive_MXUuQtLB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_gtgzGgnA, 0, m, &cVar_gtgzGgnA_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_bsluRFeX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_J8bNZ8mH, 0, m, &cVar_J8bNZ8mH_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_aPtwIGci_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_tt107kmR, 0, m, &cVar_tt107kmR_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_v7ROWZu7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_B0fzY4Mz, 0, m, &cVar_B0fzY4Mz_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_J2WCeMQt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3s77ndu3, 0, m, &cVar_3s77ndu3_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_QR2c8u53_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_ixlYq5wp_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_ySwdauha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_F2JUtxO0, 0, m, &cVar_F2JUtxO0_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_et2HKoJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gg1N0RoL, 0, m, &cVar_Gg1N0RoL_sendMessage);
}

void Heavy_WSTD_M3NGLR::cReceive_I55FWOuw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ZscTOtxg, 0, m, &cVar_ZscTOtxg_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_M3NGLR::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8, Bf9, Bf10, Bf11, Bf12, Bf13, Bf14, Bf15, Bf16, Bf17, Bf18, Bf19, Bf20;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_ZOeBbbVZ, VOf(Bf0));
    __hv_line_f(&sLine_hGf2FpqY, VOf(Bf1));
    __hv_line_f(&sLine_9Xgar7jj, VOf(Bf2));
    __hv_line_f(&sLine_MKJ09TSf, VOf(Bf3));
    __hv_line_f(&sLine_hvgeg9sF, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_QwZvdJJN, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf2), VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_Mg9MSduF, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_WOvgOVEU, VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_line_f(&sLine_aN7Jc6BW, VOf(Bf1));
    __hv_line_f(&sLine_4vFahpIw, VOf(Bf0));
    __hv_line_f(&sLine_vBUUph3E, VOf(Bf5));
    __hv_biquad_f(&sBiquad_s_KAqkDk9J, VIf(I0), VIf(Bf4), VIf(Bf2), VIf(Bf1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_EQmP72dH, VOf(Bf0));
    __hv_mul_f(VIf(Bf5), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_rMV9vtvg, VOf(Bf5));
    __hv_line_f(&sLine_SrI2ZcZI, VOf(Bf1));
    __hv_line_f(&sLine_ThP14mLv, VOf(Bf2));
    __hv_line_f(&sLine_8Z45XNva, VOf(Bf4));
    __hv_line_f(&sLine_cO5lWzbm, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_P08K5zH7, VIf(I0), VIf(Bf5), VIf(Bf1), VIf(Bf2), VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_VxqEsrjh, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_cv5YdsnC, VOf(Bf6));
    __hv_line_f(&sLine_xFV4yTk9, VOf(Bf2));
    __hv_line_f(&sLine_z24rrDfZ, VOf(Bf1));
    __hv_line_f(&sLine_V7LUW4nh, VOf(Bf5));
    __hv_line_f(&sLine_RnPwQuAo, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_2FTIEPeW, VIf(I1), VIf(Bf6), VIf(Bf2), VIf(Bf1), VIf(Bf5), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_jvbffNYL, VOf(Bf5));
    __hv_mul_f(VIf(Bf7), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_CMani0fC, VOf(Bf7));
    __hv_zero_f(VOf(Bf1));
    __hv_line_f(&sLine_PLd9bjgH, VOf(Bf2));
    __hv_line_f(&sLine_VHBmNeoE, VOf(Bf6));
    __hv_line_f(&sLine_1XFfSDBF, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_lU6SMEuO, VIf(I1), VIf(Bf7), VIf(Bf1), VIf(Bf2), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_8RDoSDxF, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_dNtwdJeF, VOf(Bf8));
    __hv_line_f(&sLine_65gaAlL7, VOf(Bf2));
    __hv_line_f(&sLine_BOVxuxvB, VOf(Bf1));
    __hv_line_f(&sLine_4LoNRmDL, VOf(Bf7));
    __hv_line_f(&sLine_tOpsZd1x, VOf(Bf9));
    __hv_biquad_f(&sBiquad_s_UVSlBIDf, VIf(I1), VIf(Bf8), VIf(Bf2), VIf(Bf1), VIf(Bf7), VIf(Bf9), VOf(Bf9));
    __hv_line_f(&sLine_BGKMYpVJ, VOf(Bf7));
    __hv_mul_f(VIf(Bf9), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_oh7daJb9, VIf(Bf0));
    __hv_varwrite_f(&sVarf_KJpPbryp, VIf(Bf6));
    __hv_varwrite_f(&sVarf_Zm2kcFzT, VIf(Bf4));
    __hv_varwrite_f(&sVarf_yYu6H3uU, VIf(Bf7));
    __hv_varread_f(&sVarf_kLi9NjSN, VOf(Bf7));
    __hv_varread_f(&sVarf_5brH23XQ, VOf(Bf4));
    __hv_varread_f(&sVarf_xBOaD12J, VOf(Bf6));
    __hv_varread_f(&sVarf_5YQTRUbK, VOf(Bf0));
    __hv_varread_f(&sVarf_botqymwU, VOf(Bf9));
    __hv_varread_f(&sVarf_G98Ii2OV, VOf(Bf1));
    __hv_line_f(&sLine_M0BhYKdh, VOf(Bf2));
    __hv_line_f(&sLine_j3vHudWM, VOf(Bf8));
    __hv_mul_f(VIf(Bf0), VIf(Bf8), VOf(Bf0));
    __hv_fma_f(VIf(Bf6), VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf8), VOf(Bf8));
    __hv_fma_f(VIf(Bf9), VIf(Bf2), VIf(Bf8), VOf(Bf8));
    __hv_varwrite_f(&sVarf_xBOaD12J, VIf(Bf7));
    __hv_varwrite_f(&sVarf_botqymwU, VIf(Bf4));
    __hv_varread_f(&sVarf_BTpn5a0u, VOf(Bf2));
    __hv_varread_f(&sVarf_09no9Kk7, VOf(Bf9));
    __hv_varread_f(&sVarf_2HjApR2h, VOf(Bf1));
    __hv_varread_f(&sVarf_WLNirjgn, VOf(Bf6));
    __hv_varread_f(&sVarf_IjEgCF5h, VOf(Bf10));
    __hv_varread_f(&sVarf_MR9JOta2, VOf(Bf11));
    __hv_varread_f(&sVarf_gl3fNEa6, VOf(Bf12));
    __hv_varwrite_f(&sVarf_XXUtD7nQ, VIf(Bf7));
    __hv_varread_f(&sVarf_mSaYzbMP, VOf(Bf13));
    __hv_line_f(&sLine_b6JfQ6Yx, VOf(Bf14));
    __hv_mul_f(VIf(Bf13), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_Qw4Ashuu, VOf(Bf15));
    __hv_line_f(&sLine_TcGiiXx5, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_6F1u4lsb, VOf(Bf14));
    __hv_line_f(&sLine_TsrwImJS, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_WLNirjgn, VIf(Bf17));
    __hv_varread_f(&sVarf_XXUtD7nQ, VOf(Bf17));
    __hv_line_f(&sLine_vgk2A29g, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_5i3cKbwr, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_as6iOcEA, VOf(Bf16));
    __hv_mul_f(VIf(Bf15), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_IjEgCF5h, VIf(Bf16));
    __hv_line_f(&sLine_uZVPAFjQ, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_Y2aK6ioQ, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_rux4Ib7O, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_MR9JOta2, VIf(Bf16));
    __hv_line_f(&sLine_SUsBlk7q, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_vjWx736Y, VOf(Bf17));
    __hv_mul_f(VIf(Bf15), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_x2v0Xapd, VOf(Bf16));
    __hv_mul_f(VIf(Bf13), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_gl3fNEa6, VIf(Bf16));
    __hv_varwrite_f(&sVarf_mSaYzbMP, VIf(Bf2));
    __hv_varwrite_f(&sVarf_Qw4Ashuu, VIf(Bf9));
    __hv_varwrite_f(&sVarf_6F1u4lsb, VIf(Bf1));
    sEnv_process(this, &sEnv_SzU1Mg5w, VIf(Bf6), &sEnv_SzU1Mg5w_sendMessage);
    sEnv_process(this, &sEnv_r1AUVe7v, VIf(Bf7), &sEnv_r1AUVe7v_sendMessage);
    __hv_line_f(&sLine_Hl5evBY3, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_line_f(&sLine_9PytLlaS, VOf(Bf6));
    __hv_mul_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_KAuxWufi, VOf(Bf7));
    __hv_var_k_f(VOf(Bf1), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf7), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf7), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf1), VIf(Bf7), VOf(Bf7));
    __hv_exp_f(VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_aUTsflgY, VOf(Bf6));
    __hv_line_f(&sLine_haNl1Bjx, VOf(Bf1));
    __hv_var_k_f(VOf(Bf9), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf1), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf9), VIf(Bf1), VOf(Bf1));
    __hv_floor_f(VIf(Bf1), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_BTpn5a0u, VIf(Bf9));
    __hv_varwrite_f(&sVarf_aUTsflgY, VIf(Bf10));
    __hv_varwrite_f(&sVarf_vk0dlxjF, VIf(Bf11));
    __hv_varwrite_f(&sVarf_3pWqBGAE, VIf(Bf12));
    __hv_varread_f(&sVarf_3pWqBGAE, VOf(Bf12));
    __hv_line_f(&sLine_JbSmkbzI, VOf(Bf11));
    __hv_mul_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_mul_f(VIf(Bf11), VIf(Bf11), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf12), VIf(Bf10), VOf(Bf9));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf12), VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_2HjApR2h, VIf(Bf10));
    __hv_varread_f(&sVarf_vk0dlxjF, VOf(Bf10));
    __hv_line_f(&sLine_BJG1KiGC, VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf10), VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf9));
    __hv_sub_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_abs_f(VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf9), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf11), VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_neg_f(VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_09no9Kk7, VIf(Bf10));
    __hv_varwrite_f(&sVarf_5YQTRUbK, VIf(Bf7));
    __hv_varread_f(&sVarf_xYXOG4lD, VOf(Bf7));
    __hv_varread_f(&sVarf_PRTAcL6O, VOf(Bf10));
    __hv_varread_f(&sVarf_vnV661We, VOf(Bf9));
    __hv_varread_f(&sVarf_P50ro213, VOf(Bf11));
    __hv_varread_f(&sVarf_MH5D78Wk, VOf(Bf6));
    __hv_varread_f(&sVarf_TlwMpO2c, VOf(Bf12));
    __hv_varread_f(&sVarf_lj7BKeYJ, VOf(Bf1));
    __hv_varwrite_f(&sVarf_an8zVcKP, VIf(Bf4));
    __hv_varread_f(&sVarf_JqLPif8h, VOf(Bf2));
    __hv_line_f(&sLine_Amup6ac7, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_al4cmFl8, VOf(Bf17));
    __hv_line_f(&sLine_5PX6IIL2, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_varread_f(&sVarf_E2USeYes, VOf(Bf16));
    __hv_line_f(&sLine_LE4uBWtt, VOf(Bf15));
    __hv_mul_f(VIf(Bf16), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_P50ro213, VIf(Bf15));
    __hv_varread_f(&sVarf_an8zVcKP, VOf(Bf15));
    __hv_line_f(&sLine_CFcAkCVd, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_fWn3rJPF, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_x3BXTbFk, VOf(Bf13));
    __hv_mul_f(VIf(Bf17), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_MH5D78Wk, VIf(Bf13));
    __hv_line_f(&sLine_Iz1IHbn5, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_6UeR09yG, VOf(Bf18));
    __hv_mul_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_kFMrlk7R, VOf(Bf13));
    __hv_mul_f(VIf(Bf16), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_TlwMpO2c, VIf(Bf13));
    __hv_line_f(&sLine_WehHQnjj, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_KteZ0aWz, VOf(Bf15));
    __hv_mul_f(VIf(Bf17), VIf(Bf15), VOf(Bf15));
    __hv_add_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_line_f(&sLine_oQ3pGVQP, VOf(Bf13));
    __hv_mul_f(VIf(Bf2), VIf(Bf13), VOf(Bf13));
    __hv_add_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_varwrite_f(&sVarf_lj7BKeYJ, VIf(Bf13));
    __hv_varwrite_f(&sVarf_JqLPif8h, VIf(Bf7));
    __hv_varwrite_f(&sVarf_al4cmFl8, VIf(Bf10));
    __hv_varwrite_f(&sVarf_E2USeYes, VIf(Bf9));
    sEnv_process(this, &sEnv_kksJiUaw, VIf(Bf11), &sEnv_kksJiUaw_sendMessage);
    sEnv_process(this, &sEnv_ZjkUFwqk, VIf(Bf4), &sEnv_ZjkUFwqk_sendMessage);
    __hv_line_f(&sLine_q5pfCqxf, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_RfORtUQ1, VOf(Bf11));
    __hv_mul_f(VIf(Bf4), VIf(Bf11), VOf(Bf11));
    __hv_line_f(&sLine_RsX1NoMl, VOf(Bf4));
    __hv_var_k_f(VOf(Bf9), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf9), VOf(Bf9));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf9), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf11), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_UIwRAVdB, VOf(Bf11));
    __hv_line_f(&sLine_rsY2H9Ff, VOf(Bf9));
    __hv_var_k_f(VOf(Bf10), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf9), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf9), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf11), VIf(Bf10), VIf(Bf9), VOf(Bf9));
    __hv_floor_f(VIf(Bf9), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_sub_f(VIf(Bf9), VIf(Bf11), VOf(Bf11));
    __hv_div_f(VIf(Bf11), VIf(Bf10), VOf(Bf10));
    __hv_varwrite_f(&sVarf_xYXOG4lD, VIf(Bf10));
    __hv_varwrite_f(&sVarf_UIwRAVdB, VIf(Bf6));
    __hv_varwrite_f(&sVarf_antCWRGZ, VIf(Bf12));
    __hv_varwrite_f(&sVarf_86J64EOS, VIf(Bf1));
    __hv_varread_f(&sVarf_86J64EOS, VOf(Bf1));
    __hv_line_f(&sLine_zREY1SfF, VOf(Bf12));
    __hv_mul_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf1), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf12), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf12), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf1), VIf(Bf12), VOf(Bf12));
    __hv_mul_f(VIf(Bf12), VIf(Bf12), VOf(Bf1));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf1), VIf(Bf6), VOf(Bf10));
    __hv_var_k_f(VOf(Bf11), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf1), VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf12), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_vnV661We, VIf(Bf6));
    __hv_varread_f(&sVarf_antCWRGZ, VOf(Bf6));
    __hv_line_f(&sLine_WgWslSHv, VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf10));
    __hv_sub_f(VIf(Bf12), VIf(Bf10), VOf(Bf10));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf10), VIf(Bf12), VOf(Bf12));
    __hv_abs_f(VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf10), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf12), VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_PRTAcL6O, VIf(Bf6));
    __hv_varwrite_f(&sVarf_G98Ii2OV, VIf(Bf4));
    __hv_varwrite_f(&sVarf_HDOTMY0t, VIf(Bf0));
    __hv_varread_f(&sVarf_oh7daJb9, VOf(Bf0));
    __hv_varread_f(&sVarf_KJpPbryp, VOf(Bf4));
    __hv_varread_f(&sVarf_eGEbyY3J, VOf(Bf6));
    __hv_varread_f(&sVarf_1PWQLeu9, VOf(Bf10));
    __hv_varread_f(&sVarf_f8qhpCoh, VOf(Bf12));
    __hv_varread_f(&sVarf_r5gL73B1, VOf(Bf11));
    __hv_line_f(&sLine_Ocj7vzbK, VOf(Bf1));
    __hv_line_f(&sLine_vLgVHuBp, VOf(Bf9));
    __hv_mul_f(VIf(Bf10), VIf(Bf9), VOf(Bf10));
    __hv_fma_f(VIf(Bf6), VIf(Bf1), VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf11), VIf(Bf9), VOf(Bf9));
    __hv_fma_f(VIf(Bf12), VIf(Bf1), VIf(Bf9), VOf(Bf9));
    __hv_varwrite_f(&sVarf_eGEbyY3J, VIf(Bf0));
    __hv_varwrite_f(&sVarf_f8qhpCoh, VIf(Bf4));
    __hv_varread_f(&sVarf_EL39LGDp, VOf(Bf1));
    __hv_varread_f(&sVarf_fwF1hmOs, VOf(Bf12));
    __hv_varread_f(&sVarf_qiJx1YSN, VOf(Bf11));
    __hv_varread_f(&sVarf_BYY5UH8x, VOf(Bf6));
    __hv_varread_f(&sVarf_AcClPwmk, VOf(Bf7));
    __hv_varread_f(&sVarf_vMer91M8, VOf(Bf13));
    __hv_varread_f(&sVarf_Tys4FHVn, VOf(Bf15));
    __hv_varwrite_f(&sVarf_PQ81CEKN, VIf(Bf0));
    __hv_varread_f(&sVarf_ZKvaBAy8, VOf(Bf2));
    __hv_line_f(&sLine_33yab13v, VOf(Bf17));
    __hv_mul_f(VIf(Bf2), VIf(Bf17), VOf(Bf17));
    __hv_varread_f(&sVarf_OrOW2xz8, VOf(Bf18));
    __hv_line_f(&sLine_nEOA8aI9, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_cNadffxp, VOf(Bf17));
    __hv_line_f(&sLine_HkB7Kaxa, VOf(Bf14));
    __hv_mul_f(VIf(Bf17), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_varwrite_f(&sVarf_BYY5UH8x, VIf(Bf14));
    __hv_varread_f(&sVarf_PQ81CEKN, VOf(Bf14));
    __hv_line_f(&sLine_tJWtFdSf, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_4oL7ZEfr, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_Wq1AhdFy, VOf(Bf16));
    __hv_mul_f(VIf(Bf18), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_AcClPwmk, VIf(Bf16));
    __hv_line_f(&sLine_hq1ABSg2, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_zGKQYMr7, VOf(Bf19));
    __hv_mul_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_AXn5EXnY, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_vMer91M8, VIf(Bf16));
    __hv_line_f(&sLine_437k1aT2, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_EPkRW1uP, VOf(Bf14));
    __hv_mul_f(VIf(Bf18), VIf(Bf14), VOf(Bf14));
    __hv_add_f(VIf(Bf16), VIf(Bf14), VOf(Bf14));
    __hv_line_f(&sLine_hxeeEjSG, VOf(Bf16));
    __hv_mul_f(VIf(Bf2), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Tys4FHVn, VIf(Bf16));
    __hv_varwrite_f(&sVarf_ZKvaBAy8, VIf(Bf1));
    __hv_varwrite_f(&sVarf_OrOW2xz8, VIf(Bf12));
    __hv_varwrite_f(&sVarf_cNadffxp, VIf(Bf11));
    sEnv_process(this, &sEnv_YC3GgUsK, VIf(Bf6), &sEnv_YC3GgUsK_sendMessage);
    sEnv_process(this, &sEnv_myiR8KhG, VIf(Bf0), &sEnv_myiR8KhG_sendMessage);
    __hv_line_f(&sLine_Cebs6eJz, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_o8S4vgbQ, VOf(Bf6));
    __hv_mul_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_dZeitjSt, VOf(Bf0));
    __hv_var_k_f(VOf(Bf11), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf0), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf0), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf11), VIf(Bf0), VOf(Bf0));
    __hv_exp_f(VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_nH1s7gdx, VOf(Bf6));
    __hv_line_f(&sLine_r4SvA1pf, VOf(Bf11));
    __hv_var_k_f(VOf(Bf12), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf11), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf12), VIf(Bf11), VOf(Bf11));
    __hv_floor_f(VIf(Bf11), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf11), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_EL39LGDp, VIf(Bf12));
    __hv_varwrite_f(&sVarf_nH1s7gdx, VIf(Bf7));
    __hv_varwrite_f(&sVarf_Rc3aHnre, VIf(Bf13));
    __hv_varwrite_f(&sVarf_fcAvfX7E, VIf(Bf15));
    __hv_varread_f(&sVarf_fcAvfX7E, VOf(Bf15));
    __hv_line_f(&sLine_XWFdzROz, VOf(Bf13));
    __hv_mul_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_mul_f(VIf(Bf13), VIf(Bf13), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf15), VIf(Bf7), VOf(Bf12));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf15), VIf(Bf6), VIf(Bf7), VOf(Bf7));
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_qiJx1YSN, VIf(Bf7));
    __hv_varread_f(&sVarf_Rc3aHnre, VOf(Bf7));
    __hv_line_f(&sLine_GeARnWNh, VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf7), VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf12));
    __hv_sub_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_abs_f(VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf12), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf13), VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_neg_f(VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_fwF1hmOs, VIf(Bf7));
    __hv_varwrite_f(&sVarf_1PWQLeu9, VIf(Bf0));
    __hv_varread_f(&sVarf_ceOwrgm6, VOf(Bf0));
    __hv_varread_f(&sVarf_dzP7yIyW, VOf(Bf7));
    __hv_varread_f(&sVarf_S5QLqQrU, VOf(Bf12));
    __hv_varread_f(&sVarf_ZMHXriKY, VOf(Bf13));
    __hv_varread_f(&sVarf_mZM53hdw, VOf(Bf6));
    __hv_varread_f(&sVarf_T6ct2mvE, VOf(Bf15));
    __hv_varread_f(&sVarf_gekzwsjk, VOf(Bf11));
    __hv_varwrite_f(&sVarf_3x0Xsvww, VIf(Bf4));
    __hv_varread_f(&sVarf_wYU2c7XG, VOf(Bf1));
    __hv_line_f(&sLine_jZkGFHbA, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_sn0Xj6x2, VOf(Bf14));
    __hv_line_f(&sLine_bLVWCqtx, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_BlWG8Y9a, VOf(Bf16));
    __hv_line_f(&sLine_9HskizCq, VOf(Bf18));
    __hv_mul_f(VIf(Bf16), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_varwrite_f(&sVarf_ZMHXriKY, VIf(Bf18));
    __hv_varread_f(&sVarf_3x0Xsvww, VOf(Bf18));
    __hv_line_f(&sLine_XJPZ4dP4, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_HJ8VGAqS, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_JNOQDcZc, VOf(Bf2));
    __hv_mul_f(VIf(Bf14), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_mZM53hdw, VIf(Bf2));
    __hv_line_f(&sLine_5nJShd33, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ILItmIhh, VOf(Bf19));
    __hv_mul_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf2), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_lUzJ7L0B, VOf(Bf2));
    __hv_mul_f(VIf(Bf16), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf19), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_T6ct2mvE, VIf(Bf2));
    __hv_line_f(&sLine_6yHMomB5, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_ex5WzkHe, VOf(Bf18));
    __hv_mul_f(VIf(Bf14), VIf(Bf18), VOf(Bf18));
    __hv_add_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_line_f(&sLine_N24yBwr2, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_varwrite_f(&sVarf_gekzwsjk, VIf(Bf2));
    __hv_varwrite_f(&sVarf_wYU2c7XG, VIf(Bf0));
    __hv_varwrite_f(&sVarf_sn0Xj6x2, VIf(Bf7));
    __hv_varwrite_f(&sVarf_BlWG8Y9a, VIf(Bf12));
    sEnv_process(this, &sEnv_HNxBPYug, VIf(Bf13), &sEnv_HNxBPYug_sendMessage);
    sEnv_process(this, &sEnv_DzKQc4mD, VIf(Bf4), &sEnv_DzKQc4mD_sendMessage);
    __hv_line_f(&sLine_jX4ZQ6vE, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_ThGM0DTZ, VOf(Bf13));
    __hv_mul_f(VIf(Bf4), VIf(Bf13), VOf(Bf13));
    __hv_line_f(&sLine_WWKCJHek, VOf(Bf4));
    __hv_var_k_f(VOf(Bf12), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf12), VOf(Bf12));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf12), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf13), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_MlHiJwIG, VOf(Bf13));
    __hv_line_f(&sLine_FDQL6git, VOf(Bf12));
    __hv_var_k_f(VOf(Bf7), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf12), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf12), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf13), VIf(Bf7), VIf(Bf12), VOf(Bf12));
    __hv_floor_f(VIf(Bf12), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_sub_f(VIf(Bf12), VIf(Bf13), VOf(Bf13));
    __hv_div_f(VIf(Bf13), VIf(Bf7), VOf(Bf7));
    __hv_varwrite_f(&sVarf_ceOwrgm6, VIf(Bf7));
    __hv_varwrite_f(&sVarf_MlHiJwIG, VIf(Bf6));
    __hv_varwrite_f(&sVarf_byLecGF9, VIf(Bf15));
    __hv_varwrite_f(&sVarf_uc5hb9ge, VIf(Bf11));
    __hv_varread_f(&sVarf_uc5hb9ge, VOf(Bf11));
    __hv_line_f(&sLine_XtwCSIKZ, VOf(Bf15));
    __hv_mul_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf11), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf15), VIf(Bf11), VOf(Bf11));
    __hv_var_k_f(VOf(Bf15), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf11), VIf(Bf15), VOf(Bf15));
    __hv_mul_f(VIf(Bf15), VIf(Bf15), VOf(Bf11));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf11), VIf(Bf6), VOf(Bf7));
    __hv_var_k_f(VOf(Bf13), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf11), VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf15), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_S5QLqQrU, VIf(Bf6));
    __hv_varread_f(&sVarf_byLecGF9, VOf(Bf6));
    __hv_line_f(&sLine_KKsj5Poa, VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf7));
    __hv_sub_f(VIf(Bf15), VIf(Bf7), VOf(Bf7));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf7), VIf(Bf15), VOf(Bf15));
    __hv_abs_f(VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf7), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf15), VIf(Bf7), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_dzP7yIyW, VIf(Bf6));
    __hv_varwrite_f(&sVarf_r5gL73B1, VIf(Bf4));
    __hv_varwrite_f(&sVarf_ZHMLXhTC, VIf(Bf10));
    __hv_varread_f(&sVarf_Zm2kcFzT, VOf(Bf10));
    __hv_varread_f(&sVarf_yYu6H3uU, VOf(Bf4));
    __hv_varread_f(&sVarf_0hOGzVKF, VOf(Bf6));
    __hv_varread_f(&sVarf_4gesI4YJ, VOf(Bf7));
    __hv_varread_f(&sVarf_JJXFAwrs, VOf(Bf15));
    __hv_varread_f(&sVarf_ZEhayyGz, VOf(Bf13));
    __hv_line_f(&sLine_RuJ0NTsR, VOf(Bf11));
    __hv_line_f(&sLine_FVo9Od1b, VOf(Bf12));
    __hv_mul_f(VIf(Bf7), VIf(Bf12), VOf(Bf7));
    __hv_fma_f(VIf(Bf6), VIf(Bf11), VIf(Bf7), VOf(Bf7));
    __hv_mul_f(VIf(Bf13), VIf(Bf12), VOf(Bf12));
    __hv_fma_f(VIf(Bf15), VIf(Bf11), VIf(Bf12), VOf(Bf12));
    __hv_varwrite_f(&sVarf_0hOGzVKF, VIf(Bf10));
    __hv_varwrite_f(&sVarf_JJXFAwrs, VIf(Bf4));
    __hv_varread_f(&sVarf_073r3Orr, VOf(Bf11));
    __hv_varread_f(&sVarf_iC5cqjfX, VOf(Bf15));
    __hv_varread_f(&sVarf_bSIxSwBC, VOf(Bf13));
    __hv_varread_f(&sVarf_MoUCEgBA, VOf(Bf6));
    __hv_varread_f(&sVarf_w6zqKVKp, VOf(Bf0));
    __hv_varread_f(&sVarf_ced5X4v1, VOf(Bf2));
    __hv_varread_f(&sVarf_Lp695ivl, VOf(Bf18));
    __hv_varwrite_f(&sVarf_2XiDijXc, VIf(Bf10));
    __hv_varread_f(&sVarf_Iql0vLIy, VOf(Bf1));
    __hv_line_f(&sLine_sHT0QqiO, VOf(Bf14));
    __hv_mul_f(VIf(Bf1), VIf(Bf14), VOf(Bf14));
    __hv_varread_f(&sVarf_YlVC8R6I, VOf(Bf19));
    __hv_line_f(&sLine_1xS2KbNe, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_DrZxmKbN, VOf(Bf14));
    __hv_line_f(&sLine_FnhbTJOl, VOf(Bf17));
    __hv_mul_f(VIf(Bf14), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_varwrite_f(&sVarf_MoUCEgBA, VIf(Bf17));
    __hv_varread_f(&sVarf_2XiDijXc, VOf(Bf17));
    __hv_line_f(&sLine_V6F7dCFZ, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_JTwocyq2, VOf(Bf20));
    __hv_mul_f(VIf(Bf14), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_VlWyqMrN, VOf(Bf16));
    __hv_mul_f(VIf(Bf19), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_w6zqKVKp, VIf(Bf16));
    __hv_line_f(&sLine_IXfG83bu, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_IcTTtF1K, VOf(Bf20));
    __hv_mul_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_xdrxI4yx, VOf(Bf16));
    __hv_mul_f(VIf(Bf14), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf20), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_ced5X4v1, VIf(Bf16));
    __hv_line_f(&sLine_x6UyTMU5, VOf(Bf16));
    __hv_mul_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_line_f(&sLine_awq9kSRG, VOf(Bf17));
    __hv_mul_f(VIf(Bf19), VIf(Bf17), VOf(Bf17));
    __hv_add_f(VIf(Bf16), VIf(Bf17), VOf(Bf17));
    __hv_line_f(&sLine_uQomrI8Z, VOf(Bf16));
    __hv_mul_f(VIf(Bf1), VIf(Bf16), VOf(Bf16));
    __hv_add_f(VIf(Bf17), VIf(Bf16), VOf(Bf16));
    __hv_varwrite_f(&sVarf_Lp695ivl, VIf(Bf16));
    __hv_varwrite_f(&sVarf_Iql0vLIy, VIf(Bf11));
    __hv_varwrite_f(&sVarf_YlVC8R6I, VIf(Bf15));
    __hv_varwrite_f(&sVarf_DrZxmKbN, VIf(Bf13));
    sEnv_process(this, &sEnv_YAbtSPPU, VIf(Bf6), &sEnv_YAbtSPPU_sendMessage);
    sEnv_process(this, &sEnv_ILqxuXLg, VIf(Bf10), &sEnv_ILqxuXLg_sendMessage);
    __hv_line_f(&sLine_FmttK2NN, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_line_f(&sLine_nB3hjMCB, VOf(Bf6));
    __hv_mul_f(VIf(Bf10), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_vDCz0vsr, VOf(Bf10));
    __hv_var_k_f(VOf(Bf13), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf10), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf10), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf13), VIf(Bf10), VOf(Bf10));
    __hv_exp_f(VIf(Bf10), VOf(Bf10));
    __hv_mul_f(VIf(Bf6), VIf(Bf10), VOf(Bf10));
    __hv_varread_f(&sVarf_e820nxqE, VOf(Bf6));
    __hv_line_f(&sLine_aF8OwE6S, VOf(Bf13));
    __hv_var_k_f(VOf(Bf15), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf13), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf13), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf6), VIf(Bf15), VIf(Bf13), VOf(Bf13));
    __hv_floor_f(VIf(Bf13), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_sub_f(VIf(Bf13), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf6), VIf(Bf15), VOf(Bf15));
    __hv_varwrite_f(&sVarf_073r3Orr, VIf(Bf15));
    __hv_varwrite_f(&sVarf_e820nxqE, VIf(Bf0));
    __hv_varwrite_f(&sVarf_HHobGLy0, VIf(Bf2));
    __hv_varwrite_f(&sVarf_4vbUBxbB, VIf(Bf18));
    __hv_varread_f(&sVarf_4vbUBxbB, VOf(Bf18));
    __hv_line_f(&sLine_Ei4G7UyD, VOf(Bf2));
    __hv_mul_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf18), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf2), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf2), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf18), VIf(Bf2), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf2), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf18), VIf(Bf0), VOf(Bf15));
    __hv_var_k_f(VOf(Bf6), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf18), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_mul_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_bSIxSwBC, VIf(Bf0));
    __hv_varread_f(&sVarf_HHobGLy0, VOf(Bf0));
    __hv_line_f(&sLine_ex897gix, VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf0), VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf15));
    __hv_sub_f(VIf(Bf2), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf2), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_abs_f(VIf(Bf2), VOf(Bf2));
    __hv_var_k_f(VOf(Bf15), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf2), VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_neg_f(VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_iC5cqjfX, VIf(Bf0));
    __hv_varwrite_f(&sVarf_4gesI4YJ, VIf(Bf10));
    __hv_varread_f(&sVarf_N0Akvobr, VOf(Bf10));
    __hv_varread_f(&sVarf_FzhRXwVz, VOf(Bf0));
    __hv_varread_f(&sVarf_zSmVpUBv, VOf(Bf15));
    __hv_varread_f(&sVarf_BiVv8HHq, VOf(Bf2));
    __hv_varread_f(&sVarf_1Azf7Mrq, VOf(Bf6));
    __hv_varread_f(&sVarf_FsNxEoUM, VOf(Bf18));
    __hv_varread_f(&sVarf_xCHKr8lg, VOf(Bf13));
    __hv_varwrite_f(&sVarf_hKGxsPTG, VIf(Bf4));
    __hv_varread_f(&sVarf_IBnG941I, VOf(Bf11));
    __hv_line_f(&sLine_kwUgVFKH, VOf(Bf16));
    __hv_mul_f(VIf(Bf11), VIf(Bf16), VOf(Bf16));
    __hv_varread_f(&sVarf_4R8JAkCz, VOf(Bf17));
    __hv_line_f(&sLine_AmMnkekN, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_2ebo6TTP, VOf(Bf16));
    __hv_line_f(&sLine_r5jsoVuv, VOf(Bf19));
    __hv_mul_f(VIf(Bf16), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_varwrite_f(&sVarf_BiVv8HHq, VIf(Bf19));
    __hv_varread_f(&sVarf_hKGxsPTG, VOf(Bf19));
    __hv_line_f(&sLine_ICVTUUMi, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_av0Qnxwf, VOf(Bf20));
    __hv_mul_f(VIf(Bf16), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_YLynZFV2, VOf(Bf1));
    __hv_mul_f(VIf(Bf17), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_1Azf7Mrq, VIf(Bf1));
    __hv_line_f(&sLine_53Y1YoUR, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_LUBmlDLt, VOf(Bf20));
    __hv_mul_f(VIf(Bf11), VIf(Bf20), VOf(Bf20));
    __hv_add_f(VIf(Bf1), VIf(Bf20), VOf(Bf20));
    __hv_line_f(&sLine_vQteJK76, VOf(Bf1));
    __hv_mul_f(VIf(Bf16), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf20), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_FsNxEoUM, VIf(Bf1));
    __hv_line_f(&sLine_yJPNxfCa, VOf(Bf1));
    __hv_mul_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_jhbFsZEl, VOf(Bf19));
    __hv_mul_f(VIf(Bf17), VIf(Bf19), VOf(Bf19));
    __hv_add_f(VIf(Bf1), VIf(Bf19), VOf(Bf19));
    __hv_line_f(&sLine_jDIBKC49, VOf(Bf1));
    __hv_mul_f(VIf(Bf11), VIf(Bf1), VOf(Bf1));
    __hv_add_f(VIf(Bf19), VIf(Bf1), VOf(Bf1));
    __hv_varwrite_f(&sVarf_xCHKr8lg, VIf(Bf1));
    __hv_varwrite_f(&sVarf_IBnG941I, VIf(Bf10));
    __hv_varwrite_f(&sVarf_4R8JAkCz, VIf(Bf0));
    __hv_varwrite_f(&sVarf_2ebo6TTP, VIf(Bf15));
    sEnv_process(this, &sEnv_dnYJh9KV, VIf(Bf2), &sEnv_dnYJh9KV_sendMessage);
    sEnv_process(this, &sEnv_jilBNwLN, VIf(Bf4), &sEnv_jilBNwLN_sendMessage);
    __hv_line_f(&sLine_KZ1utVkS, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_2memqOg2, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_line_f(&sLine_0pQCN5Kc, VOf(Bf4));
    __hv_var_k_f(VOf(Bf15), 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f, 100.0f);
    __hv_sub_f(VIf(Bf4), VIf(Bf15), VOf(Bf15));
    __hv_var_k_f(VOf(Bf4), 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f, 0.115129254649702f);
    __hv_mul_f(VIf(Bf15), VIf(Bf4), VOf(Bf4));
    __hv_exp_f(VIf(Bf4), VOf(Bf4));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_vuTnGb2l, VOf(Bf2));
    __hv_line_f(&sLine_xbNZdjGY, VOf(Bf15));
    __hv_var_k_f(VOf(Bf0), 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f, 2.0f);
    __hv_div_f(VIf(Bf15), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf15), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_fma_f(VIf(Bf2), VIf(Bf0), VIf(Bf15), VOf(Bf15));
    __hv_floor_f(VIf(Bf15), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf15), VIf(Bf2), VOf(Bf2));
    __hv_div_f(VIf(Bf2), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_N0Akvobr, VIf(Bf0));
    __hv_varwrite_f(&sVarf_vuTnGb2l, VIf(Bf6));
    __hv_varwrite_f(&sVarf_68CWNm3x, VIf(Bf18));
    __hv_varwrite_f(&sVarf_cZManktZ, VIf(Bf13));
    __hv_varread_f(&sVarf_cZManktZ, VOf(Bf13));
    __hv_line_f(&sLine_5tAv0asA, VOf(Bf18));
    __hv_mul_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf13), 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f, 3.0f);
    __hv_min_f(VIf(Bf18), VIf(Bf13), VOf(Bf13));
    __hv_var_k_f(VOf(Bf18), -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f, -3.0f);
    __hv_max_f(VIf(Bf13), VIf(Bf18), VOf(Bf18));
    __hv_mul_f(VIf(Bf18), VIf(Bf18), VOf(Bf13));
    __hv_var_k_f(VOf(Bf6), 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f, 27.0f);
    __hv_add_f(VIf(Bf13), VIf(Bf6), VOf(Bf0));
    __hv_var_k_f(VOf(Bf2), 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f, 9.0f);
    __hv_fma_f(VIf(Bf13), VIf(Bf2), VIf(Bf6), VOf(Bf6));
    __hv_div_f(VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_mul_f(VIf(Bf18), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_zSmVpUBv, VIf(Bf6));
    __hv_varread_f(&sVarf_68CWNm3x, VOf(Bf6));
    __hv_line_f(&sLine_f75shRFM, VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fma_f(VIf(Bf6), VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_div_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_floor_f(VIf(Bf18), VOf(Bf0));
    __hv_sub_f(VIf(Bf18), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf18), 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f, 0.5f);
    __hv_sub_f(VIf(Bf0), VIf(Bf18), VOf(Bf18));
    __hv_abs_f(VIf(Bf18), VOf(Bf18));
    __hv_var_k_f(VOf(Bf0), 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f, 4.0f);
    __hv_var_k_f(VOf(Bf6), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_fms_f(VIf(Bf18), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_neg_f(VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_FzhRXwVz, VIf(Bf6));
    __hv_varwrite_f(&sVarf_ZEhayyGz, VIf(Bf4));
    __hv_varwrite_f(&sVarf_vgma3qb6, VIf(Bf7));
    __hv_varwrite_f(&sVarf_syXf4B0Q, VIf(Bf8));
    __hv_varwrite_f(&sVarf_5MMUiliv, VIf(Bf9));
    __hv_varwrite_f(&sVarf_RxSz7aiq, VIf(Bf12));
    __hv_varwrite_f(&sVarf_kLi9NjSN, VIf(Bf3));
    __hv_varwrite_f(&sVarf_5brH23XQ, VIf(Bf5));
    __hv_varread_f(&sVarf_HDOTMY0t, VOf(Bf5));
    __hv_varread_f(&sVarf_ZHMLXhTC, VOf(Bf3));
    __hv_varread_f(&sVarf_vgma3qb6, VOf(Bf12));
    __hv_add_f(VIf(Bf3), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf5), VIf(Bf12), VOf(Bf12));
    __hv_add_f(VIf(Bf12), VIf(O0), VOf(O0));
    __hv_varread_f(&sVarf_syXf4B0Q, VOf(Bf12));
    __hv_varread_f(&sVarf_5MMUiliv, VOf(Bf5));
    __hv_varread_f(&sVarf_RxSz7aiq, VOf(Bf3));
    __hv_add_f(VIf(Bf5), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf12), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_M3NGLR::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_M3NGLR::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
